Class: Phrase::Automation

Inherits:
Object
  • Object
show all
Defined in:
lib/phrase/models/automation.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ Automation

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
# File 'lib/phrase/models/automation.rb', line 116

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Phrase::Automation` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Phrase::Automation`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'id')
    self.id = attributes[:'id']
  end

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  end

  if attributes.key?(:'status')
    self.status = attributes[:'status']
  end

  if attributes.key?(:'trigger')
    self.trigger = attributes[:'trigger']
  end

  if attributes.key?(:'status_filters')
    if (value = attributes[:'status_filters']).is_a?(Array)
      self.status_filters = value
    end
  end

  if attributes.key?(:'project_id')
    self.project_id = attributes[:'project_id']
  end

  if attributes.key?(:'project_ids')
    if (value = attributes[:'project_ids']).is_a?(Array)
      self.project_ids = value
    end
  end

  if attributes.key?(:'job_template_id')
    self.job_template_id = attributes[:'job_template_id']
  end

  if attributes.key?(:'job_owner_id')
    self.job_owner_id = attributes[:'job_owner_id']
  end

  if attributes.key?(:'include_only_updated_locales')
    self.include_only_updated_locales = attributes[:'include_only_updated_locales']
  end

  if attributes.key?(:'tags')
    if (value = attributes[:'tags']).is_a?(Array)
      self.tags = value
    end
  end

  if attributes.key?(:'cron_schedule')
    self.cron_schedule = attributes[:'cron_schedule']
  end

  if attributes.key?(:'time_zone')
    self.time_zone = attributes[:'time_zone']
  end

  if attributes.key?(:'account')
    self. = attributes[:'account']
  end

  if attributes.key?(:'created_at')
    self.created_at = attributes[:'created_at']
  end

  if attributes.key?(:'updated_at')
    self.updated_at = attributes[:'updated_at']
  end
end

Instance Attribute Details

#accountObject

Returns the value of attribute account.



35
36
37
# File 'lib/phrase/models/automation.rb', line 35

def 
  @account
end

#created_atObject

Returns the value of attribute created_at.



37
38
39
# File 'lib/phrase/models/automation.rb', line 37

def created_at
  @created_at
end

#cron_scheduleObject

Returns the value of attribute cron_schedule.



31
32
33
# File 'lib/phrase/models/automation.rb', line 31

def cron_schedule
  @cron_schedule
end

#idObject

Returns the value of attribute id.



5
6
7
# File 'lib/phrase/models/automation.rb', line 5

def id
  @id
end

#include_only_updated_localesObject

When ‘true`, the automation only acts on locales that changed since its last run.



27
28
29
# File 'lib/phrase/models/automation.rb', line 27

def include_only_updated_locales
  @include_only_updated_locales
end

#job_owner_idObject

User ID of the job owner that newly created jobs are assigned to.



24
25
26
# File 'lib/phrase/models/automation.rb', line 24

def job_owner_id
  @job_owner_id
end

#job_template_idObject

Returns the value of attribute job_template_id.



21
22
23
# File 'lib/phrase/models/automation.rb', line 21

def job_template_id
  @job_template_id
end

#nameObject

Returns the value of attribute name.



7
8
9
# File 'lib/phrase/models/automation.rb', line 7

def name
  @name
end

#project_idObject

Returns the value of attribute project_id.



16
17
18
# File 'lib/phrase/models/automation.rb', line 16

def project_id
  @project_id
end

#project_idsObject

All project IDs the automation applies to. Returned alongside the singular ‘project_id` for backwards compatibility.



19
20
21
# File 'lib/phrase/models/automation.rb', line 19

def project_ids
  @project_ids
end

#statusObject

Returns the value of attribute status.



9
10
11
# File 'lib/phrase/models/automation.rb', line 9

def status
  @status
end

#status_filtersObject

translation key statuses used to filter keys that are added to jobs



14
15
16
# File 'lib/phrase/models/automation.rb', line 14

def status_filters
  @status_filters
end

#tagsObject

Returns the value of attribute tags.



29
30
31
# File 'lib/phrase/models/automation.rb', line 29

def tags
  @tags
end

#time_zoneObject

Returns the value of attribute time_zone.



33
34
35
# File 'lib/phrase/models/automation.rb', line 33

def time_zone
  @time_zone
end

#triggerObject

Returns the value of attribute trigger.



11
12
13
# File 'lib/phrase/models/automation.rb', line 11

def trigger
  @trigger
end

#updated_atObject

Returns the value of attribute updated_at.



39
40
41
# File 'lib/phrase/models/automation.rb', line 39

def updated_at
  @updated_at
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
# File 'lib/phrase/models/automation.rb', line 64

def self.attribute_map
  {
    :'id' => :'id',
    :'name' => :'name',
    :'status' => :'status',
    :'trigger' => :'trigger',
    :'status_filters' => :'status_filters',
    :'project_id' => :'project_id',
    :'project_ids' => :'project_ids',
    :'job_template_id' => :'job_template_id',
    :'job_owner_id' => :'job_owner_id',
    :'include_only_updated_locales' => :'include_only_updated_locales',
    :'tags' => :'tags',
    :'cron_schedule' => :'cron_schedule',
    :'time_zone' => :'time_zone',
    :'account' => :'account',
    :'created_at' => :'created_at',
    :'updated_at' => :'updated_at'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



275
276
277
# File 'lib/phrase/models/automation.rb', line 275

def self.build_from_hash(attributes)
  new.build_from_hash(attributes)
end

.openapi_nullableObject

List of attributes with nullable: true



108
109
110
111
112
# File 'lib/phrase/models/automation.rb', line 108

def self.openapi_nullable
  Set.new([
    :'job_owner_id',
  ])
end

.openapi_typesObject

Attribute type mapping.



86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
# File 'lib/phrase/models/automation.rb', line 86

def self.openapi_types
  {
    :'id' => :'String',
    :'name' => :'String',
    :'status' => :'String',
    :'trigger' => :'String',
    :'status_filters' => :'Array<String>',
    :'project_id' => :'String',
    :'project_ids' => :'Array<String>',
    :'job_template_id' => :'String',
    :'job_owner_id' => :'String',
    :'include_only_updated_locales' => :'Boolean',
    :'tags' => :'Array<String>',
    :'cron_schedule' => :'String',
    :'time_zone' => :'String',
    :'account' => :'Account',
    :'created_at' => :'DateTime',
    :'updated_at' => :'DateTime'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
# File 'lib/phrase/models/automation.rb', line 239

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      id == o.id &&
      name == o.name &&
      status == o.status &&
      trigger == o.trigger &&
      status_filters == o.status_filters &&
      project_id == o.project_id &&
      project_ids == o.project_ids &&
      job_template_id == o.job_template_id &&
      job_owner_id == o.job_owner_id &&
      include_only_updated_locales == o.include_only_updated_locales &&
      tags == o.tags &&
      cron_schedule == o.cron_schedule &&
      time_zone == o.time_zone &&
       == o. &&
      created_at == o.created_at &&
      updated_at == o.updated_at
end

#_deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
# File 'lib/phrase/models/automation.rb', line 303

def _deserialize(type, value)
  case type.to_sym
  when :DateTime
    DateTime.parse(value)
  when :Date
    Date.parse(value)
  when :Time
    Time.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    Phrase.const_get(type).build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



374
375
376
377
378
379
380
381
382
383
384
385
386
# File 'lib/phrase/models/automation.rb', line 374

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
# File 'lib/phrase/models/automation.rb', line 282

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  self.class.openapi_types.each_pair do |key, type|
    if type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) })
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]]))
    end # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


262
263
264
# File 'lib/phrase/models/automation.rb', line 262

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



268
269
270
# File 'lib/phrase/models/automation.rb', line 268

def hash
  [id, name, status, trigger, status_filters, project_id, project_ids, job_template_id, job_owner_id, include_only_updated_locales, tags, cron_schedule, time_zone, , created_at, updated_at].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



202
203
204
205
# File 'lib/phrase/models/automation.rb', line 202

def list_invalid_properties
  invalid_properties = Array.new
  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



350
351
352
# File 'lib/phrase/models/automation.rb', line 350

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



356
357
358
359
360
361
362
363
364
365
366
367
368
# File 'lib/phrase/models/automation.rb', line 356

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



344
345
346
# File 'lib/phrase/models/automation.rb', line 344

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



209
210
211
212
213
214
215
# File 'lib/phrase/models/automation.rb', line 209

def valid?
  status_validator = EnumAttributeValidator.new('String', ["inactive", "active", "error"])
  return false unless status_validator.valid?(@status)
  trigger_validator = EnumAttributeValidator.new('String', ["schedule", "upload"])
  return false unless trigger_validator.valid?(@trigger)
  true
end