Class: Phrase::AutomationEvent

Inherits:
Object
  • Object
show all
Defined in:
lib/phrase/models/automation_event.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ AutomationEvent

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
# File 'lib/phrase/models/automation_event.rb', line 92

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Phrase::AutomationEvent` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Phrase::AutomationEvent`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'id')
    self.id = attributes[:'id']
  end

  if attributes.key?(:'automation_id')
    self.automation_id = attributes[:'automation_id']
  end

  if attributes.key?(:'state')
    self.state = attributes[:'state']
  end

  if attributes.key?(:'triggered_by')
    self.triggered_by = attributes[:'triggered_by']
  end

  if attributes.key?(:'created_at')
    self.created_at = attributes[:'created_at']
  end

  if attributes.key?(:'jobs_created')
    self.jobs_created = attributes[:'jobs_created']
  end

  if attributes.key?(:'job_ids')
    if (value = attributes[:'job_ids']).is_a?(Array)
      self.job_ids = value
    end
  end

  if attributes.key?(:'project')
    self.project = attributes[:'project']
  end

  if attributes.key?(:'details')
    self.details = attributes[:'details']
  end
end

Instance Attribute Details

#automation_idObject

Identifier of the automation that produced this event.



9
10
11
# File 'lib/phrase/models/automation_event.rb', line 9

def automation_id
  @automation_id
end

#created_atObject

Timestamp when the event was created.



18
19
20
# File 'lib/phrase/models/automation_event.rb', line 18

def created_at
  @created_at
end

#detailsObject

Error message describing the failure when state is failure; null otherwise.



29
30
31
# File 'lib/phrase/models/automation_event.rb', line 29

def details
  @details
end

#idObject

Unique identifier of the automation event.



6
7
8
# File 'lib/phrase/models/automation_event.rb', line 6

def id
  @id
end

#job_idsObject

Identifiers of the jobs created during this automation run.



24
25
26
# File 'lib/phrase/models/automation_event.rb', line 24

def job_ids
  @job_ids
end

#jobs_createdObject

Number of jobs created during this automation run.



21
22
23
# File 'lib/phrase/models/automation_event.rb', line 21

def jobs_created
  @jobs_created
end

#projectObject

Returns the value of attribute project.



26
27
28
# File 'lib/phrase/models/automation_event.rb', line 26

def project
  @project
end

#stateObject

Outcome of the automation run.



12
13
14
# File 'lib/phrase/models/automation_event.rb', line 12

def state
  @state
end

#triggered_byObject

What caused the automation to run.



15
16
17
# File 'lib/phrase/models/automation_event.rb', line 15

def triggered_by
  @triggered_by
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



54
55
56
57
58
59
60
61
62
63
64
65
66
# File 'lib/phrase/models/automation_event.rb', line 54

def self.attribute_map
  {
    :'id' => :'id',
    :'automation_id' => :'automation_id',
    :'state' => :'state',
    :'triggered_by' => :'triggered_by',
    :'created_at' => :'created_at',
    :'jobs_created' => :'jobs_created',
    :'job_ids' => :'job_ids',
    :'project' => :'project',
    :'details' => :'details'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



212
213
214
# File 'lib/phrase/models/automation_event.rb', line 212

def self.build_from_hash(attributes)
  new.build_from_hash(attributes)
end

.openapi_nullableObject

List of attributes with nullable: true



84
85
86
87
88
# File 'lib/phrase/models/automation_event.rb', line 84

def self.openapi_nullable
  Set.new([
    :'details'
  ])
end

.openapi_typesObject

Attribute type mapping.



69
70
71
72
73
74
75
76
77
78
79
80
81
# File 'lib/phrase/models/automation_event.rb', line 69

def self.openapi_types
  {
    :'id' => :'String',
    :'automation_id' => :'String',
    :'state' => :'String',
    :'triggered_by' => :'String',
    :'created_at' => :'DateTime',
    :'jobs_created' => :'Integer',
    :'job_ids' => :'Array<String>',
    :'project' => :'AutomationEventProject',
    :'details' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



183
184
185
186
187
188
189
190
191
192
193
194
195
# File 'lib/phrase/models/automation_event.rb', line 183

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      id == o.id &&
      automation_id == o.automation_id &&
      state == o.state &&
      triggered_by == o.triggered_by &&
      created_at == o.created_at &&
      jobs_created == o.jobs_created &&
      job_ids == o.job_ids &&
      project == o.project &&
      details == o.details
end

#_deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
# File 'lib/phrase/models/automation_event.rb', line 240

def _deserialize(type, value)
  case type.to_sym
  when :DateTime
    DateTime.parse(value)
  when :Date
    Date.parse(value)
  when :Time
    Time.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    Phrase.const_get(type).build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



311
312
313
314
315
316
317
318
319
320
321
322
323
# File 'lib/phrase/models/automation_event.rb', line 311

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
# File 'lib/phrase/models/automation_event.rb', line 219

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  self.class.openapi_types.each_pair do |key, type|
    if type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) })
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]]))
    end # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


199
200
201
# File 'lib/phrase/models/automation_event.rb', line 199

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



205
206
207
# File 'lib/phrase/models/automation_event.rb', line 205

def hash
  [id, automation_id, state, triggered_by, created_at, jobs_created, job_ids, project, details].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



146
147
148
149
# File 'lib/phrase/models/automation_event.rb', line 146

def list_invalid_properties
  invalid_properties = Array.new
  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



287
288
289
# File 'lib/phrase/models/automation_event.rb', line 287

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



293
294
295
296
297
298
299
300
301
302
303
304
305
# File 'lib/phrase/models/automation_event.rb', line 293

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



281
282
283
# File 'lib/phrase/models/automation_event.rb', line 281

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



153
154
155
156
157
158
159
# File 'lib/phrase/models/automation_event.rb', line 153

def valid?
  state_validator = EnumAttributeValidator.new('String', ["success", "failure", "in_progress"])
  return false unless state_validator.valid?(@state)
  triggered_by_validator = EnumAttributeValidator.new('String', ["manual", "schedule", "upload", "upload_batch"])
  return false unless triggered_by_validator.valid?(@triggered_by)
  true
end