Class: Phrase::AutomationsCreateParameters1
- Inherits:
-
Object
- Object
- Phrase::AutomationsCreateParameters1
- Defined in:
- lib/phrase/models/automations_create_parameters1.rb
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#cron_schedule ⇒ Object
along with time_zone, specifies when the scheduled automation is supposed to run.
-
#include_only_updated_locales ⇒ Object
When ‘true`, the automation only acts on locales that changed since its last run.
-
#job_owner_id ⇒ Object
User ID of the job owner that newly created jobs are assigned to.
-
#job_template_id ⇒ Object
id of job template that the automation uses to create jobs from.
-
#name ⇒ Object
name of the automation.
-
#project_ids ⇒ Object
List of project IDs to associate with the automation.
-
#status_filters ⇒ Object
translation key statuses used to filter keys that are added to jobs.
-
#tags ⇒ Object
used to filter which keys are added to jobs.
-
#time_zone ⇒ Object
along with cron_schedule, specifies when the scheduled automation is supposed to run.
-
#trigger ⇒ Object
Returns the value of attribute trigger.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ AutomationsCreateParameters1
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ AutomationsCreateParameters1
Initializes the object
96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 |
# File 'lib/phrase/models/automations_create_parameters1.rb', line 96 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Phrase::AutomationsCreateParameters1` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| if (!self.class.attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Phrase::AutomationsCreateParameters1`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'name') self.name = attributes[:'name'] end if attributes.key?(:'trigger') self.trigger = attributes[:'trigger'] end if attributes.key?(:'project_ids') if (value = attributes[:'project_ids']).is_a?(Array) self.project_ids = value end end if attributes.key?(:'job_template_id') self.job_template_id = attributes[:'job_template_id'] end if attributes.key?(:'status_filters') if (value = attributes[:'status_filters']).is_a?(Array) self.status_filters = value end end if attributes.key?(:'tags') if (value = attributes[:'tags']).is_a?(Array) self. = value end end if attributes.key?(:'cron_schedule') self.cron_schedule = attributes[:'cron_schedule'] end if attributes.key?(:'time_zone') self.time_zone = attributes[:'time_zone'] end if attributes.key?(:'job_owner_id') self.job_owner_id = attributes[:'job_owner_id'] end if attributes.key?(:'include_only_updated_locales') self.include_only_updated_locales = attributes[:'include_only_updated_locales'] end end |
Instance Attribute Details
#cron_schedule ⇒ Object
along with time_zone, specifies when the scheduled automation is supposed to run
23 24 25 |
# File 'lib/phrase/models/automations_create_parameters1.rb', line 23 def cron_schedule @cron_schedule end |
#include_only_updated_locales ⇒ Object
When ‘true`, the automation only acts on locales that changed since its last run.
32 33 34 |
# File 'lib/phrase/models/automations_create_parameters1.rb', line 32 def include_only_updated_locales @include_only_updated_locales end |
#job_owner_id ⇒ Object
User ID of the job owner that newly created jobs are assigned to.
29 30 31 |
# File 'lib/phrase/models/automations_create_parameters1.rb', line 29 def job_owner_id @job_owner_id end |
#job_template_id ⇒ Object
id of job template that the automation uses to create jobs from
14 15 16 |
# File 'lib/phrase/models/automations_create_parameters1.rb', line 14 def job_template_id @job_template_id end |
#name ⇒ Object
name of the automation
6 7 8 |
# File 'lib/phrase/models/automations_create_parameters1.rb', line 6 def name @name end |
#project_ids ⇒ Object
List of project IDs to associate with the automation. Currently, only the first ID in the array is used. The array format leaves room for future support of multiple projects.
11 12 13 |
# File 'lib/phrase/models/automations_create_parameters1.rb', line 11 def project_ids @project_ids end |
#status_filters ⇒ Object
translation key statuses used to filter keys that are added to jobs
17 18 19 |
# File 'lib/phrase/models/automations_create_parameters1.rb', line 17 def status_filters @status_filters end |
#tags ⇒ Object
used to filter which keys are added to jobs
20 21 22 |
# File 'lib/phrase/models/automations_create_parameters1.rb', line 20 def @tags end |
#time_zone ⇒ Object
along with cron_schedule, specifies when the scheduled automation is supposed to run
26 27 28 |
# File 'lib/phrase/models/automations_create_parameters1.rb', line 26 def time_zone @time_zone end |
#trigger ⇒ Object
Returns the value of attribute trigger.
8 9 10 |
# File 'lib/phrase/models/automations_create_parameters1.rb', line 8 def trigger @trigger end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
57 58 59 60 61 62 63 64 65 66 67 68 69 70 |
# File 'lib/phrase/models/automations_create_parameters1.rb', line 57 def self.attribute_map { :'name' => :'name', :'trigger' => :'trigger', :'project_ids' => :'project_ids', :'job_template_id' => :'job_template_id', :'status_filters' => :'status_filters', :'tags' => :'tags', :'cron_schedule' => :'cron_schedule', :'time_zone' => :'time_zone', :'job_owner_id' => :'job_owner_id', :'include_only_updated_locales' => :'include_only_updated_locales' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
233 234 235 |
# File 'lib/phrase/models/automations_create_parameters1.rb', line 233 def self.build_from_hash(attributes) new.build_from_hash(attributes) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
89 90 91 92 |
# File 'lib/phrase/models/automations_create_parameters1.rb', line 89 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
73 74 75 76 77 78 79 80 81 82 83 84 85 86 |
# File 'lib/phrase/models/automations_create_parameters1.rb', line 73 def self.openapi_types { :'name' => :'String', :'trigger' => :'String', :'project_ids' => :'Array<String>', :'job_template_id' => :'String', :'status_filters' => :'Array<String>', :'tags' => :'Array<String>', :'cron_schedule' => :'String', :'time_zone' => :'String', :'job_owner_id' => :'String', :'include_only_updated_locales' => :'Boolean' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
203 204 205 206 207 208 209 210 211 212 213 214 215 216 |
# File 'lib/phrase/models/automations_create_parameters1.rb', line 203 def ==(o) return true if self.equal?(o) self.class == o.class && name == o.name && trigger == o.trigger && project_ids == o.project_ids && job_template_id == o.job_template_id && status_filters == o.status_filters && == o. && cron_schedule == o.cron_schedule && time_zone == o.time_zone && job_owner_id == o.job_owner_id && include_only_updated_locales == o.include_only_updated_locales end |
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type
261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 |
# File 'lib/phrase/models/automations_create_parameters1.rb', line 261 def _deserialize(type, value) case type.to_sym when :DateTime DateTime.parse(value) when :Date Date.parse(value) when :Time Time.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model Phrase.const_get(type).build_from_hash(value) end end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
332 333 334 335 336 337 338 339 340 341 342 343 344 |
# File 'lib/phrase/models/automations_create_parameters1.rb', line 332 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 |
# File 'lib/phrase/models/automations_create_parameters1.rb', line 240 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.openapi_types.each_pair do |key, type| if type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) }) end elsif !attributes[self.class.attribute_map[key]].nil? self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]])) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(o) ⇒ Boolean
220 221 222 |
# File 'lib/phrase/models/automations_create_parameters1.rb', line 220 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
226 227 228 |
# File 'lib/phrase/models/automations_create_parameters1.rb', line 226 def hash [name, trigger, project_ids, job_template_id, status_filters, , cron_schedule, time_zone, job_owner_id, include_only_updated_locales].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 |
# File 'lib/phrase/models/automations_create_parameters1.rb', line 158 def list_invalid_properties invalid_properties = Array.new if @name.nil? invalid_properties.push('invalid value for "name", name cannot be nil.') end if @trigger.nil? invalid_properties.push('invalid value for "trigger", trigger cannot be nil.') end if @project_ids.nil? invalid_properties.push('invalid value for "project_ids", project_ids cannot be nil.') end if @status_filters.nil? invalid_properties.push('invalid value for "status_filters", status_filters cannot be nil.') end invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
308 309 310 |
# File 'lib/phrase/models/automations_create_parameters1.rb', line 308 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
314 315 316 317 318 319 320 321 322 323 324 325 326 |
# File 'lib/phrase/models/automations_create_parameters1.rb', line 314 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
302 303 304 |
# File 'lib/phrase/models/automations_create_parameters1.rb', line 302 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
181 182 183 184 185 186 187 188 189 |
# File 'lib/phrase/models/automations_create_parameters1.rb', line 181 def valid? return false if @name.nil? return false if @trigger.nil? trigger_validator = EnumAttributeValidator.new('String', ["schedule", "upload"]) return false unless trigger_validator.valid?(@trigger) return false if @project_ids.nil? return false if @status_filters.nil? true end |