Class: Phrase::FigmaAttachmentsApi
- Inherits:
-
Object
- Object
- Phrase::FigmaAttachmentsApi
- Defined in:
- lib/phrase/api/figma_attachments_api.rb
Instance Attribute Summary collapse
-
#api_client ⇒ Object
Returns the value of attribute api_client.
Instance Method Summary collapse
-
#figma_attachment_create(project_id, figma_attachment_create_parameters, opts = {}) ⇒ FigmaAttachment
Create a Figma attachment Create a new Figma attachment.
-
#figma_attachment_create_with_http_info(project_id, figma_attachment_create_parameters, opts = {}) ⇒ Array<(Response<(FigmaAttachment)>, Integer, Hash)>
Create a Figma attachment Create a new Figma attachment.
-
#figma_attachment_delete(project_id, id, opts = {}) ⇒ nil
Delete a Figma attachment Delete an existing Figma attachment.
-
#figma_attachment_delete_with_http_info(project_id, id, opts = {}) ⇒ Array<(Response, Integer, Hash)>
Delete a Figma attachment Delete an existing Figma attachment.
-
#figma_attachment_show(project_id, id, opts = {}) ⇒ FigmaAttachment
Get a single Figma attachment Get details on a single Figma attachment for a given project.
-
#figma_attachment_show_with_http_info(project_id, id, opts = {}) ⇒ Array<(Response<(FigmaAttachment)>, Integer, Hash)>
Get a single Figma attachment Get details on a single Figma attachment for a given project.
-
#figma_attachment_update(project_id, id, figma_attachment_update_parameters, opts = {}) ⇒ FigmaAttachment
Update a Figma attachment Update an existing Figma attachment.
-
#figma_attachment_update_with_http_info(project_id, id, figma_attachment_update_parameters, opts = {}) ⇒ Array<(Response<(FigmaAttachment)>, Integer, Hash)>
Update a Figma attachment Update an existing Figma attachment.
-
#figma_attachments_list(project_id, opts = {}) ⇒ Array<FigmaAttachment>
List Figma attachments List all Figma attachments for the given project.
-
#figma_attachments_list_with_http_info(project_id, opts = {}) ⇒ Array<(Response<(Array<FigmaAttachment>)>, Integer, Hash)>
List Figma attachments List all Figma attachments for the given project.
-
#initialize(api_client = ApiClient.default) ⇒ FigmaAttachmentsApi
constructor
A new instance of FigmaAttachmentsApi.
Constructor Details
#initialize(api_client = ApiClient.default) ⇒ FigmaAttachmentsApi
Returns a new instance of FigmaAttachmentsApi.
7 8 9 |
# File 'lib/phrase/api/figma_attachments_api.rb', line 7 def initialize(api_client = ApiClient.default) @api_client = api_client end |
Instance Attribute Details
#api_client ⇒ Object
Returns the value of attribute api_client.
5 6 7 |
# File 'lib/phrase/api/figma_attachments_api.rb', line 5 def api_client @api_client end |
Instance Method Details
#figma_attachment_create(project_id, figma_attachment_create_parameters, opts = {}) ⇒ FigmaAttachment
Create a Figma attachment Create a new Figma attachment.
18 19 20 21 |
# File 'lib/phrase/api/figma_attachments_api.rb', line 18 def (project_id, , opts = {}) data, _status_code, _headers = (project_id, , opts) data end |
#figma_attachment_create_with_http_info(project_id, figma_attachment_create_parameters, opts = {}) ⇒ Array<(Response<(FigmaAttachment)>, Integer, Hash)>
Create a Figma attachment Create a new Figma attachment.
31 32 33 34 35 36 37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 |
# File 'lib/phrase/api/figma_attachments_api.rb', line 31 def (project_id, , opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: FigmaAttachmentsApi.figma_attachment_create ...' end # verify the required parameter 'project_id' is set if @api_client.config.client_side_validation && project_id.nil? fail ArgumentError, "Missing the required parameter 'project_id' when calling FigmaAttachmentsApi.figma_attachment_create" end # verify the required parameter 'figma_attachment_create_parameters' is set if @api_client.config.client_side_validation && .nil? fail ArgumentError, "Missing the required parameter 'figma_attachment_create_parameters' when calling FigmaAttachmentsApi.figma_attachment_create" end # resource path local_var_path = '/projects/{project_id}/figma_attachments'.sub('{' + 'project_id' + '}', CGI.escape(project_id.to_s)) # query parameters query_params = opts[:query_params] || {} query_params[:'branch'] = opts[:'branch'] if !opts[:'branch'].nil? # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # HTTP header 'Content-Type' header_params['Content-Type'] = @api_client.select_header_content_type(['application/json']) header_params[:'X-PhraseApp-OTP'] = opts[:'x_phrase_app_otp'] if !opts[:'x_phrase_app_otp'].nil? # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:body] || @api_client.object_to_http_body() # return_type return_type = opts[:return_type] || 'FigmaAttachment' # auth_names auth_names = opts[:auth_names] || ['Basic', 'Token'] = opts.merge( :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:POST, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: FigmaAttachmentsApi#figma_attachment_create\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end response = ::Phrase::Response.new(data, headers) return response, status_code, headers end |
#figma_attachment_delete(project_id, id, opts = {}) ⇒ nil
Delete a Figma attachment Delete an existing Figma attachment.
95 96 97 98 |
# File 'lib/phrase/api/figma_attachments_api.rb', line 95 def (project_id, id, opts = {}) data, _status_code, _headers = (project_id, id, opts) data end |
#figma_attachment_delete_with_http_info(project_id, id, opts = {}) ⇒ Array<(Response, Integer, Hash)>
Delete a Figma attachment Delete an existing Figma attachment.
108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 |
# File 'lib/phrase/api/figma_attachments_api.rb', line 108 def (project_id, id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: FigmaAttachmentsApi.figma_attachment_delete ...' end # verify the required parameter 'project_id' is set if @api_client.config.client_side_validation && project_id.nil? fail ArgumentError, "Missing the required parameter 'project_id' when calling FigmaAttachmentsApi.figma_attachment_delete" end # verify the required parameter 'id' is set if @api_client.config.client_side_validation && id.nil? fail ArgumentError, "Missing the required parameter 'id' when calling FigmaAttachmentsApi.figma_attachment_delete" end # resource path local_var_path = '/projects/{project_id}/figma_attachments/{id}'.sub('{' + 'project_id' + '}', CGI.escape(project_id.to_s)).sub('{' + 'id' + '}', CGI.escape(id.to_s)) # query parameters query_params = opts[:query_params] || {} query_params[:'branch'] = opts[:'branch'] if !opts[:'branch'].nil? # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) header_params[:'X-PhraseApp-OTP'] = opts[:'x_phrase_app_otp'] if !opts[:'x_phrase_app_otp'].nil? # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:body] # return_type return_type = opts[:return_type] # auth_names auth_names = opts[:auth_names] || ['Basic', 'Token'] = opts.merge( :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:DELETE, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: FigmaAttachmentsApi#figma_attachment_delete\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end response = ::Phrase::Response.new(data, headers) return response, status_code, headers end |
#figma_attachment_show(project_id, id, opts = {}) ⇒ FigmaAttachment
Get a single Figma attachment Get details on a single Figma attachment for a given project.
170 171 172 173 |
# File 'lib/phrase/api/figma_attachments_api.rb', line 170 def (project_id, id, opts = {}) data, _status_code, _headers = (project_id, id, opts) data end |
#figma_attachment_show_with_http_info(project_id, id, opts = {}) ⇒ Array<(Response<(FigmaAttachment)>, Integer, Hash)>
Get a single Figma attachment Get details on a single Figma attachment for a given project.
183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 |
# File 'lib/phrase/api/figma_attachments_api.rb', line 183 def (project_id, id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: FigmaAttachmentsApi.figma_attachment_show ...' end # verify the required parameter 'project_id' is set if @api_client.config.client_side_validation && project_id.nil? fail ArgumentError, "Missing the required parameter 'project_id' when calling FigmaAttachmentsApi.figma_attachment_show" end # verify the required parameter 'id' is set if @api_client.config.client_side_validation && id.nil? fail ArgumentError, "Missing the required parameter 'id' when calling FigmaAttachmentsApi.figma_attachment_show" end # resource path local_var_path = '/projects/{project_id}/figma_attachments/{id}'.sub('{' + 'project_id' + '}', CGI.escape(project_id.to_s)).sub('{' + 'id' + '}', CGI.escape(id.to_s)) # query parameters query_params = opts[:query_params] || {} query_params[:'branch'] = opts[:'branch'] if !opts[:'branch'].nil? # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) header_params[:'X-PhraseApp-OTP'] = opts[:'x_phrase_app_otp'] if !opts[:'x_phrase_app_otp'].nil? # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:body] # return_type return_type = opts[:return_type] || 'FigmaAttachment' # auth_names auth_names = opts[:auth_names] || ['Basic', 'Token'] = opts.merge( :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: FigmaAttachmentsApi#figma_attachment_show\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end response = ::Phrase::Response.new(data, headers) return response, status_code, headers end |
#figma_attachment_update(project_id, id, figma_attachment_update_parameters, opts = {}) ⇒ FigmaAttachment
Update a Figma attachment Update an existing Figma attachment.
246 247 248 249 |
# File 'lib/phrase/api/figma_attachments_api.rb', line 246 def (project_id, id, , opts = {}) data, _status_code, _headers = (project_id, id, , opts) data end |
#figma_attachment_update_with_http_info(project_id, id, figma_attachment_update_parameters, opts = {}) ⇒ Array<(Response<(FigmaAttachment)>, Integer, Hash)>
Update a Figma attachment Update an existing Figma attachment.
260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 |
# File 'lib/phrase/api/figma_attachments_api.rb', line 260 def (project_id, id, , opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: FigmaAttachmentsApi.figma_attachment_update ...' end # verify the required parameter 'project_id' is set if @api_client.config.client_side_validation && project_id.nil? fail ArgumentError, "Missing the required parameter 'project_id' when calling FigmaAttachmentsApi.figma_attachment_update" end # verify the required parameter 'id' is set if @api_client.config.client_side_validation && id.nil? fail ArgumentError, "Missing the required parameter 'id' when calling FigmaAttachmentsApi.figma_attachment_update" end # verify the required parameter 'figma_attachment_update_parameters' is set if @api_client.config.client_side_validation && .nil? fail ArgumentError, "Missing the required parameter 'figma_attachment_update_parameters' when calling FigmaAttachmentsApi.figma_attachment_update" end # resource path local_var_path = '/projects/{project_id}/figma_attachments/{id}'.sub('{' + 'project_id' + '}', CGI.escape(project_id.to_s)).sub('{' + 'id' + '}', CGI.escape(id.to_s)) # query parameters query_params = opts[:query_params] || {} query_params[:'branch'] = opts[:'branch'] if !opts[:'branch'].nil? # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # HTTP header 'Content-Type' header_params['Content-Type'] = @api_client.select_header_content_type(['application/json']) header_params[:'X-PhraseApp-OTP'] = opts[:'x_phrase_app_otp'] if !opts[:'x_phrase_app_otp'].nil? # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:body] || @api_client.object_to_http_body() # return_type return_type = opts[:return_type] || 'FigmaAttachment' # auth_names auth_names = opts[:auth_names] || ['Basic', 'Token'] = opts.merge( :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:PATCH, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: FigmaAttachmentsApi#figma_attachment_update\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end response = ::Phrase::Response.new(data, headers) return response, status_code, headers end |
#figma_attachments_list(project_id, opts = {}) ⇒ Array<FigmaAttachment>
List Figma attachments List all Figma attachments for the given project
329 330 331 332 |
# File 'lib/phrase/api/figma_attachments_api.rb', line 329 def (project_id, opts = {}) data, _status_code, _headers = (project_id, opts) data end |
#figma_attachments_list_with_http_info(project_id, opts = {}) ⇒ Array<(Response<(Array<FigmaAttachment>)>, Integer, Hash)>
List Figma attachments List all Figma attachments for the given project
343 344 345 346 347 348 349 350 351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 381 382 383 384 385 386 387 388 389 390 391 392 393 |
# File 'lib/phrase/api/figma_attachments_api.rb', line 343 def (project_id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: FigmaAttachmentsApi.figma_attachments_list ...' end # verify the required parameter 'project_id' is set if @api_client.config.client_side_validation && project_id.nil? fail ArgumentError, "Missing the required parameter 'project_id' when calling FigmaAttachmentsApi.figma_attachments_list" end # resource path local_var_path = '/projects/{project_id}/figma_attachments'.sub('{' + 'project_id' + '}', CGI.escape(project_id.to_s)) # query parameters query_params = opts[:query_params] || {} query_params[:'page'] = opts[:'page'] if !opts[:'page'].nil? query_params[:'per_page'] = opts[:'per_page'] if !opts[:'per_page'].nil? query_params[:'branch'] = opts[:'branch'] if !opts[:'branch'].nil? # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) header_params[:'X-PhraseApp-OTP'] = opts[:'x_phrase_app_otp'] if !opts[:'x_phrase_app_otp'].nil? # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:body] # return_type return_type = opts[:return_type] || 'Array<FigmaAttachment>' # auth_names auth_names = opts[:auth_names] || ['Basic', 'Token'] = opts.merge( :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: FigmaAttachmentsApi#figma_attachments_list\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end response = ::Phrase::Response.new(data, headers) return response, status_code, headers end |