Class: Phrase::IcuSkeletonParameters
- Inherits:
-
Object
- Object
- Phrase::IcuSkeletonParameters
- Defined in:
- lib/phrase/models/icu_skeleton_parameters.rb
Instance Attribute Summary collapse
-
#cldr_version ⇒ Object
Strings supports two CLDR variants, when it comes to pluralization rules.
-
#content ⇒ Object
Source content to derive skeletons from.
-
#id ⇒ Object
Translation code to source content from.
-
#keep_content ⇒ Object
Keep the content and add missing plural forms for each locale.
-
#locale_codes ⇒ Object
Locale codes.
-
#zero_form_enabled ⇒ Object
Indicates whether the zero form should be included or excluded in the returned skeletons.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ IcuSkeletonParameters
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ IcuSkeletonParameters
Initializes the object
55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 |
# File 'lib/phrase/models/icu_skeleton_parameters.rb', line 55 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Phrase::IcuSkeletonParameters` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| if (!self.class.attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Phrase::IcuSkeletonParameters`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'content') self.content = attributes[:'content'] end if attributes.key?(:'id') self.id = attributes[:'id'] end if attributes.key?(:'locale_codes') if (value = attributes[:'locale_codes']).is_a?(Array) self.locale_codes = value end end if attributes.key?(:'keep_content') self.keep_content = attributes[:'keep_content'] end if attributes.key?(:'zero_form_enabled') self.zero_form_enabled = attributes[:'zero_form_enabled'] end if attributes.key?(:'cldr_version') self.cldr_version = attributes[:'cldr_version'] end end |
Instance Attribute Details
#cldr_version ⇒ Object
Strings supports two CLDR variants, when it comes to pluralization rules. \ You can choose which one you want to use when constructing the skeletons. Possible values \ are ‘legacy` and `cldr_41`. Default value is `legacy`.
21 22 23 |
# File 'lib/phrase/models/icu_skeleton_parameters.rb', line 21 def cldr_version @cldr_version end |
#content ⇒ Object
Source content to derive skeletons from. Mutually exclusive with ‘id`; exactly one of the two must be provided.
6 7 8 |
# File 'lib/phrase/models/icu_skeleton_parameters.rb', line 6 def content @content end |
#id ⇒ Object
Translation code to source content from. Mutually exclusive with ‘content`; exactly one of the two must be provided.
9 10 11 |
# File 'lib/phrase/models/icu_skeleton_parameters.rb', line 9 def id @id end |
#keep_content ⇒ Object
Keep the content and add missing plural forms for each locale
15 16 17 |
# File 'lib/phrase/models/icu_skeleton_parameters.rb', line 15 def keep_content @keep_content end |
#locale_codes ⇒ Object
Locale codes
12 13 14 |
# File 'lib/phrase/models/icu_skeleton_parameters.rb', line 12 def locale_codes @locale_codes end |
#zero_form_enabled ⇒ Object
Indicates whether the zero form should be included or excluded in the returned skeletons
18 19 20 |
# File 'lib/phrase/models/icu_skeleton_parameters.rb', line 18 def zero_form_enabled @zero_form_enabled end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
24 25 26 27 28 29 30 31 32 33 |
# File 'lib/phrase/models/icu_skeleton_parameters.rb', line 24 def self.attribute_map { :'content' => :'content', :'id' => :'id', :'locale_codes' => :'locale_codes', :'keep_content' => :'keep_content', :'zero_form_enabled' => :'zero_form_enabled', :'cldr_version' => :'cldr_version' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
136 137 138 |
# File 'lib/phrase/models/icu_skeleton_parameters.rb', line 136 def self.build_from_hash(attributes) new.build_from_hash(attributes) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
48 49 50 51 |
# File 'lib/phrase/models/icu_skeleton_parameters.rb', line 48 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
36 37 38 39 40 41 42 43 44 45 |
# File 'lib/phrase/models/icu_skeleton_parameters.rb', line 36 def self.openapi_types { :'content' => :'String', :'id' => :'String', :'locale_codes' => :'Array<String>', :'keep_content' => :'Boolean', :'zero_form_enabled' => :'Boolean', :'cldr_version' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
110 111 112 113 114 115 116 117 118 119 |
# File 'lib/phrase/models/icu_skeleton_parameters.rb', line 110 def ==(o) return true if self.equal?(o) self.class == o.class && content == o.content && id == o.id && locale_codes == o.locale_codes && keep_content == o.keep_content && zero_form_enabled == o.zero_form_enabled && cldr_version == o.cldr_version end |
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type
164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 |
# File 'lib/phrase/models/icu_skeleton_parameters.rb', line 164 def _deserialize(type, value) case type.to_sym when :DateTime DateTime.parse(value) when :Date Date.parse(value) when :Time Time.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model Phrase.const_get(type).build_from_hash(value) end end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
235 236 237 238 239 240 241 242 243 244 245 246 247 |
# File 'lib/phrase/models/icu_skeleton_parameters.rb', line 235 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 |
# File 'lib/phrase/models/icu_skeleton_parameters.rb', line 143 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.openapi_types.each_pair do |key, type| if type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) }) end elsif !attributes[self.class.attribute_map[key]].nil? self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]])) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(o) ⇒ Boolean
123 124 125 |
# File 'lib/phrase/models/icu_skeleton_parameters.rb', line 123 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
129 130 131 |
# File 'lib/phrase/models/icu_skeleton_parameters.rb', line 129 def hash [content, id, locale_codes, keep_content, zero_form_enabled, cldr_version].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
97 98 99 100 |
# File 'lib/phrase/models/icu_skeleton_parameters.rb', line 97 def list_invalid_properties invalid_properties = Array.new invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
211 212 213 |
# File 'lib/phrase/models/icu_skeleton_parameters.rb', line 211 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
217 218 219 220 221 222 223 224 225 226 227 228 229 |
# File 'lib/phrase/models/icu_skeleton_parameters.rb', line 217 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
205 206 207 |
# File 'lib/phrase/models/icu_skeleton_parameters.rb', line 205 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
104 105 106 |
# File 'lib/phrase/models/icu_skeleton_parameters.rb', line 104 def valid? true end |