Class: Phrase::JobDetails

Inherits:
Object
  • Object
show all
Defined in:
lib/phrase/models/job_details.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ JobDetails

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
# File 'lib/phrase/models/job_details.rb', line 125

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Phrase::JobDetails` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Phrase::JobDetails`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'id')
    self.id = attributes[:'id']
  end

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  end

  if attributes.key?(:'briefing')
    self.briefing = attributes[:'briefing']
  end

  if attributes.key?(:'due_date')
    self.due_date = attributes[:'due_date']
  end

  if attributes.key?(:'state')
    self.state = attributes[:'state']
  end

  if attributes.key?(:'ticket_url')
    self.ticket_url = attributes[:'ticket_url']
  end

  if attributes.key?(:'project')
    self.project = attributes[:'project']
  end

  if attributes.key?(:'branch')
    self.branch = attributes[:'branch']
  end

  if attributes.key?(:'created_at')
    self.created_at = attributes[:'created_at']
  end

  if attributes.key?(:'updated_at')
    self.updated_at = attributes[:'updated_at']
  end

  if attributes.key?(:'automation_id')
    self.automation_id = attributes[:'automation_id']
  end

  if attributes.key?(:'job_template_id')
    self.job_template_id = attributes[:'job_template_id']
  end

  if attributes.key?(:'review_due_date')
    self.review_due_date = attributes[:'review_due_date']
  end

  if attributes.key?(:'owner')
    self.owner = attributes[:'owner']
  end

  if attributes.key?(:'job_tag_name')
    self.job_tag_name = attributes[:'job_tag_name']
  end

  if attributes.key?(:'source_translations_updated_at')
    self.source_translations_updated_at = attributes[:'source_translations_updated_at']
  end

  if attributes.key?(:'source_locale')
    self.source_locale = attributes[:'source_locale']
  end

  if attributes.key?(:'locales')
    if (value = attributes[:'locales']).is_a?(Array)
      self.locales = value
    end
  end

  if attributes.key?(:'keys')
    if (value = attributes[:'keys']).is_a?(Array)
      self.keys = value
    end
  end

  if attributes.key?(:'annotations')
    if (value = attributes[:'annotations']).is_a?(Array)
      self.annotations = value
    end
  end

  if attributes.key?(:'locked')
    self.locked = attributes[:'locked']
  end
end

Instance Attribute Details

#annotationsObject

Returned only when ‘include_annotations=true` is supplied on the request.



47
48
49
# File 'lib/phrase/models/job_details.rb', line 47

def annotations
  @annotations
end

#automation_idObject

The ID of the automation that created this job, or null if the job was created manually.



26
27
28
# File 'lib/phrase/models/job_details.rb', line 26

def automation_id
  @automation_id
end

#branchObject

Returns the value of attribute branch.



19
20
21
# File 'lib/phrase/models/job_details.rb', line 19

def branch
  @branch
end

#briefingObject

Returns the value of attribute briefing.



9
10
11
# File 'lib/phrase/models/job_details.rb', line 9

def briefing
  @briefing
end

#created_atObject

Returns the value of attribute created_at.



21
22
23
# File 'lib/phrase/models/job_details.rb', line 21

def created_at
  @created_at
end

#due_dateObject

Returns the value of attribute due_date.



11
12
13
# File 'lib/phrase/models/job_details.rb', line 11

def due_date
  @due_date
end

#idObject

Returns the value of attribute id.



5
6
7
# File 'lib/phrase/models/job_details.rb', line 5

def id
  @id
end

#job_tag_nameObject

Returns the value of attribute job_tag_name.



36
37
38
# File 'lib/phrase/models/job_details.rb', line 36

def job_tag_name
  @job_tag_name
end

#job_template_idObject

The ID of the job template this job was created from, or null if no template was used.



29
30
31
# File 'lib/phrase/models/job_details.rb', line 29

def job_template_id
  @job_template_id
end

#keysObject

Returns the value of attribute keys.



44
45
46
# File 'lib/phrase/models/job_details.rb', line 44

def keys
  @keys
end

#localesObject

Returns the value of attribute locales.



42
43
44
# File 'lib/phrase/models/job_details.rb', line 42

def locales
  @locales
end

#lockedObject

‘true` if the job has been locked by the project’s job-locking workflow (translations attached to the job are read-only until the job advances).



50
51
52
# File 'lib/phrase/models/job_details.rb', line 50

def locked
  @locked
end

#nameObject

Returns the value of attribute name.



7
8
9
# File 'lib/phrase/models/job_details.rb', line 7

def name
  @name
end

#ownerObject

Returns the value of attribute owner.



34
35
36
# File 'lib/phrase/models/job_details.rb', line 34

def owner
  @owner
end

#projectObject

Returns the value of attribute project.



17
18
19
# File 'lib/phrase/models/job_details.rb', line 17

def project
  @project
end

#review_due_dateObject

The review due date for this job. Returns ‘null` when the project does not have review workflow enabled.



32
33
34
# File 'lib/phrase/models/job_details.rb', line 32

def review_due_date
  @review_due_date
end

#source_localeObject

Returns the value of attribute source_locale.



40
41
42
# File 'lib/phrase/models/job_details.rb', line 40

def source_locale
  @source_locale
end

#source_translations_updated_atObject

Returns the value of attribute source_translations_updated_at.



38
39
40
# File 'lib/phrase/models/job_details.rb', line 38

def source_translations_updated_at
  @source_translations_updated_at
end

#stateObject

Returns the value of attribute state.



13
14
15
# File 'lib/phrase/models/job_details.rb', line 13

def state
  @state
end

#ticket_urlObject

Returns the value of attribute ticket_url.



15
16
17
# File 'lib/phrase/models/job_details.rb', line 15

def ticket_url
  @ticket_url
end

#updated_atObject

Returns the value of attribute updated_at.



23
24
25
# File 'lib/phrase/models/job_details.rb', line 23

def updated_at
  @updated_at
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
# File 'lib/phrase/models/job_details.rb', line 53

def self.attribute_map
  {
    :'id' => :'id',
    :'name' => :'name',
    :'briefing' => :'briefing',
    :'due_date' => :'due_date',
    :'state' => :'state',
    :'ticket_url' => :'ticket_url',
    :'project' => :'project',
    :'branch' => :'branch',
    :'created_at' => :'created_at',
    :'updated_at' => :'updated_at',
    :'automation_id' => :'automation_id',
    :'job_template_id' => :'job_template_id',
    :'review_due_date' => :'review_due_date',
    :'owner' => :'owner',
    :'job_tag_name' => :'job_tag_name',
    :'source_translations_updated_at' => :'source_translations_updated_at',
    :'source_locale' => :'source_locale',
    :'locales' => :'locales',
    :'keys' => :'keys',
    :'annotations' => :'annotations',
    :'locked' => :'locked'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



285
286
287
# File 'lib/phrase/models/job_details.rb', line 285

def self.build_from_hash(attributes)
  new.build_from_hash(attributes)
end

.openapi_all_ofObject

List of class defined in allOf (OpenAPI v3)



117
118
119
120
121
# File 'lib/phrase/models/job_details.rb', line 117

def self.openapi_all_of
  [
  :'Job'
  ]
end

.openapi_nullableObject

List of attributes with nullable: true



107
108
109
110
111
112
113
114
# File 'lib/phrase/models/job_details.rb', line 107

def self.openapi_nullable
  Set.new([
    :'due_date',
    :'automation_id',
    :'job_template_id',
    :'review_due_date',
  ])
end

.openapi_typesObject

Attribute type mapping.



80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
# File 'lib/phrase/models/job_details.rb', line 80

def self.openapi_types
  {
    :'id' => :'String',
    :'name' => :'String',
    :'briefing' => :'String',
    :'due_date' => :'DateTime',
    :'state' => :'String',
    :'ticket_url' => :'String',
    :'project' => :'ProjectShort',
    :'branch' => :'BranchName',
    :'created_at' => :'DateTime',
    :'updated_at' => :'DateTime',
    :'automation_id' => :'String',
    :'job_template_id' => :'String',
    :'review_due_date' => :'DateTime',
    :'owner' => :'UserPreview',
    :'job_tag_name' => :'String',
    :'source_translations_updated_at' => :'DateTime',
    :'source_locale' => :'LocalePreview',
    :'locales' => :'Array<LocalePreview>',
    :'keys' => :'Array<KeyPreview>',
    :'annotations' => :'Array<JobAnnotationShort>',
    :'locked' => :'Boolean'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
# File 'lib/phrase/models/job_details.rb', line 244

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      id == o.id &&
      name == o.name &&
      briefing == o.briefing &&
      due_date == o.due_date &&
      state == o.state &&
      ticket_url == o.ticket_url &&
      project == o.project &&
      branch == o.branch &&
      created_at == o.created_at &&
      updated_at == o.updated_at &&
      automation_id == o.automation_id &&
      job_template_id == o.job_template_id &&
      review_due_date == o.review_due_date &&
      owner == o.owner &&
      job_tag_name == o.job_tag_name &&
      source_translations_updated_at == o.source_translations_updated_at &&
      source_locale == o.source_locale &&
      locales == o.locales &&
      keys == o.keys &&
      annotations == o.annotations &&
      locked == o.locked
end

#_deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
342
343
344
345
346
347
348
349
350
# File 'lib/phrase/models/job_details.rb', line 313

def _deserialize(type, value)
  case type.to_sym
  when :DateTime
    DateTime.parse(value)
  when :Date
    Date.parse(value)
  when :Time
    Time.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    Phrase.const_get(type).build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



384
385
386
387
388
389
390
391
392
393
394
395
396
# File 'lib/phrase/models/job_details.rb', line 384

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
# File 'lib/phrase/models/job_details.rb', line 292

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  self.class.openapi_types.each_pair do |key, type|
    if type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) })
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]]))
    end # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


272
273
274
# File 'lib/phrase/models/job_details.rb', line 272

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



278
279
280
# File 'lib/phrase/models/job_details.rb', line 278

def hash
  [id, name, briefing, due_date, state, ticket_url, project, branch, created_at, updated_at, automation_id, job_template_id, review_due_date, owner, job_tag_name, source_translations_updated_at, source_locale, locales, keys, annotations, locked].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



231
232
233
234
# File 'lib/phrase/models/job_details.rb', line 231

def list_invalid_properties
  invalid_properties = Array.new
  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



360
361
362
# File 'lib/phrase/models/job_details.rb', line 360

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



366
367
368
369
370
371
372
373
374
375
376
377
378
# File 'lib/phrase/models/job_details.rb', line 366

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



354
355
356
# File 'lib/phrase/models/job_details.rb', line 354

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



238
239
240
# File 'lib/phrase/models/job_details.rb', line 238

def valid?
  true
end