Class: Phrase::KeyUpdateParameters
- Inherits:
-
Object
- Object
- Phrase::KeyUpdateParameters
- Defined in:
- lib/phrase/models/key_update_parameters.rb
Instance Attribute Summary collapse
-
#branch ⇒ Object
specify the branch to use.
-
#custom_metadata ⇒ Object
Updates/Creates custom metadata property name and value pairs to be associated with key.
-
#data_type ⇒ Object
Type of the key.
-
#description ⇒ Object
Key description (usually includes contextual information for translators).
-
#excluded_in_locales ⇒ Object
Locales for which translations of this key are excluded from exports.
-
#format_value_type ⇒ Object
Override of the value type for the key in the export.
-
#localized_format_key ⇒ Object
NSStringLocalizedFormatKey attribute.
-
#localized_format_string ⇒ Object
NSStringLocalizedFormatKey attribute.
-
#max_characters_allowed ⇒ Object
Max.
-
#name ⇒ Object
Key name.
-
#name_plural ⇒ Object
Plural name for the key (used in some file formats, e.g. Gettext).
-
#original_file ⇒ Object
Original file attribute.
-
#plural ⇒ Object
Indicates whether key supports pluralization.
-
#remove_screenshot ⇒ Object
Indicates whether the screenshot will be deleted.
-
#screenshot ⇒ Object
Screenshot/image for the key.
-
#tags ⇒ Object
List of tags separated by comma to be associated with the key.
-
#unformatted ⇒ Object
Indicates whether the key should be exported as "unformatted".
-
#use_ordinal_rules ⇒ Object
Indicates whether key uses ordinal rules for pluralization.
-
#xml_space_preserve ⇒ Object
Indicates whether the key should be exported with "xml:space=preserve".
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ KeyUpdateParameters
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ KeyUpdateParameters
Initializes the object
120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 |
# File 'lib/phrase/models/key_update_parameters.rb', line 120 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Phrase::KeyUpdateParameters` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| if (!self.class.attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Phrase::KeyUpdateParameters`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'branch') self.branch = attributes[:'branch'] end if attributes.key?(:'name') self.name = attributes[:'name'] end if attributes.key?(:'description') self.description = attributes[:'description'] end if attributes.key?(:'plural') self.plural = attributes[:'plural'] end if attributes.key?(:'use_ordinal_rules') self.use_ordinal_rules = attributes[:'use_ordinal_rules'] end if attributes.key?(:'name_plural') self.name_plural = attributes[:'name_plural'] end if attributes.key?(:'data_type') self.data_type = attributes[:'data_type'] end if attributes.key?(:'tags') self. = attributes[:'tags'] end if attributes.key?(:'max_characters_allowed') self.max_characters_allowed = attributes[:'max_characters_allowed'] end if attributes.key?(:'screenshot') self.screenshot = attributes[:'screenshot'] end if attributes.key?(:'remove_screenshot') self.remove_screenshot = attributes[:'remove_screenshot'] end if attributes.key?(:'unformatted') self.unformatted = attributes[:'unformatted'] end if attributes.key?(:'xml_space_preserve') self.xml_space_preserve = attributes[:'xml_space_preserve'] end if attributes.key?(:'original_file') self.original_file = attributes[:'original_file'] end if attributes.key?(:'localized_format_string') self.localized_format_string = attributes[:'localized_format_string'] end if attributes.key?(:'localized_format_key') self.localized_format_key = attributes[:'localized_format_key'] end if attributes.key?(:'custom_metadata') self. = attributes[:'custom_metadata'] end if attributes.key?(:'excluded_in_locales') if (value = attributes[:'excluded_in_locales']).is_a?(Array) self.excluded_in_locales = value end end if attributes.key?(:'format_value_type') self.format_value_type = attributes[:'format_value_type'] end end |
Instance Attribute Details
#branch ⇒ Object
specify the branch to use
6 7 8 |
# File 'lib/phrase/models/key_update_parameters.rb', line 6 def branch @branch end |
#custom_metadata ⇒ Object
Updates/Creates custom metadata property name and value pairs to be associated with key. If you want to delete a custom metadata property, you can set its value to null. If you want to update a custom metadata property, you can set its value to the new value.
54 55 56 |
# File 'lib/phrase/models/key_update_parameters.rb', line 54 def @custom_metadata end |
#data_type ⇒ Object
Type of the key. Can be one of the following: string, number, boolean, array, markdown.
24 25 26 |
# File 'lib/phrase/models/key_update_parameters.rb', line 24 def data_type @data_type end |
#description ⇒ Object
Key description (usually includes contextual information for translators)
12 13 14 |
# File 'lib/phrase/models/key_update_parameters.rb', line 12 def description @description end |
#excluded_in_locales ⇒ Object
Locales for which translations of this key are excluded from exports. Pass an empty array to clear exclusions.
57 58 59 |
# File 'lib/phrase/models/key_update_parameters.rb', line 57 def excluded_in_locales @excluded_in_locales end |
#format_value_type ⇒ Object
Override of the value type for the key in the export. Most useful for formats like Android XML that distinguish string vs. plural resources.
60 61 62 |
# File 'lib/phrase/models/key_update_parameters.rb', line 60 def format_value_type @format_value_type end |
#localized_format_key ⇒ Object
NSStringLocalizedFormatKey attribute. Used in .stringsdict format.
51 52 53 |
# File 'lib/phrase/models/key_update_parameters.rb', line 51 def localized_format_key @localized_format_key end |
#localized_format_string ⇒ Object
NSStringLocalizedFormatKey attribute. Used in .stringsdict format.
48 49 50 |
# File 'lib/phrase/models/key_update_parameters.rb', line 48 def localized_format_string @localized_format_string end |
#max_characters_allowed ⇒ Object
Max. number of characters translations for this key can have.
30 31 32 |
# File 'lib/phrase/models/key_update_parameters.rb', line 30 def max_characters_allowed @max_characters_allowed end |
#name ⇒ Object
Key name
9 10 11 |
# File 'lib/phrase/models/key_update_parameters.rb', line 9 def name @name end |
#name_plural ⇒ Object
Plural name for the key (used in some file formats, e.g. Gettext)
21 22 23 |
# File 'lib/phrase/models/key_update_parameters.rb', line 21 def name_plural @name_plural end |
#original_file ⇒ Object
Original file attribute. Used in some formats, e.g. XLIFF.
45 46 47 |
# File 'lib/phrase/models/key_update_parameters.rb', line 45 def original_file @original_file end |
#plural ⇒ Object
Indicates whether key supports pluralization
15 16 17 |
# File 'lib/phrase/models/key_update_parameters.rb', line 15 def plural @plural end |
#remove_screenshot ⇒ Object
Indicates whether the screenshot will be deleted. This parameter is deprecated. Please use the Screenshots endpoint instead.
36 37 38 |
# File 'lib/phrase/models/key_update_parameters.rb', line 36 def remove_screenshot @remove_screenshot end |
#screenshot ⇒ Object
Screenshot/image for the key. This parameter is deprecated. Please use the Screenshots endpoint instead.
33 34 35 |
# File 'lib/phrase/models/key_update_parameters.rb', line 33 def screenshot @screenshot end |
#tags ⇒ Object
List of tags separated by comma to be associated with the key.
27 28 29 |
# File 'lib/phrase/models/key_update_parameters.rb', line 27 def @tags end |
#unformatted ⇒ Object
Indicates whether the key should be exported as "unformatted". Supported by Android XML and other formats.
39 40 41 |
# File 'lib/phrase/models/key_update_parameters.rb', line 39 def unformatted @unformatted end |
#use_ordinal_rules ⇒ Object
Indicates whether key uses ordinal rules for pluralization
18 19 20 |
# File 'lib/phrase/models/key_update_parameters.rb', line 18 def use_ordinal_rules @use_ordinal_rules end |
#xml_space_preserve ⇒ Object
Indicates whether the key should be exported with "xml:space=preserve". Supported by several XML-based formats.
42 43 44 |
# File 'lib/phrase/models/key_update_parameters.rb', line 42 def xml_space_preserve @xml_space_preserve end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 |
# File 'lib/phrase/models/key_update_parameters.rb', line 63 def self.attribute_map { :'branch' => :'branch', :'name' => :'name', :'description' => :'description', :'plural' => :'plural', :'use_ordinal_rules' => :'use_ordinal_rules', :'name_plural' => :'name_plural', :'data_type' => :'data_type', :'tags' => :'tags', :'max_characters_allowed' => :'max_characters_allowed', :'screenshot' => :'screenshot', :'remove_screenshot' => :'remove_screenshot', :'unformatted' => :'unformatted', :'xml_space_preserve' => :'xml_space_preserve', :'original_file' => :'original_file', :'localized_format_string' => :'localized_format_string', :'localized_format_key' => :'localized_format_key', :'custom_metadata' => :'custom_metadata', :'excluded_in_locales' => :'excluded_in_locales', :'format_value_type' => :'format_value_type' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
266 267 268 |
# File 'lib/phrase/models/key_update_parameters.rb', line 266 def self.build_from_hash(attributes) new.build_from_hash(attributes) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
113 114 115 116 |
# File 'lib/phrase/models/key_update_parameters.rb', line 113 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 |
# File 'lib/phrase/models/key_update_parameters.rb', line 88 def self.openapi_types { :'branch' => :'String', :'name' => :'String', :'description' => :'String', :'plural' => :'Boolean', :'use_ordinal_rules' => :'Boolean', :'name_plural' => :'String', :'data_type' => :'String', :'tags' => :'String', :'max_characters_allowed' => :'Integer', :'screenshot' => :'File', :'remove_screenshot' => :'Boolean', :'unformatted' => :'Boolean', :'xml_space_preserve' => :'Boolean', :'original_file' => :'String', :'localized_format_string' => :'String', :'localized_format_key' => :'String', :'custom_metadata' => :'Object', :'excluded_in_locales' => :'Array<String>', :'format_value_type' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 |
# File 'lib/phrase/models/key_update_parameters.rb', line 227 def ==(o) return true if self.equal?(o) self.class == o.class && branch == o.branch && name == o.name && description == o.description && plural == o.plural && use_ordinal_rules == o.use_ordinal_rules && name_plural == o.name_plural && data_type == o.data_type && == o. && max_characters_allowed == o.max_characters_allowed && screenshot == o.screenshot && remove_screenshot == o.remove_screenshot && unformatted == o.unformatted && xml_space_preserve == o.xml_space_preserve && original_file == o.original_file && localized_format_string == o.localized_format_string && localized_format_key == o.localized_format_key && == o. && excluded_in_locales == o.excluded_in_locales && format_value_type == o.format_value_type end |
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type
294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 |
# File 'lib/phrase/models/key_update_parameters.rb', line 294 def _deserialize(type, value) case type.to_sym when :DateTime DateTime.parse(value) when :Date Date.parse(value) when :Time Time.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model Phrase.const_get(type).build_from_hash(value) end end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
365 366 367 368 369 370 371 372 373 374 375 376 377 |
# File 'lib/phrase/models/key_update_parameters.rb', line 365 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 |
# File 'lib/phrase/models/key_update_parameters.rb', line 273 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.openapi_types.each_pair do |key, type| if type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) }) end elsif !attributes[self.class.attribute_map[key]].nil? self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]])) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(o) ⇒ Boolean
253 254 255 |
# File 'lib/phrase/models/key_update_parameters.rb', line 253 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
259 260 261 |
# File 'lib/phrase/models/key_update_parameters.rb', line 259 def hash [branch, name, description, plural, use_ordinal_rules, name_plural, data_type, , max_characters_allowed, screenshot, remove_screenshot, unformatted, xml_space_preserve, original_file, localized_format_string, localized_format_key, , excluded_in_locales, format_value_type].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
214 215 216 217 |
# File 'lib/phrase/models/key_update_parameters.rb', line 214 def list_invalid_properties invalid_properties = Array.new invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
341 342 343 |
# File 'lib/phrase/models/key_update_parameters.rb', line 341 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
347 348 349 350 351 352 353 354 355 356 357 358 359 |
# File 'lib/phrase/models/key_update_parameters.rb', line 347 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
335 336 337 |
# File 'lib/phrase/models/key_update_parameters.rb', line 335 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
221 222 223 |
# File 'lib/phrase/models/key_update_parameters.rb', line 221 def valid? true end |