Class: Phrase::LocaleCreateParameters

Inherits:
Object
  • Object
show all
Defined in:
lib/phrase/models/locale_create_parameters.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ LocaleCreateParameters

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
# File 'lib/phrase/models/locale_create_parameters.rb', line 90

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Phrase::LocaleCreateParameters` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Phrase::LocaleCreateParameters`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'branch')
    self.branch = attributes[:'branch']
  end

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  end

  if attributes.key?(:'code')
    self.code = attributes[:'code']
  end

  if attributes.key?(:'default')
    self.default = attributes[:'default']
  end

  if attributes.key?(:'main')
    self.main = attributes[:'main']
  end

  if attributes.key?(:'rtl')
    self.rtl = attributes[:'rtl']
  end

  if attributes.key?(:'source_locale_id')
    self.source_locale_id = attributes[:'source_locale_id']
  end

  if attributes.key?(:'fallback_locale_id')
    self.fallback_locale_id = attributes[:'fallback_locale_id']
  end

  if attributes.key?(:'unverify_new_translations')
    self.unverify_new_translations = attributes[:'unverify_new_translations']
  end

  if attributes.key?(:'unverify_updated_translations')
    self.unverify_updated_translations = attributes[:'unverify_updated_translations']
  end

  if attributes.key?(:'unverify_on_source_changes')
    self.unverify_on_source_changes = attributes[:'unverify_on_source_changes']
  end

  if attributes.key?(:'autotranslate')
    self.autotranslate = attributes[:'autotranslate']
  end

  if attributes.key?(:'language_ai_profile')
    self.language_ai_profile = attributes[:'language_ai_profile']
  end
end

Instance Attribute Details

#autotranslateObject

If set, translations for this locale will be fetched automatically, right after creation.



39
40
41
# File 'lib/phrase/models/locale_create_parameters.rb', line 39

def autotranslate
  @autotranslate
end

#branchObject

specify the branch to use



6
7
8
# File 'lib/phrase/models/locale_create_parameters.rb', line 6

def branch
  @branch
end

#codeObject

Locale ISO code



12
13
14
# File 'lib/phrase/models/locale_create_parameters.rb', line 12

def code
  @code
end

#defaultObject

Indicates whether locale is the default locale. If set to true, the previous default locale the project is no longer the default locale.



15
16
17
# File 'lib/phrase/models/locale_create_parameters.rb', line 15

def default
  @default
end

#fallback_locale_idObject

Fallback locale for empty translations. Can be a locale name or id.



27
28
29
# File 'lib/phrase/models/locale_create_parameters.rb', line 27

def fallback_locale_id
  @fallback_locale_id
end

#language_ai_profileObject

Identifier of the Language AI profile to use for this locale.



42
43
44
# File 'lib/phrase/models/locale_create_parameters.rb', line 42

def language_ai_profile
  @language_ai_profile
end

#mainObject

Indicates whether locale is a main locale. Main locales are part of the Verification System feature.



18
19
20
# File 'lib/phrase/models/locale_create_parameters.rb', line 18

def main
  @main
end

#nameObject

Locale name



9
10
11
# File 'lib/phrase/models/locale_create_parameters.rb', line 9

def name
  @name
end

#rtlObject

Indicates whether locale is a RTL (Right-to-Left) locale.



21
22
23
# File 'lib/phrase/models/locale_create_parameters.rb', line 21

def rtl
  @rtl
end

#source_locale_idObject

Source locale. Can be the name or id of the locale. Preferred is id.



24
25
26
# File 'lib/phrase/models/locale_create_parameters.rb', line 24

def source_locale_id
  @source_locale_id
end

#unverify_new_translationsObject

Indicates that new translations for this locale should be marked as unverified. Part of the Advanced Workflows feature.



30
31
32
# File 'lib/phrase/models/locale_create_parameters.rb', line 30

def unverify_new_translations
  @unverify_new_translations
end

#unverify_on_source_changesObject

Indicates that translations for this locale should be marked as unverified when the source language has been changed.



36
37
38
# File 'lib/phrase/models/locale_create_parameters.rb', line 36

def unverify_on_source_changes
  @unverify_on_source_changes
end

#unverify_updated_translationsObject

Indicates that updated translations for this locale should be marked as unverified. Part of the Advanced Workflows feature.



33
34
35
# File 'lib/phrase/models/locale_create_parameters.rb', line 33

def unverify_updated_translations
  @unverify_updated_translations
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
# File 'lib/phrase/models/locale_create_parameters.rb', line 45

def self.attribute_map
  {
    :'branch' => :'branch',
    :'name' => :'name',
    :'code' => :'code',
    :'default' => :'default',
    :'main' => :'main',
    :'rtl' => :'rtl',
    :'source_locale_id' => :'source_locale_id',
    :'fallback_locale_id' => :'fallback_locale_id',
    :'unverify_new_translations' => :'unverify_new_translations',
    :'unverify_updated_translations' => :'unverify_updated_translations',
    :'unverify_on_source_changes' => :'unverify_on_source_changes',
    :'autotranslate' => :'autotranslate',
    :'language_ai_profile' => :'language_ai_profile'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



214
215
216
# File 'lib/phrase/models/locale_create_parameters.rb', line 214

def self.build_from_hash(attributes)
  new.build_from_hash(attributes)
end

.openapi_nullableObject

List of attributes with nullable: true



83
84
85
86
# File 'lib/phrase/models/locale_create_parameters.rb', line 83

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
# File 'lib/phrase/models/locale_create_parameters.rb', line 64

def self.openapi_types
  {
    :'branch' => :'String',
    :'name' => :'String',
    :'code' => :'String',
    :'default' => :'Boolean',
    :'main' => :'Boolean',
    :'rtl' => :'Boolean',
    :'source_locale_id' => :'String',
    :'fallback_locale_id' => :'String',
    :'unverify_new_translations' => :'Boolean',
    :'unverify_updated_translations' => :'Boolean',
    :'unverify_on_source_changes' => :'Boolean',
    :'autotranslate' => :'Boolean',
    :'language_ai_profile' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
# File 'lib/phrase/models/locale_create_parameters.rb', line 181

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      branch == o.branch &&
      name == o.name &&
      code == o.code &&
      default == o.default &&
      main == o.main &&
      rtl == o.rtl &&
      source_locale_id == o.source_locale_id &&
      fallback_locale_id == o.fallback_locale_id &&
      unverify_new_translations == o.unverify_new_translations &&
      unverify_updated_translations == o.unverify_updated_translations &&
      unverify_on_source_changes == o.unverify_on_source_changes &&
      autotranslate == o.autotranslate &&
      language_ai_profile == o.language_ai_profile
end

#_deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
# File 'lib/phrase/models/locale_create_parameters.rb', line 242

def _deserialize(type, value)
  case type.to_sym
  when :DateTime
    DateTime.parse(value)
  when :Date
    Date.parse(value)
  when :Time
    Time.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    Phrase.const_get(type).build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



313
314
315
316
317
318
319
320
321
322
323
324
325
# File 'lib/phrase/models/locale_create_parameters.rb', line 313

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
# File 'lib/phrase/models/locale_create_parameters.rb', line 221

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  self.class.openapi_types.each_pair do |key, type|
    if type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) })
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]]))
    end # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


201
202
203
# File 'lib/phrase/models/locale_create_parameters.rb', line 201

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



207
208
209
# File 'lib/phrase/models/locale_create_parameters.rb', line 207

def hash
  [branch, name, code, default, main, rtl, source_locale_id, fallback_locale_id, unverify_new_translations, unverify_updated_translations, unverify_on_source_changes, autotranslate, language_ai_profile].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



158
159
160
161
162
163
164
165
166
167
168
169
# File 'lib/phrase/models/locale_create_parameters.rb', line 158

def list_invalid_properties
  invalid_properties = Array.new
  if @name.nil?
    invalid_properties.push('invalid value for "name", name cannot be nil.')
  end

  if @code.nil?
    invalid_properties.push('invalid value for "code", code cannot be nil.')
  end

  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



289
290
291
# File 'lib/phrase/models/locale_create_parameters.rb', line 289

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



295
296
297
298
299
300
301
302
303
304
305
306
307
# File 'lib/phrase/models/locale_create_parameters.rb', line 295

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



283
284
285
# File 'lib/phrase/models/locale_create_parameters.rb', line 283

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



173
174
175
176
177
# File 'lib/phrase/models/locale_create_parameters.rb', line 173

def valid?
  return false if @name.nil?
  return false if @code.nil?
  true
end