Class: Phrase::LocaleDetails

Inherits:
Object
  • Object
show all
Defined in:
lib/phrase/models/locale_details.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ LocaleDetails

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
# File 'lib/phrase/models/locale_details.rb', line 103

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Phrase::LocaleDetails` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Phrase::LocaleDetails`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'id')
    self.id = attributes[:'id']
  end

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  end

  if attributes.key?(:'code')
    self.code = attributes[:'code']
  end

  if attributes.key?(:'default')
    self.default = attributes[:'default']
  end

  if attributes.key?(:'main')
    self.main = attributes[:'main']
  end

  if attributes.key?(:'rtl')
    self.rtl = attributes[:'rtl']
  end

  if attributes.key?(:'plural_forms')
    if (value = attributes[:'plural_forms']).is_a?(Array)
      self.plural_forms = value
    end
  end

  if attributes.key?(:'ordinal_plural_forms')
    if (value = attributes[:'ordinal_plural_forms']).is_a?(Array)
      self.ordinal_plural_forms = value
    end
  end

  if attributes.key?(:'source_locale')
    self.source_locale = attributes[:'source_locale']
  end

  if attributes.key?(:'fallback_locale')
    self.fallback_locale = attributes[:'fallback_locale']
  end

  if attributes.key?(:'language_ai_profile')
    self.language_ai_profile = attributes[:'language_ai_profile']
  end

  if attributes.key?(:'unverify_new_translations')
    self.unverify_new_translations = attributes[:'unverify_new_translations']
  end

  if attributes.key?(:'unverify_updated_translations')
    self.unverify_updated_translations = attributes[:'unverify_updated_translations']
  end

  if attributes.key?(:'unverify_on_source_changes')
    self.unverify_on_source_changes = attributes[:'unverify_on_source_changes']
  end

  if attributes.key?(:'created_at')
    self.created_at = attributes[:'created_at']
  end

  if attributes.key?(:'updated_at')
    self.updated_at = attributes[:'updated_at']
  end

  if attributes.key?(:'statistics')
    self.statistics = attributes[:'statistics']
  end
end

Instance Attribute Details

#codeObject

Returns the value of attribute code.



9
10
11
# File 'lib/phrase/models/locale_details.rb', line 9

def code
  @code
end

#created_atObject

Returns the value of attribute created_at.



36
37
38
# File 'lib/phrase/models/locale_details.rb', line 36

def created_at
  @created_at
end

#defaultObject

Returns the value of attribute default.



11
12
13
# File 'lib/phrase/models/locale_details.rb', line 11

def default
  @default
end

#fallback_localeObject

Returns the value of attribute fallback_locale.



23
24
25
# File 'lib/phrase/models/locale_details.rb', line 23

def fallback_locale
  @fallback_locale
end

#idObject

Returns the value of attribute id.



5
6
7
# File 'lib/phrase/models/locale_details.rb', line 5

def id
  @id
end

#language_ai_profileObject

Returns the value of attribute language_ai_profile.



25
26
27
# File 'lib/phrase/models/locale_details.rb', line 25

def language_ai_profile
  @language_ai_profile
end

#mainObject

Returns the value of attribute main.



13
14
15
# File 'lib/phrase/models/locale_details.rb', line 13

def main
  @main
end

#nameObject

Returns the value of attribute name.



7
8
9
# File 'lib/phrase/models/locale_details.rb', line 7

def name
  @name
end

#ordinal_plural_formsObject

Returns the value of attribute ordinal_plural_forms.



19
20
21
# File 'lib/phrase/models/locale_details.rb', line 19

def ordinal_plural_forms
  @ordinal_plural_forms
end

#plural_formsObject

Returns the value of attribute plural_forms.



17
18
19
# File 'lib/phrase/models/locale_details.rb', line 17

def plural_forms
  @plural_forms
end

#rtlObject

Returns the value of attribute rtl.



15
16
17
# File 'lib/phrase/models/locale_details.rb', line 15

def rtl
  @rtl
end

#source_localeObject

Returns the value of attribute source_locale.



21
22
23
# File 'lib/phrase/models/locale_details.rb', line 21

def source_locale
  @source_locale
end

#statisticsObject

Returns the value of attribute statistics.



40
41
42
# File 'lib/phrase/models/locale_details.rb', line 40

def statistics
  @statistics
end

#unverify_new_translationsObject

Indicates that new translations for this locale are marked as unverified. Only applies to locales using the basic verification workflow. Part of the Advanced Workflows feature.



28
29
30
# File 'lib/phrase/models/locale_details.rb', line 28

def unverify_new_translations
  @unverify_new_translations
end

#unverify_on_source_changesObject

Indicates that translations for this locale are marked as unverified when the source language has been changed.



34
35
36
# File 'lib/phrase/models/locale_details.rb', line 34

def unverify_on_source_changes
  @unverify_on_source_changes
end

#unverify_updated_translationsObject

Indicates that updated translations for this locale are marked as unverified. Only applies to locales using the basic verification workflow. Part of the Advanced Workflows feature.



31
32
33
# File 'lib/phrase/models/locale_details.rb', line 31

def unverify_updated_translations
  @unverify_updated_translations
end

#updated_atObject

Returns the value of attribute updated_at.



38
39
40
# File 'lib/phrase/models/locale_details.rb', line 38

def updated_at
  @updated_at
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
# File 'lib/phrase/models/locale_details.rb', line 43

def self.attribute_map
  {
    :'id' => :'id',
    :'name' => :'name',
    :'code' => :'code',
    :'default' => :'default',
    :'main' => :'main',
    :'rtl' => :'rtl',
    :'plural_forms' => :'plural_forms',
    :'ordinal_plural_forms' => :'ordinal_plural_forms',
    :'source_locale' => :'source_locale',
    :'fallback_locale' => :'fallback_locale',
    :'language_ai_profile' => :'language_ai_profile',
    :'unverify_new_translations' => :'unverify_new_translations',
    :'unverify_updated_translations' => :'unverify_updated_translations',
    :'unverify_on_source_changes' => :'unverify_on_source_changes',
    :'created_at' => :'created_at',
    :'updated_at' => :'updated_at',
    :'statistics' => :'statistics'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



241
242
243
# File 'lib/phrase/models/locale_details.rb', line 241

def self.build_from_hash(attributes)
  new.build_from_hash(attributes)
end

.openapi_all_ofObject

List of class defined in allOf (OpenAPI v3)



95
96
97
98
99
# File 'lib/phrase/models/locale_details.rb', line 95

def self.openapi_all_of
  [
  :'Locale'
  ]
end

.openapi_nullableObject

List of attributes with nullable: true



89
90
91
92
# File 'lib/phrase/models/locale_details.rb', line 89

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
# File 'lib/phrase/models/locale_details.rb', line 66

def self.openapi_types
  {
    :'id' => :'String',
    :'name' => :'String',
    :'code' => :'String',
    :'default' => :'Boolean',
    :'main' => :'Boolean',
    :'rtl' => :'Boolean',
    :'plural_forms' => :'Array<String>',
    :'ordinal_plural_forms' => :'Array<String>',
    :'source_locale' => :'LocalePreview',
    :'fallback_locale' => :'LocalePreview',
    :'language_ai_profile' => :'String',
    :'unverify_new_translations' => :'Boolean',
    :'unverify_updated_translations' => :'Boolean',
    :'unverify_on_source_changes' => :'Boolean',
    :'created_at' => :'DateTime',
    :'updated_at' => :'DateTime',
    :'statistics' => :'LocaleStatistics'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
# File 'lib/phrase/models/locale_details.rb', line 204

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      id == o.id &&
      name == o.name &&
      code == o.code &&
      default == o.default &&
      main == o.main &&
      rtl == o.rtl &&
      plural_forms == o.plural_forms &&
      ordinal_plural_forms == o.ordinal_plural_forms &&
      source_locale == o.source_locale &&
      fallback_locale == o.fallback_locale &&
      language_ai_profile == o.language_ai_profile &&
      unverify_new_translations == o.unverify_new_translations &&
      unverify_updated_translations == o.unverify_updated_translations &&
      unverify_on_source_changes == o.unverify_on_source_changes &&
      created_at == o.created_at &&
      updated_at == o.updated_at &&
      statistics == o.statistics
end

#_deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
# File 'lib/phrase/models/locale_details.rb', line 269

def _deserialize(type, value)
  case type.to_sym
  when :DateTime
    DateTime.parse(value)
  when :Date
    Date.parse(value)
  when :Time
    Time.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    Phrase.const_get(type).build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



340
341
342
343
344
345
346
347
348
349
350
351
352
# File 'lib/phrase/models/locale_details.rb', line 340

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
# File 'lib/phrase/models/locale_details.rb', line 248

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  self.class.openapi_types.each_pair do |key, type|
    if type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) })
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]]))
    end # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


228
229
230
# File 'lib/phrase/models/locale_details.rb', line 228

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



234
235
236
# File 'lib/phrase/models/locale_details.rb', line 234

def hash
  [id, name, code, default, main, rtl, plural_forms, ordinal_plural_forms, source_locale, fallback_locale, language_ai_profile, unverify_new_translations, unverify_updated_translations, unverify_on_source_changes, created_at, updated_at, statistics].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



191
192
193
194
# File 'lib/phrase/models/locale_details.rb', line 191

def list_invalid_properties
  invalid_properties = Array.new
  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



316
317
318
# File 'lib/phrase/models/locale_details.rb', line 316

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



322
323
324
325
326
327
328
329
330
331
332
333
334
# File 'lib/phrase/models/locale_details.rb', line 322

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



310
311
312
# File 'lib/phrase/models/locale_details.rb', line 310

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



198
199
200
# File 'lib/phrase/models/locale_details.rb', line 198

def valid?
  true
end