Class: Phrase::OrganizationJobTemplatesApi

Inherits:
Object
  • Object
show all
Defined in:
lib/phrase/api/organization_job_templates_api.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(api_client = ApiClient.default) ⇒ OrganizationJobTemplatesApi

Returns a new instance of OrganizationJobTemplatesApi.



7
8
9
# File 'lib/phrase/api/organization_job_templates_api.rb', line 7

def initialize(api_client = ApiClient.default)
  @api_client = api_client
end

Instance Attribute Details

#api_clientObject

Returns the value of attribute api_client.



5
6
7
# File 'lib/phrase/api/organization_job_templates_api.rb', line 5

def api_client
  @api_client
end

Instance Method Details

#organization_job_template_create(account_id, organization_job_template_create_parameters, opts = {}) ⇒ OrganizationJobTemplateDetails

Create an organization job template Create a new organization job template.

Parameters:

Options Hash (opts):

  • :x_phrase_app_otp (String)

    Two-Factor-Authentication token (optional)

Returns:



17
18
19
20
# File 'lib/phrase/api/organization_job_templates_api.rb', line 17

def organization_job_template_create(, organization_job_template_create_parameters, opts = {})
  data, _status_code, _headers = organization_job_template_create_with_http_info(, organization_job_template_create_parameters, opts)
  data
end

#organization_job_template_create_with_http_info(account_id, organization_job_template_create_parameters, opts = {}) ⇒ Array<(Response<(OrganizationJobTemplateDetails)>, Integer, Hash)>

Create an organization job template Create a new organization job template.

Parameters:

Options Hash (opts):

  • :x_phrase_app_otp (String)

    Two-Factor-Authentication token (optional)

Returns:



29
30
31
32
33
34
35
36
37
38
39
40
41
42
43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
# File 'lib/phrase/api/organization_job_templates_api.rb', line 29

def organization_job_template_create_with_http_info(, organization_job_template_create_parameters, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: OrganizationJobTemplatesApi.organization_job_template_create ...'
  end
  # verify the required parameter 'account_id' is set
  if @api_client.config.client_side_validation && .nil?
    fail ArgumentError, "Missing the required parameter 'account_id' when calling OrganizationJobTemplatesApi.organization_job_template_create"
  end
  # verify the required parameter 'organization_job_template_create_parameters' is set
  if @api_client.config.client_side_validation && organization_job_template_create_parameters.nil?
    fail ArgumentError, "Missing the required parameter 'organization_job_template_create_parameters' when calling OrganizationJobTemplatesApi.organization_job_template_create"
  end
  # resource path
  local_var_path = '/accounts/{account_id}/job_templates'.sub('{' + 'account_id' + '}', CGI.escape(.to_s))

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json'])
  # HTTP header 'Content-Type'
  header_params['Content-Type'] = @api_client.select_header_content_type(['application/json'])
  header_params[:'X-PhraseApp-OTP'] = opts[:'x_phrase_app_otp'] if !opts[:'x_phrase_app_otp'].nil?

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:body] || @api_client.object_to_http_body(organization_job_template_create_parameters) 

  # return_type
  return_type = opts[:return_type] || 'OrganizationJobTemplateDetails' 

  # auth_names
  auth_names = opts[:auth_names] || ['Basic', 'Token']

  new_options = opts.merge(
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:POST, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: OrganizationJobTemplatesApi#organization_job_template_create\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  response = ::Phrase::Response.new(data, headers)
  return response, status_code, headers
end

#organization_job_template_delete(account_id, id, opts = {}) ⇒ nil

Delete an organization job template Delete an existing organization job template.

Parameters:

  • account_id (String)

    Account ID

  • id (String)

    ID

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :x_phrase_app_otp (String)

    Two-Factor-Authentication token (optional)

Returns:

  • (nil)


91
92
93
94
# File 'lib/phrase/api/organization_job_templates_api.rb', line 91

def organization_job_template_delete(, id, opts = {})
  data, _status_code, _headers = organization_job_template_delete_with_http_info(, id, opts)
  data
end

#organization_job_template_delete_with_http_info(account_id, id, opts = {}) ⇒ Array<(Response, Integer, Hash)>

Delete an organization job template Delete an existing organization job template.

Parameters:

  • account_id (String)

    Account ID

  • id (String)

    ID

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :x_phrase_app_otp (String)

    Two-Factor-Authentication token (optional)

Returns:

  • (Array<(Response, Integer, Hash)>)

    Response<(nil, response status code and response headers



103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
# File 'lib/phrase/api/organization_job_templates_api.rb', line 103

def organization_job_template_delete_with_http_info(, id, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: OrganizationJobTemplatesApi.organization_job_template_delete ...'
  end
  # verify the required parameter 'account_id' is set
  if @api_client.config.client_side_validation && .nil?
    fail ArgumentError, "Missing the required parameter 'account_id' when calling OrganizationJobTemplatesApi.organization_job_template_delete"
  end
  # verify the required parameter 'id' is set
  if @api_client.config.client_side_validation && id.nil?
    fail ArgumentError, "Missing the required parameter 'id' when calling OrganizationJobTemplatesApi.organization_job_template_delete"
  end
  # resource path
  local_var_path = '/accounts/{account_id}/job_templates/{id}'.sub('{' + 'account_id' + '}', CGI.escape(.to_s)).sub('{' + 'id' + '}', CGI.escape(id.to_s))

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json'])
  header_params[:'X-PhraseApp-OTP'] = opts[:'x_phrase_app_otp'] if !opts[:'x_phrase_app_otp'].nil?

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:body] 

  # return_type
  return_type = opts[:return_type] 

  # auth_names
  auth_names = opts[:auth_names] || ['Basic', 'Token']

  new_options = opts.merge(
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:DELETE, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: OrganizationJobTemplatesApi#organization_job_template_delete\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  response = ::Phrase::Response.new(data, headers)
  return response, status_code, headers
end

#organization_job_template_update(account_id, id, organization_job_template_update_parameters, opts = {}) ⇒ OrganizationJobTemplateDetails

Update an organization job template Update an existing organization job template.

Parameters:

  • account_id (String)

    Account ID

  • id (String)

    ID

  • organization_job_template_update_parameters (OrganizationJobTemplateUpdateParameters)
  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :x_phrase_app_otp (String)

    Two-Factor-Authentication token (optional)

Returns:



164
165
166
167
# File 'lib/phrase/api/organization_job_templates_api.rb', line 164

def organization_job_template_update(, id, organization_job_template_update_parameters, opts = {})
  data, _status_code, _headers = organization_job_template_update_with_http_info(, id, organization_job_template_update_parameters, opts)
  data
end

#organization_job_template_update_with_http_info(account_id, id, organization_job_template_update_parameters, opts = {}) ⇒ Array<(Response<(OrganizationJobTemplateDetails)>, Integer, Hash)>

Update an organization job template Update an existing organization job template.

Parameters:

  • account_id (String)

    Account ID

  • id (String)

    ID

  • organization_job_template_update_parameters (OrganizationJobTemplateUpdateParameters)
  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :x_phrase_app_otp (String)

    Two-Factor-Authentication token (optional)

Returns:



177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
# File 'lib/phrase/api/organization_job_templates_api.rb', line 177

def organization_job_template_update_with_http_info(, id, organization_job_template_update_parameters, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: OrganizationJobTemplatesApi.organization_job_template_update ...'
  end
  # verify the required parameter 'account_id' is set
  if @api_client.config.client_side_validation && .nil?
    fail ArgumentError, "Missing the required parameter 'account_id' when calling OrganizationJobTemplatesApi.organization_job_template_update"
  end
  # verify the required parameter 'id' is set
  if @api_client.config.client_side_validation && id.nil?
    fail ArgumentError, "Missing the required parameter 'id' when calling OrganizationJobTemplatesApi.organization_job_template_update"
  end
  # verify the required parameter 'organization_job_template_update_parameters' is set
  if @api_client.config.client_side_validation && organization_job_template_update_parameters.nil?
    fail ArgumentError, "Missing the required parameter 'organization_job_template_update_parameters' when calling OrganizationJobTemplatesApi.organization_job_template_update"
  end
  # resource path
  local_var_path = '/accounts/{account_id}/job_templates/{id}'.sub('{' + 'account_id' + '}', CGI.escape(.to_s)).sub('{' + 'id' + '}', CGI.escape(id.to_s))

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json'])
  # HTTP header 'Content-Type'
  header_params['Content-Type'] = @api_client.select_header_content_type(['application/json'])
  header_params[:'X-PhraseApp-OTP'] = opts[:'x_phrase_app_otp'] if !opts[:'x_phrase_app_otp'].nil?

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:body] || @api_client.object_to_http_body(organization_job_template_update_parameters) 

  # return_type
  return_type = opts[:return_type] || 'OrganizationJobTemplateDetails' 

  # auth_names
  auth_names = opts[:auth_names] || ['Basic', 'Token']

  new_options = opts.merge(
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:PATCH, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: OrganizationJobTemplatesApi#organization_job_template_update\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  response = ::Phrase::Response.new(data, headers)
  return response, status_code, headers
end

#organization_job_templates_list(account_id, opts = {}) ⇒ Array<OrganizationJobTemplate>

List organization job templates List all job templates for the given account.

Parameters:

  • account_id (String)

    Account ID

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :x_phrase_app_otp (String)

    Two-Factor-Authentication token (optional)

  • :page (Integer)

    Page number

  • :per_page (Integer)

    Limit on the number of objects to be returned, between 1 and 100. 25 by default

Returns:



244
245
246
247
# File 'lib/phrase/api/organization_job_templates_api.rb', line 244

def organization_job_templates_list(, opts = {})
  data, _status_code, _headers = organization_job_templates_list_with_http_info(, opts)
  data
end

#organization_job_templates_list_with_http_info(account_id, opts = {}) ⇒ Array<(Response<(Array<OrganizationJobTemplate>)>, Integer, Hash)>

List organization job templates List all job templates for the given account.

Parameters:

  • account_id (String)

    Account ID

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :x_phrase_app_otp (String)

    Two-Factor-Authentication token (optional)

  • :page (Integer)

    Page number

  • :per_page (Integer)

    Limit on the number of objects to be returned, between 1 and 100. 25 by default

Returns:

  • (Array<(Response<(Array<OrganizationJobTemplate>)>, Integer, Hash)>)

    Response<(Array<OrganizationJobTemplate>)> data, response status code and response headers



257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
# File 'lib/phrase/api/organization_job_templates_api.rb', line 257

def organization_job_templates_list_with_http_info(, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: OrganizationJobTemplatesApi.organization_job_templates_list ...'
  end
  # verify the required parameter 'account_id' is set
  if @api_client.config.client_side_validation && .nil?
    fail ArgumentError, "Missing the required parameter 'account_id' when calling OrganizationJobTemplatesApi.organization_job_templates_list"
  end
  # resource path
  local_var_path = '/accounts/{account_id}/job_templates'.sub('{' + 'account_id' + '}', CGI.escape(.to_s))

  # query parameters
  query_params = opts[:query_params] || {}
  query_params[:'page'] = opts[:'page'] if !opts[:'page'].nil?
  query_params[:'per_page'] = opts[:'per_page'] if !opts[:'per_page'].nil?

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json'])
  header_params[:'X-PhraseApp-OTP'] = opts[:'x_phrase_app_otp'] if !opts[:'x_phrase_app_otp'].nil?

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:body] 

  # return_type
  return_type = opts[:return_type] || 'Array<OrganizationJobTemplate>' 

  # auth_names
  auth_names = opts[:auth_names] || ['Basic', 'Token']

  new_options = opts.merge(
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:GET, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: OrganizationJobTemplatesApi#organization_job_templates_list\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  response = ::Phrase::Response.new(data, headers)
  return response, status_code, headers
end

#organization_job_templates_show(account_id, id, opts = {}) ⇒ OrganizationJobTemplateDetails

Get a single organization job template Get details on a single organization job template for a given account.

Parameters:

  • account_id (String)

    Account ID

  • id (String)

    ID

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :x_phrase_app_otp (String)

    Two-Factor-Authentication token (optional)

Returns:



315
316
317
318
# File 'lib/phrase/api/organization_job_templates_api.rb', line 315

def organization_job_templates_show(, id, opts = {})
  data, _status_code, _headers = organization_job_templates_show_with_http_info(, id, opts)
  data
end

#organization_job_templates_show_with_http_info(account_id, id, opts = {}) ⇒ Array<(Response<(OrganizationJobTemplateDetails)>, Integer, Hash)>

Get a single organization job template Get details on a single organization job template for a given account.

Parameters:

  • account_id (String)

    Account ID

  • id (String)

    ID

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :x_phrase_app_otp (String)

    Two-Factor-Authentication token (optional)

Returns:



327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
342
343
344
345
346
347
348
349
350
351
352
353
354
355
356
357
358
359
360
361
362
363
364
365
366
367
368
369
370
371
372
373
374
375
376
377
378
# File 'lib/phrase/api/organization_job_templates_api.rb', line 327

def organization_job_templates_show_with_http_info(, id, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: OrganizationJobTemplatesApi.organization_job_templates_show ...'
  end
  # verify the required parameter 'account_id' is set
  if @api_client.config.client_side_validation && .nil?
    fail ArgumentError, "Missing the required parameter 'account_id' when calling OrganizationJobTemplatesApi.organization_job_templates_show"
  end
  # verify the required parameter 'id' is set
  if @api_client.config.client_side_validation && id.nil?
    fail ArgumentError, "Missing the required parameter 'id' when calling OrganizationJobTemplatesApi.organization_job_templates_show"
  end
  # resource path
  local_var_path = '/accounts/{account_id}/job_templates/{id}'.sub('{' + 'account_id' + '}', CGI.escape(.to_s)).sub('{' + 'id' + '}', CGI.escape(id.to_s))

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json'])
  header_params[:'X-PhraseApp-OTP'] = opts[:'x_phrase_app_otp'] if !opts[:'x_phrase_app_otp'].nil?

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:body] 

  # return_type
  return_type = opts[:return_type] || 'OrganizationJobTemplateDetails' 

  # auth_names
  auth_names = opts[:auth_names] || ['Basic', 'Token']

  new_options = opts.merge(
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:GET, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: OrganizationJobTemplatesApi#organization_job_templates_show\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  response = ::Phrase::Response.new(data, headers)
  return response, status_code, headers
end