Class: Phrase::PreTranslationsApi
- Inherits:
-
Object
- Object
- Phrase::PreTranslationsApi
- Defined in:
- lib/phrase/api/pre_translations_api.rb
Instance Attribute Summary collapse
-
#api_client ⇒ Object
Returns the value of attribute api_client.
Instance Method Summary collapse
-
#initialize(api_client = ApiClient.default) ⇒ PreTranslationsApi
constructor
A new instance of PreTranslationsApi.
-
#pre_translation_create(project_id, pre_translation_create_parameters, opts = {}) ⇒ PreTranslation
Create a pre-translation job Triggers a pre-translation job for a resource within a project, addressed by
translatable_type(locale,job,translation_key, orupload) andtranslatable_id(its ID). -
#pre_translation_create_with_http_info(project_id, pre_translation_create_parameters, opts = {}) ⇒ Array<(Response<(PreTranslation)>, Integer, Hash)>
Create a pre-translation job Triggers a pre-translation job for a resource within a project, addressed by `translatable_type` (`locale`, `job`, `translation_key`, or `upload`) and `translatable_id` (its ID).
-
#pre_translation_show(project_id, id, opts = {}) ⇒ PreTranslation
Get a single pre-translation job Returns a single pre-translation job identified by its ID.
-
#pre_translation_show_with_http_info(project_id, id, opts = {}) ⇒ Array<(Response<(PreTranslation)>, Integer, Hash)>
Get a single pre-translation job Returns a single pre-translation job identified by its ID.
-
#pre_translations_list(project_id, opts = {}) ⇒ Array<PreTranslation>
List pre-translation jobs Returns all pre-translation jobs scoped to a project, ordered by creation date descending.
-
#pre_translations_list_with_http_info(project_id, opts = {}) ⇒ Array<(Response<(Array<PreTranslation>)>, Integer, Hash)>
List pre-translation jobs Returns all pre-translation jobs scoped to a project, ordered by creation date descending.
Constructor Details
#initialize(api_client = ApiClient.default) ⇒ PreTranslationsApi
Returns a new instance of PreTranslationsApi.
7 8 9 |
# File 'lib/phrase/api/pre_translations_api.rb', line 7 def initialize(api_client = ApiClient.default) @api_client = api_client end |
Instance Attribute Details
#api_client ⇒ Object
Returns the value of attribute api_client.
5 6 7 |
# File 'lib/phrase/api/pre_translations_api.rb', line 5 def api_client @api_client end |
Instance Method Details
#pre_translation_create(project_id, pre_translation_create_parameters, opts = {}) ⇒ PreTranslation
Create a pre-translation job
Triggers a pre-translation job for a resource within a project, addressed by translatable_type (locale, job, translation_key, or upload) and translatable_id (its ID). Enqueues machine translation using the project's configured MT engine.
17 18 19 20 |
# File 'lib/phrase/api/pre_translations_api.rb', line 17 def pre_translation_create(project_id, pre_translation_create_parameters, opts = {}) data, _status_code, _headers = pre_translation_create_with_http_info(project_id, pre_translation_create_parameters, opts) data end |
#pre_translation_create_with_http_info(project_id, pre_translation_create_parameters, opts = {}) ⇒ Array<(Response<(PreTranslation)>, Integer, Hash)>
Create a pre-translation job Triggers a pre-translation job for a resource within a project, addressed by `translatable_type` (`locale`, `job`, `translation_key`, or `upload`) and `translatable_id` (its ID). Enqueues machine translation using the project's configured MT engine.
29 30 31 32 33 34 35 36 37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 |
# File 'lib/phrase/api/pre_translations_api.rb', line 29 def pre_translation_create_with_http_info(project_id, pre_translation_create_parameters, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: PreTranslationsApi.pre_translation_create ...' end # verify the required parameter 'project_id' is set if @api_client.config.client_side_validation && project_id.nil? fail ArgumentError, "Missing the required parameter 'project_id' when calling PreTranslationsApi.pre_translation_create" end # verify the required parameter 'pre_translation_create_parameters' is set if @api_client.config.client_side_validation && pre_translation_create_parameters.nil? fail ArgumentError, "Missing the required parameter 'pre_translation_create_parameters' when calling PreTranslationsApi.pre_translation_create" end # resource path local_var_path = '/projects/{project_id}/pre_translations'.sub('{' + 'project_id' + '}', CGI.escape(project_id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # HTTP header 'Content-Type' header_params['Content-Type'] = @api_client.select_header_content_type(['application/json']) header_params[:'X-PhraseApp-OTP'] = opts[:'x_phrase_app_otp'] if !opts[:'x_phrase_app_otp'].nil? # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:body] || @api_client.object_to_http_body(pre_translation_create_parameters) # return_type return_type = opts[:return_type] || 'PreTranslation' # auth_names auth_names = opts[:auth_names] || ['Basic', 'Token'] = opts.merge( :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:POST, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: PreTranslationsApi#pre_translation_create\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end response = ::Phrase::Response.new(data, headers) return response, status_code, headers end |
#pre_translation_show(project_id, id, opts = {}) ⇒ PreTranslation
Get a single pre-translation job Returns a single pre-translation job identified by its ID.
93 94 95 96 |
# File 'lib/phrase/api/pre_translations_api.rb', line 93 def pre_translation_show(project_id, id, opts = {}) data, _status_code, _headers = pre_translation_show_with_http_info(project_id, id, opts) data end |
#pre_translation_show_with_http_info(project_id, id, opts = {}) ⇒ Array<(Response<(PreTranslation)>, Integer, Hash)>
Get a single pre-translation job Returns a single pre-translation job identified by its ID.
107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 |
# File 'lib/phrase/api/pre_translations_api.rb', line 107 def pre_translation_show_with_http_info(project_id, id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: PreTranslationsApi.pre_translation_show ...' end # verify the required parameter 'project_id' is set if @api_client.config.client_side_validation && project_id.nil? fail ArgumentError, "Missing the required parameter 'project_id' when calling PreTranslationsApi.pre_translation_show" end # verify the required parameter 'id' is set if @api_client.config.client_side_validation && id.nil? fail ArgumentError, "Missing the required parameter 'id' when calling PreTranslationsApi.pre_translation_show" end # resource path local_var_path = '/projects/{project_id}/pre_translations/{id}'.sub('{' + 'project_id' + '}', CGI.escape(project_id.to_s)).sub('{' + 'id' + '}', CGI.escape(id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) header_params[:'X-PhraseApp-OTP'] = opts[:'x_phrase_app_otp'] if !opts[:'x_phrase_app_otp'].nil? header_params[:'If-Modified-Since'] = opts[:'if_modified_since'] if !opts[:'if_modified_since'].nil? header_params[:'If-None-Match'] = opts[:'if_none_match'] if !opts[:'if_none_match'].nil? # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:body] # return_type return_type = opts[:return_type] || 'PreTranslation' # auth_names auth_names = opts[:auth_names] || ['Basic', 'Token'] = opts.merge( :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: PreTranslationsApi#pre_translation_show\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end response = ::Phrase::Response.new(data, headers) return response, status_code, headers end |
#pre_translations_list(project_id, opts = {}) ⇒ Array<PreTranslation>
List pre-translation jobs Returns all pre-translation jobs scoped to a project, ordered by creation date descending.
172 173 174 175 |
# File 'lib/phrase/api/pre_translations_api.rb', line 172 def pre_translations_list(project_id, opts = {}) data, _status_code, _headers = pre_translations_list_with_http_info(project_id, opts) data end |
#pre_translations_list_with_http_info(project_id, opts = {}) ⇒ Array<(Response<(Array<PreTranslation>)>, Integer, Hash)>
List pre-translation jobs Returns all pre-translation jobs scoped to a project, ordered by creation date descending.
187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 |
# File 'lib/phrase/api/pre_translations_api.rb', line 187 def pre_translations_list_with_http_info(project_id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: PreTranslationsApi.pre_translations_list ...' end # verify the required parameter 'project_id' is set if @api_client.config.client_side_validation && project_id.nil? fail ArgumentError, "Missing the required parameter 'project_id' when calling PreTranslationsApi.pre_translations_list" end # resource path local_var_path = '/projects/{project_id}/pre_translations'.sub('{' + 'project_id' + '}', CGI.escape(project_id.to_s)) # query parameters query_params = opts[:query_params] || {} query_params[:'page'] = opts[:'page'] if !opts[:'page'].nil? query_params[:'per_page'] = opts[:'per_page'] if !opts[:'per_page'].nil? # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) header_params[:'X-PhraseApp-OTP'] = opts[:'x_phrase_app_otp'] if !opts[:'x_phrase_app_otp'].nil? header_params[:'If-Modified-Since'] = opts[:'if_modified_since'] if !opts[:'if_modified_since'].nil? header_params[:'If-None-Match'] = opts[:'if_none_match'] if !opts[:'if_none_match'].nil? # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:body] # return_type return_type = opts[:return_type] || 'Array<PreTranslation>' # auth_names auth_names = opts[:auth_names] || ['Basic', 'Token'] = opts.merge( :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: PreTranslationsApi#pre_translations_list\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end response = ::Phrase::Response.new(data, headers) return response, status_code, headers end |