Class: Phrase::ProjectDetails
- Inherits:
-
Object
- Object
- Phrase::ProjectDetails
- Defined in:
- lib/phrase/models/project_details.rb
Instance Attribute Summary collapse
-
#account ⇒ Object
Returns the value of attribute account.
-
#autotranslate_check_new_locales ⇒ Object
Returns the value of attribute autotranslate_check_new_locales.
-
#autotranslate_check_new_translation_keys ⇒ Object
Returns the value of attribute autotranslate_check_new_translation_keys.
-
#autotranslate_check_new_uploads ⇒ Object
Returns the value of attribute autotranslate_check_new_uploads.
-
#autotranslate_enabled ⇒ Object
Returns the value of attribute autotranslate_enabled.
-
#autotranslate_mark_as_unverified ⇒ Object
Returns the value of attribute autotranslate_mark_as_unverified.
-
#autotranslate_use_machine_translation ⇒ Object
Returns the value of attribute autotranslate_use_machine_translation.
-
#autotranslate_use_translation_memory ⇒ Object
Returns the value of attribute autotranslate_use_translation_memory.
-
#cldr_version ⇒ Object
Returns the value of attribute cldr_version.
-
#created_at ⇒ Object
Returns the value of attribute created_at.
-
#default_encoding ⇒ Object
Returns the value of attribute default_encoding.
-
#enable_all_data_type_translation_keys_for_translators ⇒ Object
Returns the value of attribute enable_all_data_type_translation_keys_for_translators.
-
#enable_branching ⇒ Object
Returns the value of attribute enable_branching.
-
#enable_icu_message_format ⇒ Object
Returns the value of attribute enable_icu_message_format.
-
#id ⇒ Object
Returns the value of attribute id.
-
#job_locking_enabled ⇒ Object
Returns the value of attribute job_locking_enabled.
-
#machine_translation_enabled ⇒ Object
Returns the value of attribute machine_translation_enabled.
-
#main_format ⇒ Object
Returns the value of attribute main_format.
-
#media ⇒ Object
Returns the value of attribute media.
-
#name ⇒ Object
Returns the value of attribute name.
-
#placeholder_styles ⇒ Object
Returns the value of attribute placeholder_styles.
-
#point_of_contact ⇒ Object
Returns the value of attribute point_of_contact.
-
#project_image_url ⇒ Object
Returns the value of attribute project_image_url.
-
#protect_master_branch ⇒ Object
Returns the value of attribute protect_master_branch.
-
#shares_translation_memory ⇒ Object
Returns the value of attribute shares_translation_memory.
-
#slug ⇒ Object
Returns the value of attribute slug.
-
#space ⇒ Object
Returns the value of attribute space.
-
#updated_at ⇒ Object
Returns the value of attribute updated_at.
-
#zero_plural_form_enabled ⇒ Object
Returns the value of attribute zero_plural_form_enabled.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_all_of ⇒ Object
List of class defined in allOf (OpenAPI v3).
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ ProjectDetails
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ ProjectDetails
Initializes the object
148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 |
# File 'lib/phrase/models/project_details.rb', line 148 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Phrase::ProjectDetails` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| if (!self.class.attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Phrase::ProjectDetails`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'id') self.id = attributes[:'id'] end if attributes.key?(:'name') self.name = attributes[:'name'] end if attributes.key?(:'slug') self.slug = attributes[:'slug'] end if attributes.key?(:'main_format') self.main_format = attributes[:'main_format'] end if attributes.key?(:'project_image_url') self.project_image_url = attributes[:'project_image_url'] end if attributes.key?(:'media') self.media = attributes[:'media'] end if attributes.key?(:'account') self.account = attributes[:'account'] end if attributes.key?(:'space') self.space = attributes[:'space'] end if attributes.key?(:'point_of_contact') self.point_of_contact = attributes[:'point_of_contact'] end if attributes.key?(:'created_at') self.created_at = attributes[:'created_at'] end if attributes.key?(:'updated_at') self.updated_at = attributes[:'updated_at'] end if attributes.key?(:'shares_translation_memory') self.shares_translation_memory = attributes[:'shares_translation_memory'] end if attributes.key?(:'machine_translation_enabled') self.machine_translation_enabled = attributes[:'machine_translation_enabled'] end if attributes.key?(:'zero_plural_form_enabled') self.zero_plural_form_enabled = attributes[:'zero_plural_form_enabled'] end if attributes.key?(:'enable_all_data_type_translation_keys_for_translators') self.enable_all_data_type_translation_keys_for_translators = attributes[:'enable_all_data_type_translation_keys_for_translators'] end if attributes.key?(:'enable_icu_message_format') self. = attributes[:'enable_icu_message_format'] end if attributes.key?(:'enable_branching') self.enable_branching = attributes[:'enable_branching'] end if attributes.key?(:'protect_master_branch') self.protect_master_branch = attributes[:'protect_master_branch'] end if attributes.key?(:'autotranslate_enabled') self.autotranslate_enabled = attributes[:'autotranslate_enabled'] end if attributes.key?(:'autotranslate_check_new_translation_keys') self.autotranslate_check_new_translation_keys = attributes[:'autotranslate_check_new_translation_keys'] end if attributes.key?(:'autotranslate_check_new_uploads') self.autotranslate_check_new_uploads = attributes[:'autotranslate_check_new_uploads'] end if attributes.key?(:'autotranslate_check_new_locales') self.autotranslate_check_new_locales = attributes[:'autotranslate_check_new_locales'] end if attributes.key?(:'autotranslate_mark_as_unverified') self.autotranslate_mark_as_unverified = attributes[:'autotranslate_mark_as_unverified'] end if attributes.key?(:'autotranslate_use_machine_translation') self.autotranslate_use_machine_translation = attributes[:'autotranslate_use_machine_translation'] end if attributes.key?(:'autotranslate_use_translation_memory') self.autotranslate_use_translation_memory = attributes[:'autotranslate_use_translation_memory'] end if attributes.key?(:'default_encoding') self.default_encoding = attributes[:'default_encoding'] end if attributes.key?(:'cldr_version') self.cldr_version = attributes[:'cldr_version'] end if attributes.key?(:'job_locking_enabled') self.job_locking_enabled = attributes[:'job_locking_enabled'] end if attributes.key?(:'placeholder_styles') if (value = attributes[:'placeholder_styles']).is_a?(Array) self.placeholder_styles = value end end end |
Instance Attribute Details
#account ⇒ Object
Returns the value of attribute account.
17 18 19 |
# File 'lib/phrase/models/project_details.rb', line 17 def account @account end |
#autotranslate_check_new_locales ⇒ Object
Returns the value of attribute autotranslate_check_new_locales.
47 48 49 |
# File 'lib/phrase/models/project_details.rb', line 47 def autotranslate_check_new_locales @autotranslate_check_new_locales end |
#autotranslate_check_new_translation_keys ⇒ Object
Returns the value of attribute autotranslate_check_new_translation_keys.
43 44 45 |
# File 'lib/phrase/models/project_details.rb', line 43 def autotranslate_check_new_translation_keys @autotranslate_check_new_translation_keys end |
#autotranslate_check_new_uploads ⇒ Object
Returns the value of attribute autotranslate_check_new_uploads.
45 46 47 |
# File 'lib/phrase/models/project_details.rb', line 45 def autotranslate_check_new_uploads @autotranslate_check_new_uploads end |
#autotranslate_enabled ⇒ Object
Returns the value of attribute autotranslate_enabled.
41 42 43 |
# File 'lib/phrase/models/project_details.rb', line 41 def autotranslate_enabled @autotranslate_enabled end |
#autotranslate_mark_as_unverified ⇒ Object
Returns the value of attribute autotranslate_mark_as_unverified.
49 50 51 |
# File 'lib/phrase/models/project_details.rb', line 49 def autotranslate_mark_as_unverified @autotranslate_mark_as_unverified end |
#autotranslate_use_machine_translation ⇒ Object
Returns the value of attribute autotranslate_use_machine_translation.
51 52 53 |
# File 'lib/phrase/models/project_details.rb', line 51 def autotranslate_use_machine_translation @autotranslate_use_machine_translation end |
#autotranslate_use_translation_memory ⇒ Object
Returns the value of attribute autotranslate_use_translation_memory.
53 54 55 |
# File 'lib/phrase/models/project_details.rb', line 53 def autotranslate_use_translation_memory @autotranslate_use_translation_memory end |
#cldr_version ⇒ Object
Returns the value of attribute cldr_version.
57 58 59 |
# File 'lib/phrase/models/project_details.rb', line 57 def cldr_version @cldr_version end |
#created_at ⇒ Object
Returns the value of attribute created_at.
23 24 25 |
# File 'lib/phrase/models/project_details.rb', line 23 def created_at @created_at end |
#default_encoding ⇒ Object
Returns the value of attribute default_encoding.
55 56 57 |
# File 'lib/phrase/models/project_details.rb', line 55 def default_encoding @default_encoding end |
#enable_all_data_type_translation_keys_for_translators ⇒ Object
Returns the value of attribute enable_all_data_type_translation_keys_for_translators.
33 34 35 |
# File 'lib/phrase/models/project_details.rb', line 33 def enable_all_data_type_translation_keys_for_translators @enable_all_data_type_translation_keys_for_translators end |
#enable_branching ⇒ Object
Returns the value of attribute enable_branching.
37 38 39 |
# File 'lib/phrase/models/project_details.rb', line 37 def enable_branching @enable_branching end |
#enable_icu_message_format ⇒ Object
Returns the value of attribute enable_icu_message_format.
35 36 37 |
# File 'lib/phrase/models/project_details.rb', line 35 def @enable_icu_message_format end |
#id ⇒ Object
Returns the value of attribute id.
5 6 7 |
# File 'lib/phrase/models/project_details.rb', line 5 def id @id end |
#job_locking_enabled ⇒ Object
Returns the value of attribute job_locking_enabled.
59 60 61 |
# File 'lib/phrase/models/project_details.rb', line 59 def job_locking_enabled @job_locking_enabled end |
#machine_translation_enabled ⇒ Object
Returns the value of attribute machine_translation_enabled.
29 30 31 |
# File 'lib/phrase/models/project_details.rb', line 29 def machine_translation_enabled @machine_translation_enabled end |
#main_format ⇒ Object
Returns the value of attribute main_format.
11 12 13 |
# File 'lib/phrase/models/project_details.rb', line 11 def main_format @main_format end |
#media ⇒ Object
Returns the value of attribute media.
15 16 17 |
# File 'lib/phrase/models/project_details.rb', line 15 def media @media end |
#name ⇒ Object
Returns the value of attribute name.
7 8 9 |
# File 'lib/phrase/models/project_details.rb', line 7 def name @name end |
#placeholder_styles ⇒ Object
Returns the value of attribute placeholder_styles.
61 62 63 |
# File 'lib/phrase/models/project_details.rb', line 61 def placeholder_styles @placeholder_styles end |
#point_of_contact ⇒ Object
Returns the value of attribute point_of_contact.
21 22 23 |
# File 'lib/phrase/models/project_details.rb', line 21 def point_of_contact @point_of_contact end |
#project_image_url ⇒ Object
Returns the value of attribute project_image_url.
13 14 15 |
# File 'lib/phrase/models/project_details.rb', line 13 def project_image_url @project_image_url end |
#protect_master_branch ⇒ Object
Returns the value of attribute protect_master_branch.
39 40 41 |
# File 'lib/phrase/models/project_details.rb', line 39 def protect_master_branch @protect_master_branch end |
#shares_translation_memory ⇒ Object
Returns the value of attribute shares_translation_memory.
27 28 29 |
# File 'lib/phrase/models/project_details.rb', line 27 def shares_translation_memory @shares_translation_memory end |
#slug ⇒ Object
Returns the value of attribute slug.
9 10 11 |
# File 'lib/phrase/models/project_details.rb', line 9 def slug @slug end |
#space ⇒ Object
Returns the value of attribute space.
19 20 21 |
# File 'lib/phrase/models/project_details.rb', line 19 def space @space end |
#updated_at ⇒ Object
Returns the value of attribute updated_at.
25 26 27 |
# File 'lib/phrase/models/project_details.rb', line 25 def updated_at @updated_at end |
#zero_plural_form_enabled ⇒ Object
Returns the value of attribute zero_plural_form_enabled.
31 32 33 |
# File 'lib/phrase/models/project_details.rb', line 31 def zero_plural_form_enabled @zero_plural_form_enabled end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 |
# File 'lib/phrase/models/project_details.rb', line 64 def self.attribute_map { :'id' => :'id', :'name' => :'name', :'slug' => :'slug', :'main_format' => :'main_format', :'project_image_url' => :'project_image_url', :'media' => :'media', :'account' => :'account', :'space' => :'space', :'point_of_contact' => :'point_of_contact', :'created_at' => :'created_at', :'updated_at' => :'updated_at', :'shares_translation_memory' => :'shares_translation_memory', :'machine_translation_enabled' => :'machine_translation_enabled', :'zero_plural_form_enabled' => :'zero_plural_form_enabled', :'enable_all_data_type_translation_keys_for_translators' => :'enable_all_data_type_translation_keys_for_translators', :'enable_icu_message_format' => :'enable_icu_message_format', :'enable_branching' => :'enable_branching', :'protect_master_branch' => :'protect_master_branch', :'autotranslate_enabled' => :'autotranslate_enabled', :'autotranslate_check_new_translation_keys' => :'autotranslate_check_new_translation_keys', :'autotranslate_check_new_uploads' => :'autotranslate_check_new_uploads', :'autotranslate_check_new_locales' => :'autotranslate_check_new_locales', :'autotranslate_mark_as_unverified' => :'autotranslate_mark_as_unverified', :'autotranslate_use_machine_translation' => :'autotranslate_use_machine_translation', :'autotranslate_use_translation_memory' => :'autotranslate_use_translation_memory', :'default_encoding' => :'default_encoding', :'cldr_version' => :'cldr_version', :'job_locking_enabled' => :'job_locking_enabled', :'placeholder_styles' => :'placeholder_styles' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
344 345 346 |
# File 'lib/phrase/models/project_details.rb', line 344 def self.build_from_hash(attributes) new.build_from_hash(attributes) end |
.openapi_all_of ⇒ Object
List of class defined in allOf (OpenAPI v3)
140 141 142 143 144 |
# File 'lib/phrase/models/project_details.rb', line 140 def self.openapi_all_of [ :'Project' ] end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
134 135 136 137 |
# File 'lib/phrase/models/project_details.rb', line 134 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 |
# File 'lib/phrase/models/project_details.rb', line 99 def self.openapi_types { :'id' => :'String', :'name' => :'String', :'slug' => :'String', :'main_format' => :'String', :'project_image_url' => :'String', :'media' => :'String', :'account' => :'Account', :'space' => :'Space1', :'point_of_contact' => :'UserPreview', :'created_at' => :'DateTime', :'updated_at' => :'DateTime', :'shares_translation_memory' => :'Boolean', :'machine_translation_enabled' => :'Boolean', :'zero_plural_form_enabled' => :'Boolean', :'enable_all_data_type_translation_keys_for_translators' => :'Boolean', :'enable_icu_message_format' => :'Boolean', :'enable_branching' => :'Boolean', :'protect_master_branch' => :'Boolean', :'autotranslate_enabled' => :'Boolean', :'autotranslate_check_new_translation_keys' => :'Boolean', :'autotranslate_check_new_uploads' => :'Boolean', :'autotranslate_check_new_locales' => :'Boolean', :'autotranslate_mark_as_unverified' => :'Boolean', :'autotranslate_use_machine_translation' => :'Boolean', :'autotranslate_use_translation_memory' => :'Boolean', :'default_encoding' => :'String', :'cldr_version' => :'String', :'job_locking_enabled' => :'Boolean', :'placeholder_styles' => :'Array<String>' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 |
# File 'lib/phrase/models/project_details.rb', line 295 def ==(o) return true if self.equal?(o) self.class == o.class && id == o.id && name == o.name && slug == o.slug && main_format == o.main_format && project_image_url == o.project_image_url && media == o.media && account == o.account && space == o.space && point_of_contact == o.point_of_contact && created_at == o.created_at && updated_at == o.updated_at && shares_translation_memory == o.shares_translation_memory && machine_translation_enabled == o.machine_translation_enabled && zero_plural_form_enabled == o.zero_plural_form_enabled && enable_all_data_type_translation_keys_for_translators == o.enable_all_data_type_translation_keys_for_translators && == o. && enable_branching == o.enable_branching && protect_master_branch == o.protect_master_branch && autotranslate_enabled == o.autotranslate_enabled && autotranslate_check_new_translation_keys == o.autotranslate_check_new_translation_keys && autotranslate_check_new_uploads == o.autotranslate_check_new_uploads && autotranslate_check_new_locales == o.autotranslate_check_new_locales && autotranslate_mark_as_unverified == o.autotranslate_mark_as_unverified && autotranslate_use_machine_translation == o.autotranslate_use_machine_translation && autotranslate_use_translation_memory == o.autotranslate_use_translation_memory && default_encoding == o.default_encoding && cldr_version == o.cldr_version && job_locking_enabled == o.job_locking_enabled && placeholder_styles == o.placeholder_styles end |
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type
372 373 374 375 376 377 378 379 380 381 382 383 384 385 386 387 388 389 390 391 392 393 394 395 396 397 398 399 400 401 402 403 404 405 406 407 408 409 |
# File 'lib/phrase/models/project_details.rb', line 372 def _deserialize(type, value) case type.to_sym when :DateTime DateTime.parse(value) when :Date Date.parse(value) when :Time Time.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model Phrase.const_get(type).build_from_hash(value) end end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
443 444 445 446 447 448 449 450 451 452 453 454 455 |
# File 'lib/phrase/models/project_details.rb', line 443 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 366 |
# File 'lib/phrase/models/project_details.rb', line 351 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.openapi_types.each_pair do |key, type| if type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) }) end elsif !attributes[self.class.attribute_map[key]].nil? self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]])) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(o) ⇒ Boolean
331 332 333 |
# File 'lib/phrase/models/project_details.rb', line 331 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
337 338 339 |
# File 'lib/phrase/models/project_details.rb', line 337 def hash [id, name, slug, main_format, project_image_url, media, account, space, point_of_contact, created_at, updated_at, shares_translation_memory, machine_translation_enabled, zero_plural_form_enabled, enable_all_data_type_translation_keys_for_translators, , enable_branching, protect_master_branch, autotranslate_enabled, autotranslate_check_new_translation_keys, autotranslate_check_new_uploads, autotranslate_check_new_locales, autotranslate_mark_as_unverified, autotranslate_use_machine_translation, autotranslate_use_translation_memory, default_encoding, cldr_version, job_locking_enabled, placeholder_styles].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
282 283 284 285 |
# File 'lib/phrase/models/project_details.rb', line 282 def list_invalid_properties invalid_properties = Array.new invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
419 420 421 |
# File 'lib/phrase/models/project_details.rb', line 419 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
425 426 427 428 429 430 431 432 433 434 435 436 437 |
# File 'lib/phrase/models/project_details.rb', line 425 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
413 414 415 |
# File 'lib/phrase/models/project_details.rb', line 413 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
289 290 291 |
# File 'lib/phrase/models/project_details.rb', line 289 def valid? true end |