Class: Phrase::RepoSyncCreateParameters

Inherits:
Object
  • Object
show all
Defined in:
lib/phrase/models/repo_sync_create_parameters.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ RepoSyncCreateParameters

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
# File 'lib/phrase/models/repo_sync_create_parameters.rb', line 98

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Phrase::RepoSyncCreateParameters` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Phrase::RepoSyncCreateParameters`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'project_id')
    self.project_id = attributes[:'project_id']
  end

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  end

  if attributes.key?(:'git_provider')
    self.git_provider = attributes[:'git_provider']
  else
    self.git_provider = 'github'
  end

  if attributes.key?(:'connection_type')
    self.connection_type = attributes[:'connection_type']
  end

  if attributes.key?(:'repo_name')
    self.repo_name = attributes[:'repo_name']
  end

  if attributes.key?(:'base_branch')
    self.base_branch = attributes[:'base_branch']
  end

  if attributes.key?(:'pr_branch')
    self.pr_branch = attributes[:'pr_branch']
  end

  if attributes.key?(:'auto_import')
    self.auto_import = attributes[:'auto_import']
  end

  if attributes.key?(:'access_token')
    self.access_token = attributes[:'access_token']
  end

  if attributes.key?(:'custom_api_endpoint')
    self.custom_api_endpoint = attributes[:'custom_api_endpoint']
  end
end

Instance Attribute Details

#access_tokenObject

Personal access token for the Git provider. Required when ‘connection_type` is `token` or `self_hosted`. Not used for `github_app`.



30
31
32
# File 'lib/phrase/models/repo_sync_create_parameters.rb', line 30

def access_token
  @access_token
end

#auto_importObject

Enable automatic import of translations triggered by pushes to the repository.



27
28
29
# File 'lib/phrase/models/repo_sync_create_parameters.rb', line 27

def auto_import
  @auto_import
end

#base_branchObject

The default branch to use for imports and exports.



21
22
23
# File 'lib/phrase/models/repo_sync_create_parameters.rb', line 21

def base_branch
  @base_branch
end

#connection_typeObject

The authentication method used to connect to the Git provider. Defaults to ‘token` if not specified. Valid values: - `token` — Personal access token stored on the Repo Sync. Supported by all providers. - `github_app` — Authenticate via the Phrase GitHub App installation on your account. GitHub only. The account must already have the GitHub App installed; if not, the response will include a `github_app_installation_url`. - `self_hosted` — Token-based auth for self-hosted Git instances. Requires `custom_api_endpoint`.



15
16
17
# File 'lib/phrase/models/repo_sync_create_parameters.rb', line 15

def connection_type
  @connection_type
end

#custom_api_endpointObject

Custom API endpoint URL for self-hosted Git instances. Required when ‘connection_type` is `self_hosted`.



33
34
35
# File 'lib/phrase/models/repo_sync_create_parameters.rb', line 33

def custom_api_endpoint
  @custom_api_endpoint
end

#git_providerObject

The Git provider to use.



12
13
14
# File 'lib/phrase/models/repo_sync_create_parameters.rb', line 12

def git_provider
  @git_provider
end

#nameObject

Optional custom display name for this repo sync. Defaults to null; when null the project name is used as the display name.



9
10
11
# File 'lib/phrase/models/repo_sync_create_parameters.rb', line 9

def name
  @name
end

#pr_branchObject

Branch that translations are exported to before opening a pull request. If omitted, exports go directly to ‘base_branch`.



24
25
26
# File 'lib/phrase/models/repo_sync_create_parameters.rb', line 24

def pr_branch
  @pr_branch
end

#project_idObject

ID of the project to connect the Repo Sync to.



6
7
8
# File 'lib/phrase/models/repo_sync_create_parameters.rb', line 6

def project_id
  @project_id
end

#repo_nameObject

Full repository name including the owner, e.g. ‘my-org/my-repo`.



18
19
20
# File 'lib/phrase/models/repo_sync_create_parameters.rb', line 18

def repo_name
  @repo_name
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



58
59
60
61
62
63
64
65
66
67
68
69
70
71
# File 'lib/phrase/models/repo_sync_create_parameters.rb', line 58

def self.attribute_map
  {
    :'project_id' => :'project_id',
    :'name' => :'name',
    :'git_provider' => :'git_provider',
    :'connection_type' => :'connection_type',
    :'repo_name' => :'repo_name',
    :'base_branch' => :'base_branch',
    :'pr_branch' => :'pr_branch',
    :'auto_import' => :'auto_import',
    :'access_token' => :'access_token',
    :'custom_api_endpoint' => :'custom_api_endpoint'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



253
254
255
# File 'lib/phrase/models/repo_sync_create_parameters.rb', line 253

def self.build_from_hash(attributes)
  new.build_from_hash(attributes)
end

.openapi_nullableObject

List of attributes with nullable: true



90
91
92
93
94
# File 'lib/phrase/models/repo_sync_create_parameters.rb', line 90

def self.openapi_nullable
  Set.new([
    :'name',
  ])
end

.openapi_typesObject

Attribute type mapping.



74
75
76
77
78
79
80
81
82
83
84
85
86
87
# File 'lib/phrase/models/repo_sync_create_parameters.rb', line 74

def self.openapi_types
  {
    :'project_id' => :'String',
    :'name' => :'String',
    :'git_provider' => :'String',
    :'connection_type' => :'String',
    :'repo_name' => :'String',
    :'base_branch' => :'String',
    :'pr_branch' => :'String',
    :'auto_import' => :'Boolean',
    :'access_token' => :'String',
    :'custom_api_endpoint' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



223
224
225
226
227
228
229
230
231
232
233
234
235
236
# File 'lib/phrase/models/repo_sync_create_parameters.rb', line 223

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      project_id == o.project_id &&
      name == o.name &&
      git_provider == o.git_provider &&
      connection_type == o.connection_type &&
      repo_name == o.repo_name &&
      base_branch == o.base_branch &&
      pr_branch == o.pr_branch &&
      auto_import == o.auto_import &&
      access_token == o.access_token &&
      custom_api_endpoint == o.custom_api_endpoint
end

#_deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
# File 'lib/phrase/models/repo_sync_create_parameters.rb', line 281

def _deserialize(type, value)
  case type.to_sym
  when :DateTime
    DateTime.parse(value)
  when :Date
    Date.parse(value)
  when :Time
    Time.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    Phrase.const_get(type).build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



352
353
354
355
356
357
358
359
360
361
362
363
364
# File 'lib/phrase/models/repo_sync_create_parameters.rb', line 352

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
# File 'lib/phrase/models/repo_sync_create_parameters.rb', line 260

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  self.class.openapi_types.each_pair do |key, type|
    if type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) })
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]]))
    end # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


240
241
242
# File 'lib/phrase/models/repo_sync_create_parameters.rb', line 240

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



246
247
248
# File 'lib/phrase/models/repo_sync_create_parameters.rb', line 246

def hash
  [project_id, name, git_provider, connection_type, repo_name, base_branch, pr_branch, auto_import, access_token, custom_api_endpoint].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
# File 'lib/phrase/models/repo_sync_create_parameters.rb', line 156

def list_invalid_properties
  invalid_properties = Array.new
  if @project_id.nil?
    invalid_properties.push('invalid value for "project_id", project_id cannot be nil.')
  end

  if !@name.nil? && @name.to_s.length > 100
    invalid_properties.push('invalid value for "name", the character length must be smaller than or equal to 100.')
  end

  if @connection_type.nil?
    invalid_properties.push('invalid value for "connection_type", connection_type cannot be nil.')
  end

  if @repo_name.nil?
    invalid_properties.push('invalid value for "repo_name", repo_name cannot be nil.')
  end

  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



328
329
330
# File 'lib/phrase/models/repo_sync_create_parameters.rb', line 328

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



334
335
336
337
338
339
340
341
342
343
344
345
346
# File 'lib/phrase/models/repo_sync_create_parameters.rb', line 334

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



322
323
324
# File 'lib/phrase/models/repo_sync_create_parameters.rb', line 322

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



179
180
181
182
183
184
185
186
187
188
189
# File 'lib/phrase/models/repo_sync_create_parameters.rb', line 179

def valid?
  return false if @project_id.nil?
  return false if !@name.nil? && @name.to_s.length > 100
  git_provider_validator = EnumAttributeValidator.new('String', ["github", "gitlab", "bitbucket"])
  return false unless git_provider_validator.valid?(@git_provider)
  return false if @connection_type.nil?
  connection_type_validator = EnumAttributeValidator.new('String', ["token", "github_app", "self_hosted"])
  return false unless connection_type_validator.valid?(@connection_type)
  return false if @repo_name.nil?
  true
end