Class: Phrase::SearchApi
- Inherits:
-
Object
- Object
- Phrase::SearchApi
- Defined in:
- lib/phrase/api/search_api.rb
Instance Attribute Summary collapse
-
#api_client ⇒ Object
Returns the value of attribute api_client.
Instance Method Summary collapse
-
#initialize(api_client = ApiClient.default) ⇒ SearchApi
constructor
A new instance of SearchApi.
-
#search_in_account(account_id, search_in_account_parameters, opts = {}) ⇒ AccountSearchResult
Search across projects Search for keys and translations in all account projects Note: Search is limited to 10000 results and may not include recently updated data depending on the project sizes..
-
#search_in_account_with_http_info(account_id, search_in_account_parameters, opts = {}) ⇒ Array<(Response<(AccountSearchResult)>, Integer, Hash)>
Search across projects Search for keys and translations in all account projects Note: Search is limited to 10000 results and may not include recently updated data depending on the project sizes..
Constructor Details
Instance Attribute Details
#api_client ⇒ Object
Returns the value of attribute api_client.
5 6 7 |
# File 'lib/phrase/api/search_api.rb', line 5 def api_client @api_client end |
Instance Method Details
#search_in_account(account_id, search_in_account_parameters, opts = {}) ⇒ AccountSearchResult
Search across projects Search for keys and translations in all account projects Note: Search is limited to 10000 results and may not include recently updated data depending on the project sizes.
17 18 19 20 |
# File 'lib/phrase/api/search_api.rb', line 17 def search_in_account(account_id, search_in_account_parameters, opts = {}) data, _status_code, _headers = search_in_account_with_http_info(account_id, search_in_account_parameters, opts) data end |
#search_in_account_with_http_info(account_id, search_in_account_parameters, opts = {}) ⇒ Array<(Response<(AccountSearchResult)>, Integer, Hash)>
Search across projects Search for keys and translations in all account projects Note: Search is limited to 10000 results and may not include recently updated data depending on the project sizes.
29 30 31 32 33 34 35 36 37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 |
# File 'lib/phrase/api/search_api.rb', line 29 def search_in_account_with_http_info(account_id, search_in_account_parameters, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: SearchApi.search_in_account ...' end # verify the required parameter 'account_id' is set if @api_client.config.client_side_validation && account_id.nil? fail ArgumentError, "Missing the required parameter 'account_id' when calling SearchApi.search_in_account" end # verify the required parameter 'search_in_account_parameters' is set if @api_client.config.client_side_validation && search_in_account_parameters.nil? fail ArgumentError, "Missing the required parameter 'search_in_account_parameters' when calling SearchApi.search_in_account" end # resource path local_var_path = '/accounts/{account_id}/search'.sub('{' + 'account_id' + '}', CGI.escape(account_id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # HTTP header 'Content-Type' header_params['Content-Type'] = @api_client.select_header_content_type(['application/json']) header_params[:'X-PhraseApp-OTP'] = opts[:'x_phrase_app_otp'] if !opts[:'x_phrase_app_otp'].nil? # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:body] || @api_client.object_to_http_body(search_in_account_parameters) # return_type return_type = opts[:return_type] || 'AccountSearchResult' # auth_names auth_names = opts[:auth_names] || ['Basic', 'Token'] = opts.merge( :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:POST, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: SearchApi#search_in_account\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end response = ::Phrase::Response.new(data, headers) return response, status_code, headers end |