Class: Phrase::StyleguideUpdateParameters
- Inherits:
-
Object
- Object
- Phrase::StyleguideUpdateParameters
- Defined in:
- lib/phrase/models/styleguide_update_parameters.rb
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#audience ⇒ Object
Audience description.
-
#business ⇒ Object
Description of the business.
-
#company_branding ⇒ Object
Company branding to remain consistent.
-
#formatting ⇒ Object
Formatting requirements and character limitations.
-
#glossary_terms ⇒ Object
List of terms and/or phrases that need to be translated consistently.
-
#grammar_consistency ⇒ Object
Formal or informal pronouns, consistent conjugation, grammatical gender.
-
#grammatical_person ⇒ Object
Preferred grammatical person.
-
#literal_translation ⇒ Object
Can be one of: Cultural/Conversational, Literal, Neutral.
-
#overall_tone ⇒ Object
Tone requirement descriptions.
-
#samples ⇒ Object
Provide links to sample product pages, FAQ pages, etc.
-
#target_audience ⇒ Object
Target audience for the translations.
-
#title ⇒ Object
Style guide title.
-
#vocabulary_type ⇒ Object
Vocabulary register the translations should use.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ StyleguideUpdateParameters
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ StyleguideUpdateParameters
Initializes the object
112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 |
# File 'lib/phrase/models/styleguide_update_parameters.rb', line 112 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Phrase::StyleguideUpdateParameters` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| if (!self.class.attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Phrase::StyleguideUpdateParameters`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'title') self.title = attributes[:'title'] end if attributes.key?(:'audience') self.audience = attributes[:'audience'] end if attributes.key?(:'target_audience') self.target_audience = attributes[:'target_audience'] end if attributes.key?(:'grammatical_person') self.grammatical_person = attributes[:'grammatical_person'] end if attributes.key?(:'vocabulary_type') self.vocabulary_type = attributes[:'vocabulary_type'] end if attributes.key?(:'business') self.business = attributes[:'business'] end if attributes.key?(:'company_branding') self.company_branding = attributes[:'company_branding'] end if attributes.key?(:'formatting') self.formatting = attributes[:'formatting'] end if attributes.key?(:'glossary_terms') self.glossary_terms = attributes[:'glossary_terms'] end if attributes.key?(:'grammar_consistency') self.grammar_consistency = attributes[:'grammar_consistency'] end if attributes.key?(:'literal_translation') self.literal_translation = attributes[:'literal_translation'] end if attributes.key?(:'overall_tone') self.overall_tone = attributes[:'overall_tone'] end if attributes.key?(:'samples') self.samples = attributes[:'samples'] end end |
Instance Attribute Details
#audience ⇒ Object
Audience description
9 10 11 |
# File 'lib/phrase/models/styleguide_update_parameters.rb', line 9 def audience @audience end |
#business ⇒ Object
Description of the business
21 22 23 |
# File 'lib/phrase/models/styleguide_update_parameters.rb', line 21 def business @business end |
#company_branding ⇒ Object
Company branding to remain consistent.
24 25 26 |
# File 'lib/phrase/models/styleguide_update_parameters.rb', line 24 def company_branding @company_branding end |
#formatting ⇒ Object
Formatting requirements and character limitations.
27 28 29 |
# File 'lib/phrase/models/styleguide_update_parameters.rb', line 27 def formatting @formatting end |
#glossary_terms ⇒ Object
List of terms and/or phrases that need to be translated consistently.
30 31 32 |
# File 'lib/phrase/models/styleguide_update_parameters.rb', line 30 def glossary_terms @glossary_terms end |
#grammar_consistency ⇒ Object
Formal or informal pronouns, consistent conjugation, grammatical gender
33 34 35 |
# File 'lib/phrase/models/styleguide_update_parameters.rb', line 33 def grammar_consistency @grammar_consistency end |
#grammatical_person ⇒ Object
Preferred grammatical person.
15 16 17 |
# File 'lib/phrase/models/styleguide_update_parameters.rb', line 15 def grammatical_person @grammatical_person end |
#literal_translation ⇒ Object
Can be one of: Cultural/Conversational, Literal, Neutral.
36 37 38 |
# File 'lib/phrase/models/styleguide_update_parameters.rb', line 36 def literal_translation @literal_translation end |
#overall_tone ⇒ Object
Tone requirement descriptions
39 40 41 |
# File 'lib/phrase/models/styleguide_update_parameters.rb', line 39 def overall_tone @overall_tone end |
#samples ⇒ Object
Provide links to sample product pages, FAQ pages, etc. to give the translator a point of reference. You can also provide past translations. Even snippets or short paragraphs are helpful for maintaining consistency.
42 43 44 |
# File 'lib/phrase/models/styleguide_update_parameters.rb', line 42 def samples @samples end |
#target_audience ⇒ Object
Target audience for the translations.
12 13 14 |
# File 'lib/phrase/models/styleguide_update_parameters.rb', line 12 def target_audience @target_audience end |
#title ⇒ Object
Style guide title
6 7 8 |
# File 'lib/phrase/models/styleguide_update_parameters.rb', line 6 def title @title end |
#vocabulary_type ⇒ Object
Vocabulary register the translations should use.
18 19 20 |
# File 'lib/phrase/models/styleguide_update_parameters.rb', line 18 def vocabulary_type @vocabulary_type end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 |
# File 'lib/phrase/models/styleguide_update_parameters.rb', line 67 def self.attribute_map { :'title' => :'title', :'audience' => :'audience', :'target_audience' => :'target_audience', :'grammatical_person' => :'grammatical_person', :'vocabulary_type' => :'vocabulary_type', :'business' => :'business', :'company_branding' => :'company_branding', :'formatting' => :'formatting', :'glossary_terms' => :'glossary_terms', :'grammar_consistency' => :'grammar_consistency', :'literal_translation' => :'literal_translation', :'overall_tone' => :'overall_tone', :'samples' => :'samples' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
262 263 264 |
# File 'lib/phrase/models/styleguide_update_parameters.rb', line 262 def self.build_from_hash(attributes) new.build_from_hash(attributes) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
105 106 107 108 |
# File 'lib/phrase/models/styleguide_update_parameters.rb', line 105 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 |
# File 'lib/phrase/models/styleguide_update_parameters.rb', line 86 def self.openapi_types { :'title' => :'String', :'audience' => :'String', :'target_audience' => :'String', :'grammatical_person' => :'String', :'vocabulary_type' => :'String', :'business' => :'String', :'company_branding' => :'String', :'formatting' => :'String', :'glossary_terms' => :'String', :'grammar_consistency' => :'String', :'literal_translation' => :'String', :'overall_tone' => :'String', :'samples' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 |
# File 'lib/phrase/models/styleguide_update_parameters.rb', line 229 def ==(o) return true if self.equal?(o) self.class == o.class && title == o.title && audience == o.audience && target_audience == o.target_audience && grammatical_person == o.grammatical_person && vocabulary_type == o.vocabulary_type && business == o.business && company_branding == o.company_branding && formatting == o.formatting && glossary_terms == o.glossary_terms && grammar_consistency == o.grammar_consistency && literal_translation == o.literal_translation && overall_tone == o.overall_tone && samples == o.samples end |
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type
290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 |
# File 'lib/phrase/models/styleguide_update_parameters.rb', line 290 def _deserialize(type, value) case type.to_sym when :DateTime DateTime.parse(value) when :Date Date.parse(value) when :Time Time.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model Phrase.const_get(type).build_from_hash(value) end end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
361 362 363 364 365 366 367 368 369 370 371 372 373 |
# File 'lib/phrase/models/styleguide_update_parameters.rb', line 361 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 |
# File 'lib/phrase/models/styleguide_update_parameters.rb', line 269 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.openapi_types.each_pair do |key, type| if type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) }) end elsif !attributes[self.class.attribute_map[key]].nil? self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]])) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(o) ⇒ Boolean
249 250 251 |
# File 'lib/phrase/models/styleguide_update_parameters.rb', line 249 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
255 256 257 |
# File 'lib/phrase/models/styleguide_update_parameters.rb', line 255 def hash [title, audience, target_audience, grammatical_person, vocabulary_type, business, company_branding, formatting, glossary_terms, grammar_consistency, literal_translation, overall_tone, samples].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
180 181 182 183 |
# File 'lib/phrase/models/styleguide_update_parameters.rb', line 180 def list_invalid_properties invalid_properties = Array.new invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
337 338 339 |
# File 'lib/phrase/models/styleguide_update_parameters.rb', line 337 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
343 344 345 346 347 348 349 350 351 352 353 354 355 |
# File 'lib/phrase/models/styleguide_update_parameters.rb', line 343 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
331 332 333 |
# File 'lib/phrase/models/styleguide_update_parameters.rb', line 331 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
187 188 189 190 191 192 193 194 195 |
# File 'lib/phrase/models/styleguide_update_parameters.rb', line 187 def valid? target_audience_validator = EnumAttributeValidator.new('String', ["not_specified", "children", "teenager", "young_adults", "adults", "old_adults"]) return false unless target_audience_validator.valid?(@target_audience) grammatical_person_validator = EnumAttributeValidator.new('String', ["not_specified", "first_person_singular", "second_person_singular", "third_person_singular_masculine", "third_person_singular_feminine", "third_person_singular_neuter", "first_person_plural", "second_person_plural", "third_person_plural"]) return false unless grammatical_person_validator.valid?(@grammatical_person) vocabulary_type_validator = EnumAttributeValidator.new('String', ["not_specified", "popular", "technical", "fictional"]) return false unless vocabulary_type_validator.valid?(@vocabulary_type) true end |