Class: Phrase::Tag
- Inherits:
-
Object
- Object
- Phrase::Tag
- Defined in:
- lib/phrase/models/tag.rb
Instance Attribute Summary collapse
-
#created_at ⇒ Object
Returns the value of attribute created_at.
-
#keys_count ⇒ Object
Returns the value of attribute keys_count.
-
#name ⇒ Object
Returns the value of attribute name.
-
#system_tag ⇒ Object
‘true` when the tag was created automatically by the system (e.g. for jobs, uploads, or Figma attachments) rather than by a user.
-
#updated_at ⇒ Object
Returns the value of attribute updated_at.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ Tag
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ Tag
Initializes the object
46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 |
# File 'lib/phrase/models/tag.rb', line 46 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Phrase::Tag` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| if (!self.class.attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Phrase::Tag`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'name') self.name = attributes[:'name'] end if attributes.key?(:'keys_count') self.keys_count = attributes[:'keys_count'] end if attributes.key?(:'system_tag') self.system_tag = attributes[:'system_tag'] end if attributes.key?(:'created_at') self.created_at = attributes[:'created_at'] end if attributes.key?(:'updated_at') self.updated_at = attributes[:'updated_at'] end end |
Instance Attribute Details
#created_at ⇒ Object
Returns the value of attribute created_at.
12 13 14 |
# File 'lib/phrase/models/tag.rb', line 12 def created_at @created_at end |
#keys_count ⇒ Object
Returns the value of attribute keys_count.
7 8 9 |
# File 'lib/phrase/models/tag.rb', line 7 def keys_count @keys_count end |
#name ⇒ Object
Returns the value of attribute name.
5 6 7 |
# File 'lib/phrase/models/tag.rb', line 5 def name @name end |
#system_tag ⇒ Object
‘true` when the tag was created automatically by the system (e.g. for jobs, uploads, or Figma attachments) rather than by a user.
10 11 12 |
# File 'lib/phrase/models/tag.rb', line 10 def system_tag @system_tag end |
#updated_at ⇒ Object
Returns the value of attribute updated_at.
14 15 16 |
# File 'lib/phrase/models/tag.rb', line 14 def updated_at @updated_at end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
17 18 19 20 21 22 23 24 25 |
# File 'lib/phrase/models/tag.rb', line 17 def self.attribute_map { :'name' => :'name', :'keys_count' => :'keys_count', :'system_tag' => :'system_tag', :'created_at' => :'created_at', :'updated_at' => :'updated_at' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
120 121 122 |
# File 'lib/phrase/models/tag.rb', line 120 def self.build_from_hash(attributes) new.build_from_hash(attributes) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
39 40 41 42 |
# File 'lib/phrase/models/tag.rb', line 39 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
28 29 30 31 32 33 34 35 36 |
# File 'lib/phrase/models/tag.rb', line 28 def self.openapi_types { :'name' => :'String', :'keys_count' => :'Integer', :'system_tag' => :'Boolean', :'created_at' => :'DateTime', :'updated_at' => :'DateTime' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
95 96 97 98 99 100 101 102 103 |
# File 'lib/phrase/models/tag.rb', line 95 def ==(o) return true if self.equal?(o) self.class == o.class && name == o.name && keys_count == o.keys_count && system_tag == o.system_tag && created_at == o.created_at && updated_at == o.updated_at end |
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type
148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 |
# File 'lib/phrase/models/tag.rb', line 148 def _deserialize(type, value) case type.to_sym when :DateTime DateTime.parse(value) when :Date Date.parse(value) when :Time Time.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model Phrase.const_get(type).build_from_hash(value) end end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
219 220 221 222 223 224 225 226 227 228 229 230 231 |
# File 'lib/phrase/models/tag.rb', line 219 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 |
# File 'lib/phrase/models/tag.rb', line 127 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.openapi_types.each_pair do |key, type| if type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) }) end elsif !attributes[self.class.attribute_map[key]].nil? self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]])) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(o) ⇒ Boolean
107 108 109 |
# File 'lib/phrase/models/tag.rb', line 107 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
113 114 115 |
# File 'lib/phrase/models/tag.rb', line 113 def hash [name, keys_count, system_tag, created_at, updated_at].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
82 83 84 85 |
# File 'lib/phrase/models/tag.rb', line 82 def list_invalid_properties invalid_properties = Array.new invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
195 196 197 |
# File 'lib/phrase/models/tag.rb', line 195 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
201 202 203 204 205 206 207 208 209 210 211 212 213 |
# File 'lib/phrase/models/tag.rb', line 201 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
189 190 191 |
# File 'lib/phrase/models/tag.rb', line 189 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
89 90 91 |
# File 'lib/phrase/models/tag.rb', line 89 def valid? true end |