Class: Phrase::TranslationOrder

Inherits:
Object
  • Object
show all
Defined in:
lib/phrase/models/translation_order.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ TranslationOrder

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
# File 'lib/phrase/models/translation_order.rb', line 98

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Phrase::TranslationOrder` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Phrase::TranslationOrder`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'id')
    self.id = attributes[:'id']
  end

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  end

  if attributes.key?(:'lsp')
    self.lsp = attributes[:'lsp']
  end

  if attributes.key?(:'amount_in_cents')
    self.amount_in_cents = attributes[:'amount_in_cents']
  end

  if attributes.key?(:'currency')
    self.currency = attributes[:'currency']
  end

  if attributes.key?(:'message')
    self.message = attributes[:'message']
  end

  if attributes.key?(:'state')
    self.state = attributes[:'state']
  end

  if attributes.key?(:'translation_type')
    self.translation_type = attributes[:'translation_type']
  end

  if attributes.key?(:'progress_percent')
    self.progress_percent = attributes[:'progress_percent']
  end

  if attributes.key?(:'source_locale')
    self.source_locale = attributes[:'source_locale']
  end

  if attributes.key?(:'target_locales')
    if (value = attributes[:'target_locales']).is_a?(Array)
      self.target_locales = value
    end
  end

  if attributes.key?(:'tag_name')
    self.tag_name = attributes[:'tag_name']
  end

  if attributes.key?(:'styleguide')
    self.styleguide = attributes[:'styleguide']
  end

  if attributes.key?(:'unverify_translations_upon_delivery')
    self.unverify_translations_upon_delivery = attributes[:'unverify_translations_upon_delivery']
  end

  if attributes.key?(:'quality')
    self.quality = attributes[:'quality']
  end

  if attributes.key?(:'priority')
    self.priority = attributes[:'priority']
  end

  if attributes.key?(:'created_at')
    self.created_at = attributes[:'created_at']
  end

  if attributes.key?(:'updated_at')
    self.updated_at = attributes[:'updated_at']
  end
end

Instance Attribute Details

#amount_in_centsObject

Returns the value of attribute amount_in_cents.



11
12
13
# File 'lib/phrase/models/translation_order.rb', line 11

def amount_in_cents
  @amount_in_cents
end

#created_atObject

Returns the value of attribute created_at.



38
39
40
# File 'lib/phrase/models/translation_order.rb', line 38

def created_at
  @created_at
end

#currencyObject

Returns the value of attribute currency.



13
14
15
# File 'lib/phrase/models/translation_order.rb', line 13

def currency
  @currency
end

#idObject

Returns the value of attribute id.



5
6
7
# File 'lib/phrase/models/translation_order.rb', line 5

def id
  @id
end

#lspObject

Returns the value of attribute lsp.



9
10
11
# File 'lib/phrase/models/translation_order.rb', line 9

def lsp
  @lsp
end

#messageObject

Returns the value of attribute message.



15
16
17
# File 'lib/phrase/models/translation_order.rb', line 15

def message
  @message
end

#nameObject

Returns the value of attribute name.



7
8
9
# File 'lib/phrase/models/translation_order.rb', line 7

def name
  @name
end

#priorityObject

Returns the value of attribute priority.



36
37
38
# File 'lib/phrase/models/translation_order.rb', line 36

def priority
  @priority
end

#progress_percentObject

Returns the value of attribute progress_percent.



21
22
23
# File 'lib/phrase/models/translation_order.rb', line 21

def progress_percent
  @progress_percent
end

#qualityObject

Returns the value of attribute quality.



34
35
36
# File 'lib/phrase/models/translation_order.rb', line 34

def quality
  @quality
end

#source_localeObject

Returns the value of attribute source_locale.



23
24
25
# File 'lib/phrase/models/translation_order.rb', line 23

def source_locale
  @source_locale
end

#stateObject

Returns the value of attribute state.



17
18
19
# File 'lib/phrase/models/translation_order.rb', line 17

def state
  @state
end

#styleguideObject

Returns the value of attribute styleguide.



30
31
32
# File 'lib/phrase/models/translation_order.rb', line 30

def styleguide
  @styleguide
end

#tag_nameObject

Name of the tag whose keys are included in the order.



28
29
30
# File 'lib/phrase/models/translation_order.rb', line 28

def tag_name
  @tag_name
end

#target_localesObject

Returns the value of attribute target_locales.



25
26
27
# File 'lib/phrase/models/translation_order.rb', line 25

def target_locales
  @target_locales
end

#translation_typeObject

Returns the value of attribute translation_type.



19
20
21
# File 'lib/phrase/models/translation_order.rb', line 19

def translation_type
  @translation_type
end

#unverify_translations_upon_deliveryObject

Returns the value of attribute unverify_translations_upon_delivery.



32
33
34
# File 'lib/phrase/models/translation_order.rb', line 32

def unverify_translations_upon_delivery
  @unverify_translations_upon_delivery
end

#updated_atObject

Returns the value of attribute updated_at.



40
41
42
# File 'lib/phrase/models/translation_order.rb', line 40

def updated_at
  @updated_at
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
# File 'lib/phrase/models/translation_order.rb', line 43

def self.attribute_map
  {
    :'id' => :'id',
    :'name' => :'name',
    :'lsp' => :'lsp',
    :'amount_in_cents' => :'amount_in_cents',
    :'currency' => :'currency',
    :'message' => :'message',
    :'state' => :'state',
    :'translation_type' => :'translation_type',
    :'progress_percent' => :'progress_percent',
    :'source_locale' => :'source_locale',
    :'target_locales' => :'target_locales',
    :'tag_name' => :'tag_name',
    :'styleguide' => :'styleguide',
    :'unverify_translations_upon_delivery' => :'unverify_translations_upon_delivery',
    :'quality' => :'quality',
    :'priority' => :'priority',
    :'created_at' => :'created_at',
    :'updated_at' => :'updated_at'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



239
240
241
# File 'lib/phrase/models/translation_order.rb', line 239

def self.build_from_hash(attributes)
  new.build_from_hash(attributes)
end

.openapi_nullableObject

List of attributes with nullable: true



91
92
93
94
# File 'lib/phrase/models/translation_order.rb', line 91

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
# File 'lib/phrase/models/translation_order.rb', line 67

def self.openapi_types
  {
    :'id' => :'String',
    :'name' => :'String',
    :'lsp' => :'String',
    :'amount_in_cents' => :'Integer',
    :'currency' => :'String',
    :'message' => :'String',
    :'state' => :'String',
    :'translation_type' => :'String',
    :'progress_percent' => :'Integer',
    :'source_locale' => :'LocalePreview',
    :'target_locales' => :'Array<LocalePreview>',
    :'tag_name' => :'String',
    :'styleguide' => :'StyleguidePreview',
    :'unverify_translations_upon_delivery' => :'Boolean',
    :'quality' => :'Boolean',
    :'priority' => :'Boolean',
    :'created_at' => :'DateTime',
    :'updated_at' => :'DateTime'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
# File 'lib/phrase/models/translation_order.rb', line 201

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      id == o.id &&
      name == o.name &&
      lsp == o.lsp &&
      amount_in_cents == o.amount_in_cents &&
      currency == o.currency &&
      message == o.message &&
      state == o.state &&
      translation_type == o.translation_type &&
      progress_percent == o.progress_percent &&
      source_locale == o.source_locale &&
      target_locales == o.target_locales &&
      tag_name == o.tag_name &&
      styleguide == o.styleguide &&
      unverify_translations_upon_delivery == o.unverify_translations_upon_delivery &&
      quality == o.quality &&
      priority == o.priority &&
      created_at == o.created_at &&
      updated_at == o.updated_at
end

#_deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
# File 'lib/phrase/models/translation_order.rb', line 267

def _deserialize(type, value)
  case type.to_sym
  when :DateTime
    DateTime.parse(value)
  when :Date
    Date.parse(value)
  when :Time
    Time.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    Phrase.const_get(type).build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



338
339
340
341
342
343
344
345
346
347
348
349
350
# File 'lib/phrase/models/translation_order.rb', line 338

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
# File 'lib/phrase/models/translation_order.rb', line 246

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  self.class.openapi_types.each_pair do |key, type|
    if type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) })
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]]))
    end # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


226
227
228
# File 'lib/phrase/models/translation_order.rb', line 226

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



232
233
234
# File 'lib/phrase/models/translation_order.rb', line 232

def hash
  [id, name, lsp, amount_in_cents, currency, message, state, translation_type, progress_percent, source_locale, target_locales, tag_name, styleguide, unverify_translations_upon_delivery, quality, priority, created_at, updated_at].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



188
189
190
191
# File 'lib/phrase/models/translation_order.rb', line 188

def list_invalid_properties
  invalid_properties = Array.new
  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



314
315
316
# File 'lib/phrase/models/translation_order.rb', line 314

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



320
321
322
323
324
325
326
327
328
329
330
331
332
# File 'lib/phrase/models/translation_order.rb', line 320

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



308
309
310
# File 'lib/phrase/models/translation_order.rb', line 308

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



195
196
197
# File 'lib/phrase/models/translation_order.rb', line 195

def valid?
  true
end