Class: Phrase::UploadSummary

Inherits:
Object
  • Object
show all
Defined in:
lib/phrase/models/upload_summary.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ UploadSummary

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
# File 'lib/phrase/models/upload_summary.rb', line 66

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Phrase::UploadSummary` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Phrase::UploadSummary`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'locales_created')
    self.locales_created = attributes[:'locales_created']
  end

  if attributes.key?(:'translation_keys_created')
    self.translation_keys_created = attributes[:'translation_keys_created']
  end

  if attributes.key?(:'translation_keys_updated')
    self.translation_keys_updated = attributes[:'translation_keys_updated']
  end

  if attributes.key?(:'translation_keys_unmentioned')
    self.translation_keys_unmentioned = attributes[:'translation_keys_unmentioned']
  end

  if attributes.key?(:'translations_created')
    self.translations_created = attributes[:'translations_created']
  end

  if attributes.key?(:'translations_updated')
    self.translations_updated = attributes[:'translations_updated']
  end

  if attributes.key?(:'tags_created')
    self.tags_created = attributes[:'tags_created']
  end

  if attributes.key?(:'translation_keys_ignored')
    self.translation_keys_ignored = attributes[:'translation_keys_ignored']
  end

  if attributes.key?(:'processed_translations')
    self.processed_translations = attributes[:'processed_translations']
  end

  if attributes.key?(:'upload_total_translations')
    self.upload_total_translations = attributes[:'upload_total_translations']
  end
end

Instance Attribute Details

#locales_createdObject

Returns the value of attribute locales_created.



5
6
7
# File 'lib/phrase/models/upload_summary.rb', line 5

def locales_created
  @locales_created
end

#processed_translationsObject

Returns the value of attribute processed_translations.



22
23
24
# File 'lib/phrase/models/upload_summary.rb', line 22

def processed_translations
  @processed_translations
end

#tags_createdObject

Returns the value of attribute tags_created.



18
19
20
# File 'lib/phrase/models/upload_summary.rb', line 18

def tags_created
  @tags_created
end

#translation_keys_createdObject

Returns the value of attribute translation_keys_created.



7
8
9
# File 'lib/phrase/models/upload_summary.rb', line 7

def translation_keys_created
  @translation_keys_created
end

#translation_keys_ignoredObject

Returns the value of attribute translation_keys_ignored.



20
21
22
# File 'lib/phrase/models/upload_summary.rb', line 20

def translation_keys_ignored
  @translation_keys_ignored
end

#translation_keys_unmentionedObject

The number of translation keys in the project that were not mentioned in the upload. Note: this field is not calculated (and shows 0) if the upload contains more than 10,000 keys.



12
13
14
# File 'lib/phrase/models/upload_summary.rb', line 12

def translation_keys_unmentioned
  @translation_keys_unmentioned
end

#translation_keys_updatedObject

Returns the value of attribute translation_keys_updated.



9
10
11
# File 'lib/phrase/models/upload_summary.rb', line 9

def translation_keys_updated
  @translation_keys_updated
end

#translations_createdObject

Returns the value of attribute translations_created.



14
15
16
# File 'lib/phrase/models/upload_summary.rb', line 14

def translations_created
  @translations_created
end

#translations_updatedObject

Returns the value of attribute translations_updated.



16
17
18
# File 'lib/phrase/models/upload_summary.rb', line 16

def translations_updated
  @translations_updated
end

#upload_total_translationsObject

Returns the value of attribute upload_total_translations.



24
25
26
# File 'lib/phrase/models/upload_summary.rb', line 24

def upload_total_translations
  @upload_total_translations
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



27
28
29
30
31
32
33
34
35
36
37
38
39
40
# File 'lib/phrase/models/upload_summary.rb', line 27

def self.attribute_map
  {
    :'locales_created' => :'locales_created',
    :'translation_keys_created' => :'translation_keys_created',
    :'translation_keys_updated' => :'translation_keys_updated',
    :'translation_keys_unmentioned' => :'translation_keys_unmentioned',
    :'translations_created' => :'translations_created',
    :'translations_updated' => :'translations_updated',
    :'tags_created' => :'tags_created',
    :'translation_keys_ignored' => :'translation_keys_ignored',
    :'processed_translations' => :'processed_translations',
    :'upload_total_translations' => :'upload_total_translations'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



165
166
167
# File 'lib/phrase/models/upload_summary.rb', line 165

def self.build_from_hash(attributes)
  new.build_from_hash(attributes)
end

.openapi_nullableObject

List of attributes with nullable: true



59
60
61
62
# File 'lib/phrase/models/upload_summary.rb', line 59

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



43
44
45
46
47
48
49
50
51
52
53
54
55
56
# File 'lib/phrase/models/upload_summary.rb', line 43

def self.openapi_types
  {
    :'locales_created' => :'Integer',
    :'translation_keys_created' => :'Integer',
    :'translation_keys_updated' => :'Integer',
    :'translation_keys_unmentioned' => :'Integer',
    :'translations_created' => :'Integer',
    :'translations_updated' => :'Integer',
    :'tags_created' => :'Integer',
    :'translation_keys_ignored' => :'Integer',
    :'processed_translations' => :'Integer',
    :'upload_total_translations' => :'Integer'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



135
136
137
138
139
140
141
142
143
144
145
146
147
148
# File 'lib/phrase/models/upload_summary.rb', line 135

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      locales_created == o.locales_created &&
      translation_keys_created == o.translation_keys_created &&
      translation_keys_updated == o.translation_keys_updated &&
      translation_keys_unmentioned == o.translation_keys_unmentioned &&
      translations_created == o.translations_created &&
      translations_updated == o.translations_updated &&
      tags_created == o.tags_created &&
      translation_keys_ignored == o.translation_keys_ignored &&
      processed_translations == o.processed_translations &&
      upload_total_translations == o.upload_total_translations
end

#_deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
# File 'lib/phrase/models/upload_summary.rb', line 193

def _deserialize(type, value)
  case type.to_sym
  when :DateTime
    DateTime.parse(value)
  when :Date
    Date.parse(value)
  when :Time
    Time.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    Phrase.const_get(type).build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



264
265
266
267
268
269
270
271
272
273
274
275
276
# File 'lib/phrase/models/upload_summary.rb', line 264

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
# File 'lib/phrase/models/upload_summary.rb', line 172

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  self.class.openapi_types.each_pair do |key, type|
    if type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) })
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]]))
    end # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


152
153
154
# File 'lib/phrase/models/upload_summary.rb', line 152

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



158
159
160
# File 'lib/phrase/models/upload_summary.rb', line 158

def hash
  [locales_created, translation_keys_created, translation_keys_updated, translation_keys_unmentioned, translations_created, translations_updated, tags_created, translation_keys_ignored, processed_translations, upload_total_translations].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



122
123
124
125
# File 'lib/phrase/models/upload_summary.rb', line 122

def list_invalid_properties
  invalid_properties = Array.new
  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



240
241
242
# File 'lib/phrase/models/upload_summary.rb', line 240

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



246
247
248
249
250
251
252
253
254
255
256
257
258
# File 'lib/phrase/models/upload_summary.rb', line 246

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



234
235
236
# File 'lib/phrase/models/upload_summary.rb', line 234

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



129
130
131
# File 'lib/phrase/models/upload_summary.rb', line 129

def valid?
  true
end