Class: Phrase::BranchesApi
- Inherits:
-
Object
- Object
- Phrase::BranchesApi
- Defined in:
- lib/phrase/api/branches_api.rb
Instance Attribute Summary collapse
-
#api_client ⇒ Object
Returns the value of attribute api_client.
Instance Method Summary collapse
-
#branch_compare(project_id, name, opts = {}) ⇒ nil
Compare branches Compare branch with main branch.
-
#branch_compare_with_http_info(project_id, name, opts = {}) ⇒ Array<(Response, Integer, Hash)>
Compare branches Compare branch with main branch.
-
#branch_comparison_create(project_id, name, branch_create_comparison_parameters, opts = {}) ⇒ nil
Create comparison (async.) Create a branch comparison asynchronously.
-
#branch_comparison_create_with_http_info(project_id, name, branch_create_comparison_parameters, opts = {}) ⇒ Array<(Response, Integer, Hash)>
Create comparison (async.) Create a branch comparison asynchronously.
-
#branch_create(project_id, branch_create_parameters, opts = {}) ⇒ Branch
Create a branch Create a new branch.
-
#branch_create_with_http_info(project_id, branch_create_parameters, opts = {}) ⇒ Array<(Response<(Branch)>, Integer, Hash)>
Create a branch Create a new branch.
-
#branch_delete(project_id, name, opts = {}) ⇒ nil
Delete a branch Delete an existing branch.
-
#branch_delete_with_http_info(project_id, name, opts = {}) ⇒ Array<(Response, Integer, Hash)>
Delete a branch Delete an existing branch.
-
#branch_merge(project_id, name, branch_merge_parameters, opts = {}) ⇒ nil
Merge a branch Merge an existing branch.
-
#branch_merge_with_http_info(project_id, name, branch_merge_parameters, opts = {}) ⇒ Array<(Response, Integer, Hash)>
Merge a branch Merge an existing branch.
-
#branch_show(project_id, name, opts = {}) ⇒ Branch
Get a single branch Get details on a single branch for a given project.
-
#branch_show_with_http_info(project_id, name, opts = {}) ⇒ Array<(Response<(Branch)>, Integer, Hash)>
Get a single branch Get details on a single branch for a given project.
-
#branch_sync(project_id, name, branch_sync_parameters, opts = {}) ⇒ nil
Sync a branch Sync an existing branch.
-
#branch_sync_with_http_info(project_id, name, branch_sync_parameters, opts = {}) ⇒ Array<(Response, Integer, Hash)>
Sync a branch Sync an existing branch.
-
#branch_update(project_id, name, branch_update_parameters, opts = {}) ⇒ Branch
Update a branch Update an existing branch.
-
#branch_update_with_http_info(project_id, name, branch_update_parameters, opts = {}) ⇒ Array<(Response<(Branch)>, Integer, Hash)>
Update a branch Update an existing branch.
-
#branches_list(project_id, opts = {}) ⇒ Array<Branch>
List branches List all branches the of the current project.
-
#branches_list_with_http_info(project_id, opts = {}) ⇒ Array<(Response<(Array<Branch>)>, Integer, Hash)>
List branches List all branches the of the current project.
-
#initialize(api_client = ApiClient.default) ⇒ BranchesApi
constructor
A new instance of BranchesApi.
Constructor Details
#initialize(api_client = ApiClient.default) ⇒ BranchesApi
Returns a new instance of BranchesApi.
7 8 9 |
# File 'lib/phrase/api/branches_api.rb', line 7 def initialize(api_client = ApiClient.default) @api_client = api_client end |
Instance Attribute Details
#api_client ⇒ Object
Returns the value of attribute api_client.
5 6 7 |
# File 'lib/phrase/api/branches_api.rb', line 5 def api_client @api_client end |
Instance Method Details
#branch_compare(project_id, name, opts = {}) ⇒ nil
Compare branches Compare branch with main branch. *Note: Comparing a branch may take several minutes depending on the project size. Consider using the ‘POST /compare` endpoint for creating comparison asynchronously.*
17 18 19 20 |
# File 'lib/phrase/api/branches_api.rb', line 17 def branch_compare(project_id, name, opts = {}) data, _status_code, _headers = branch_compare_with_http_info(project_id, name, opts) data end |
#branch_compare_with_http_info(project_id, name, opts = {}) ⇒ Array<(Response, Integer, Hash)>
Compare branches Compare branch with main branch. *Note: Comparing a branch may take several minutes depending on the project size. Consider using the `POST /compare` endpoint for creating comparison asynchronously.*
29 30 31 32 33 34 35 36 37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 |
# File 'lib/phrase/api/branches_api.rb', line 29 def branch_compare_with_http_info(project_id, name, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: BranchesApi.branch_compare ...' end # verify the required parameter 'project_id' is set if @api_client.config.client_side_validation && project_id.nil? fail ArgumentError, "Missing the required parameter 'project_id' when calling BranchesApi.branch_compare" end # verify the required parameter 'name' is set if @api_client.config.client_side_validation && name.nil? fail ArgumentError, "Missing the required parameter 'name' when calling BranchesApi.branch_compare" end # resource path local_var_path = '/projects/{project_id}/branches/{name}/compare'.sub('{' + 'project_id' + '}', CGI.escape(project_id.to_s)).sub('{' + 'name' + '}', CGI.escape(name.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} header_params[:'X-PhraseApp-OTP'] = opts[:'x_phrase_app_otp'] if !opts[:'x_phrase_app_otp'].nil? # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:body] # return_type return_type = opts[:return_type] # auth_names auth_names = opts[:auth_names] || ['Basic', 'Token'] = opts.merge( :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: BranchesApi#branch_compare\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end response = ::Phrase::Response.new(data, headers) return response, status_code, headers end |
#branch_comparison_create(project_id, name, branch_create_comparison_parameters, opts = {}) ⇒ nil
Create comparison (async.) Create a branch comparison asynchronously.
88 89 90 91 |
# File 'lib/phrase/api/branches_api.rb', line 88 def branch_comparison_create(project_id, name, branch_create_comparison_parameters, opts = {}) data, _status_code, _headers = branch_comparison_create_with_http_info(project_id, name, branch_create_comparison_parameters, opts) data end |
#branch_comparison_create_with_http_info(project_id, name, branch_create_comparison_parameters, opts = {}) ⇒ Array<(Response, Integer, Hash)>
Create comparison (async.) Create a branch comparison asynchronously.
101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 |
# File 'lib/phrase/api/branches_api.rb', line 101 def branch_comparison_create_with_http_info(project_id, name, branch_create_comparison_parameters, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: BranchesApi.branch_comparison_create ...' end # verify the required parameter 'project_id' is set if @api_client.config.client_side_validation && project_id.nil? fail ArgumentError, "Missing the required parameter 'project_id' when calling BranchesApi.branch_comparison_create" end # verify the required parameter 'name' is set if @api_client.config.client_side_validation && name.nil? fail ArgumentError, "Missing the required parameter 'name' when calling BranchesApi.branch_comparison_create" end # verify the required parameter 'branch_create_comparison_parameters' is set if @api_client.config.client_side_validation && branch_create_comparison_parameters.nil? fail ArgumentError, "Missing the required parameter 'branch_create_comparison_parameters' when calling BranchesApi.branch_comparison_create" end # resource path local_var_path = '/projects/{project_id}/branches/{name}/compare'.sub('{' + 'project_id' + '}', CGI.escape(project_id.to_s)).sub('{' + 'name' + '}', CGI.escape(name.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Content-Type' header_params['Content-Type'] = @api_client.select_header_content_type(['application/json']) header_params[:'X-PhraseApp-OTP'] = opts[:'x_phrase_app_otp'] if !opts[:'x_phrase_app_otp'].nil? # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:body] || @api_client.object_to_http_body(branch_create_comparison_parameters) # return_type return_type = opts[:return_type] # auth_names auth_names = opts[:auth_names] || ['Basic', 'Token'] = opts.merge( :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:POST, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: BranchesApi#branch_comparison_create\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end response = ::Phrase::Response.new(data, headers) return response, status_code, headers end |
#branch_create(project_id, branch_create_parameters, opts = {}) ⇒ Branch
Create a branch Create a new branch. *Note: Creating a new branch may take several minutes depending on the project size.*
165 166 167 168 |
# File 'lib/phrase/api/branches_api.rb', line 165 def branch_create(project_id, branch_create_parameters, opts = {}) data, _status_code, _headers = branch_create_with_http_info(project_id, branch_create_parameters, opts) data end |
#branch_create_with_http_info(project_id, branch_create_parameters, opts = {}) ⇒ Array<(Response<(Branch)>, Integer, Hash)>
Create a branch Create a new branch. *Note: Creating a new branch may take several minutes depending on the project size.*
177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 |
# File 'lib/phrase/api/branches_api.rb', line 177 def branch_create_with_http_info(project_id, branch_create_parameters, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: BranchesApi.branch_create ...' end # verify the required parameter 'project_id' is set if @api_client.config.client_side_validation && project_id.nil? fail ArgumentError, "Missing the required parameter 'project_id' when calling BranchesApi.branch_create" end # verify the required parameter 'branch_create_parameters' is set if @api_client.config.client_side_validation && branch_create_parameters.nil? fail ArgumentError, "Missing the required parameter 'branch_create_parameters' when calling BranchesApi.branch_create" end # resource path local_var_path = '/projects/{project_id}/branches'.sub('{' + 'project_id' + '}', CGI.escape(project_id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # HTTP header 'Content-Type' header_params['Content-Type'] = @api_client.select_header_content_type(['application/json']) header_params[:'X-PhraseApp-OTP'] = opts[:'x_phrase_app_otp'] if !opts[:'x_phrase_app_otp'].nil? # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:body] || @api_client.object_to_http_body(branch_create_parameters) # return_type return_type = opts[:return_type] || 'Branch' # auth_names auth_names = opts[:auth_names] || ['Basic', 'Token'] = opts.merge( :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:POST, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: BranchesApi#branch_create\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end response = ::Phrase::Response.new(data, headers) return response, status_code, headers end |
#branch_delete(project_id, name, opts = {}) ⇒ nil
Delete a branch Delete an existing branch.
239 240 241 242 |
# File 'lib/phrase/api/branches_api.rb', line 239 def branch_delete(project_id, name, opts = {}) data, _status_code, _headers = branch_delete_with_http_info(project_id, name, opts) data end |
#branch_delete_with_http_info(project_id, name, opts = {}) ⇒ Array<(Response, Integer, Hash)>
Delete a branch Delete an existing branch.
251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 |
# File 'lib/phrase/api/branches_api.rb', line 251 def branch_delete_with_http_info(project_id, name, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: BranchesApi.branch_delete ...' end # verify the required parameter 'project_id' is set if @api_client.config.client_side_validation && project_id.nil? fail ArgumentError, "Missing the required parameter 'project_id' when calling BranchesApi.branch_delete" end # verify the required parameter 'name' is set if @api_client.config.client_side_validation && name.nil? fail ArgumentError, "Missing the required parameter 'name' when calling BranchesApi.branch_delete" end # resource path local_var_path = '/projects/{project_id}/branches/{name}'.sub('{' + 'project_id' + '}', CGI.escape(project_id.to_s)).sub('{' + 'name' + '}', CGI.escape(name.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} header_params[:'X-PhraseApp-OTP'] = opts[:'x_phrase_app_otp'] if !opts[:'x_phrase_app_otp'].nil? # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:body] # return_type return_type = opts[:return_type] # auth_names auth_names = opts[:auth_names] || ['Basic', 'Token'] = opts.merge( :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:DELETE, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: BranchesApi#branch_delete\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end response = ::Phrase::Response.new(data, headers) return response, status_code, headers end |
#branch_merge(project_id, name, branch_merge_parameters, opts = {}) ⇒ nil
Merge a branch Merge an existing branch. *Note: Merging a branch may take several minutes depending on diff size.*
310 311 312 313 |
# File 'lib/phrase/api/branches_api.rb', line 310 def branch_merge(project_id, name, branch_merge_parameters, opts = {}) data, _status_code, _headers = branch_merge_with_http_info(project_id, name, branch_merge_parameters, opts) data end |
#branch_merge_with_http_info(project_id, name, branch_merge_parameters, opts = {}) ⇒ Array<(Response, Integer, Hash)>
Merge a branch Merge an existing branch. *Note: Merging a branch may take several minutes depending on diff size.*
323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 350 351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 |
# File 'lib/phrase/api/branches_api.rb', line 323 def branch_merge_with_http_info(project_id, name, branch_merge_parameters, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: BranchesApi.branch_merge ...' end # verify the required parameter 'project_id' is set if @api_client.config.client_side_validation && project_id.nil? fail ArgumentError, "Missing the required parameter 'project_id' when calling BranchesApi.branch_merge" end # verify the required parameter 'name' is set if @api_client.config.client_side_validation && name.nil? fail ArgumentError, "Missing the required parameter 'name' when calling BranchesApi.branch_merge" end # verify the required parameter 'branch_merge_parameters' is set if @api_client.config.client_side_validation && branch_merge_parameters.nil? fail ArgumentError, "Missing the required parameter 'branch_merge_parameters' when calling BranchesApi.branch_merge" end # resource path local_var_path = '/projects/{project_id}/branches/{name}/merge'.sub('{' + 'project_id' + '}', CGI.escape(project_id.to_s)).sub('{' + 'name' + '}', CGI.escape(name.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Content-Type' header_params['Content-Type'] = @api_client.select_header_content_type(['application/json']) header_params[:'X-PhraseApp-OTP'] = opts[:'x_phrase_app_otp'] if !opts[:'x_phrase_app_otp'].nil? # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:body] || @api_client.object_to_http_body(branch_merge_parameters) # return_type return_type = opts[:return_type] # auth_names auth_names = opts[:auth_names] || ['Basic', 'Token'] = opts.merge( :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:PATCH, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: BranchesApi#branch_merge\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end response = ::Phrase::Response.new(data, headers) return response, status_code, headers end |
#branch_show(project_id, name, opts = {}) ⇒ Branch
Get a single branch Get details on a single branch for a given project.
387 388 389 390 |
# File 'lib/phrase/api/branches_api.rb', line 387 def branch_show(project_id, name, opts = {}) data, _status_code, _headers = branch_show_with_http_info(project_id, name, opts) data end |
#branch_show_with_http_info(project_id, name, opts = {}) ⇒ Array<(Response<(Branch)>, Integer, Hash)>
Get a single branch Get details on a single branch for a given project.
399 400 401 402 403 404 405 406 407 408 409 410 411 412 413 414 415 416 417 418 419 420 421 422 423 424 425 426 427 428 429 430 431 432 433 434 435 436 437 438 439 440 441 442 443 444 445 446 447 448 449 450 |
# File 'lib/phrase/api/branches_api.rb', line 399 def branch_show_with_http_info(project_id, name, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: BranchesApi.branch_show ...' end # verify the required parameter 'project_id' is set if @api_client.config.client_side_validation && project_id.nil? fail ArgumentError, "Missing the required parameter 'project_id' when calling BranchesApi.branch_show" end # verify the required parameter 'name' is set if @api_client.config.client_side_validation && name.nil? fail ArgumentError, "Missing the required parameter 'name' when calling BranchesApi.branch_show" end # resource path local_var_path = '/projects/{project_id}/branches/{name}'.sub('{' + 'project_id' + '}', CGI.escape(project_id.to_s)).sub('{' + 'name' + '}', CGI.escape(name.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) header_params[:'X-PhraseApp-OTP'] = opts[:'x_phrase_app_otp'] if !opts[:'x_phrase_app_otp'].nil? # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:body] # return_type return_type = opts[:return_type] || 'Branch' # auth_names auth_names = opts[:auth_names] || ['Basic', 'Token'] = opts.merge( :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: BranchesApi#branch_show\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end response = ::Phrase::Response.new(data, headers) return response, status_code, headers end |
#branch_sync(project_id, name, branch_sync_parameters, opts = {}) ⇒ nil
Sync a branch Sync an existing branch. *Note: Only available for branches created with new branching.*
460 461 462 463 |
# File 'lib/phrase/api/branches_api.rb', line 460 def branch_sync(project_id, name, branch_sync_parameters, opts = {}) data, _status_code, _headers = branch_sync_with_http_info(project_id, name, branch_sync_parameters, opts) data end |
#branch_sync_with_http_info(project_id, name, branch_sync_parameters, opts = {}) ⇒ Array<(Response, Integer, Hash)>
Sync a branch Sync an existing branch. *Note: Only available for branches created with new branching.*
473 474 475 476 477 478 479 480 481 482 483 484 485 486 487 488 489 490 491 492 493 494 495 496 497 498 499 500 501 502 503 504 505 506 507 508 509 510 511 512 513 514 515 516 517 518 519 520 521 522 523 524 525 526 527 528 |
# File 'lib/phrase/api/branches_api.rb', line 473 def branch_sync_with_http_info(project_id, name, branch_sync_parameters, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: BranchesApi.branch_sync ...' end # verify the required parameter 'project_id' is set if @api_client.config.client_side_validation && project_id.nil? fail ArgumentError, "Missing the required parameter 'project_id' when calling BranchesApi.branch_sync" end # verify the required parameter 'name' is set if @api_client.config.client_side_validation && name.nil? fail ArgumentError, "Missing the required parameter 'name' when calling BranchesApi.branch_sync" end # verify the required parameter 'branch_sync_parameters' is set if @api_client.config.client_side_validation && branch_sync_parameters.nil? fail ArgumentError, "Missing the required parameter 'branch_sync_parameters' when calling BranchesApi.branch_sync" end # resource path local_var_path = '/projects/{project_id}/branches/{name}/sync'.sub('{' + 'project_id' + '}', CGI.escape(project_id.to_s)).sub('{' + 'name' + '}', CGI.escape(name.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Content-Type' header_params['Content-Type'] = @api_client.select_header_content_type(['application/json']) header_params[:'X-PhraseApp-OTP'] = opts[:'x_phrase_app_otp'] if !opts[:'x_phrase_app_otp'].nil? # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:body] || @api_client.object_to_http_body(branch_sync_parameters) # return_type return_type = opts[:return_type] # auth_names auth_names = opts[:auth_names] || ['Basic', 'Token'] = opts.merge( :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:PATCH, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: BranchesApi#branch_sync\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end response = ::Phrase::Response.new(data, headers) return response, status_code, headers end |
#branch_update(project_id, name, branch_update_parameters, opts = {}) ⇒ Branch
Update a branch Update an existing branch.
538 539 540 541 |
# File 'lib/phrase/api/branches_api.rb', line 538 def branch_update(project_id, name, branch_update_parameters, opts = {}) data, _status_code, _headers = branch_update_with_http_info(project_id, name, branch_update_parameters, opts) data end |
#branch_update_with_http_info(project_id, name, branch_update_parameters, opts = {}) ⇒ Array<(Response<(Branch)>, Integer, Hash)>
Update a branch Update an existing branch.
551 552 553 554 555 556 557 558 559 560 561 562 563 564 565 566 567 568 569 570 571 572 573 574 575 576 577 578 579 580 581 582 583 584 585 586 587 588 589 590 591 592 593 594 595 596 597 598 599 600 601 602 603 604 605 606 607 608 |
# File 'lib/phrase/api/branches_api.rb', line 551 def branch_update_with_http_info(project_id, name, branch_update_parameters, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: BranchesApi.branch_update ...' end # verify the required parameter 'project_id' is set if @api_client.config.client_side_validation && project_id.nil? fail ArgumentError, "Missing the required parameter 'project_id' when calling BranchesApi.branch_update" end # verify the required parameter 'name' is set if @api_client.config.client_side_validation && name.nil? fail ArgumentError, "Missing the required parameter 'name' when calling BranchesApi.branch_update" end # verify the required parameter 'branch_update_parameters' is set if @api_client.config.client_side_validation && branch_update_parameters.nil? fail ArgumentError, "Missing the required parameter 'branch_update_parameters' when calling BranchesApi.branch_update" end # resource path local_var_path = '/projects/{project_id}/branches/{name}'.sub('{' + 'project_id' + '}', CGI.escape(project_id.to_s)).sub('{' + 'name' + '}', CGI.escape(name.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # HTTP header 'Content-Type' header_params['Content-Type'] = @api_client.select_header_content_type(['application/json']) header_params[:'X-PhraseApp-OTP'] = opts[:'x_phrase_app_otp'] if !opts[:'x_phrase_app_otp'].nil? # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:body] || @api_client.object_to_http_body(branch_update_parameters) # return_type return_type = opts[:return_type] || 'Branch' # auth_names auth_names = opts[:auth_names] || ['Basic', 'Token'] = opts.merge( :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:PATCH, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: BranchesApi#branch_update\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end response = ::Phrase::Response.new(data, headers) return response, status_code, headers end |
#branches_list(project_id, opts = {}) ⇒ Array<Branch>
List branches List all branches the of the current project.
618 619 620 621 |
# File 'lib/phrase/api/branches_api.rb', line 618 def branches_list(project_id, opts = {}) data, _status_code, _headers = branches_list_with_http_info(project_id, opts) data end |
#branches_list_with_http_info(project_id, opts = {}) ⇒ Array<(Response<(Array<Branch>)>, Integer, Hash)>
List branches List all branches the of the current project.
631 632 633 634 635 636 637 638 639 640 641 642 643 644 645 646 647 648 649 650 651 652 653 654 655 656 657 658 659 660 661 662 663 664 665 666 667 668 669 670 671 672 673 674 675 676 677 678 679 680 |
# File 'lib/phrase/api/branches_api.rb', line 631 def branches_list_with_http_info(project_id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: BranchesApi.branches_list ...' end # verify the required parameter 'project_id' is set if @api_client.config.client_side_validation && project_id.nil? fail ArgumentError, "Missing the required parameter 'project_id' when calling BranchesApi.branches_list" end # resource path local_var_path = '/projects/{project_id}/branches'.sub('{' + 'project_id' + '}', CGI.escape(project_id.to_s)) # query parameters query_params = opts[:query_params] || {} query_params[:'page'] = opts[:'page'] if !opts[:'page'].nil? query_params[:'per_page'] = opts[:'per_page'] if !opts[:'per_page'].nil? # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) header_params[:'X-PhraseApp-OTP'] = opts[:'x_phrase_app_otp'] if !opts[:'x_phrase_app_otp'].nil? # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:body] # return_type return_type = opts[:return_type] || 'Array<Branch>' # auth_names auth_names = opts[:auth_names] || ['Basic', 'Token'] = opts.merge( :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: BranchesApi#branches_list\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end response = ::Phrase::Response.new(data, headers) return response, status_code, headers end |