Class: Phrase::ChecksApi
- Inherits:
-
Object
- Object
- Phrase::ChecksApi
- Defined in:
- lib/phrase/api/checks_api.rb
Instance Attribute Summary collapse
-
#api_client ⇒ Object
Returns the value of attribute api_client.
Instance Method Summary collapse
-
#check_issue_dismiss(project_id, id, opts = {}) ⇒ CheckIssue
Dismiss a check issue Note: The Checks API is still in development and might change in subsequent releases.
-
#check_issue_dismiss_with_http_info(project_id, id, opts = {}) ⇒ Array<(Response<(CheckIssue)>, Integer, Hash)>
Dismiss a check issue Note: The Checks API is still in development and might change in subsequent releases.
-
#check_issues_list(project_id, opts = {}) ⇒ Array<CheckIssue>
List check issues Note: The Checks API is still in development and might change in subsequent releases.
-
#check_issues_list_with_http_info(project_id, opts = {}) ⇒ Array<(Response<(Array<CheckIssue>)>, Integer, Hash)>
List check issues Note: The Checks API is still in development and might change in subsequent releases.
-
#initialize(api_client = ApiClient.default) ⇒ ChecksApi
constructor
A new instance of ChecksApi.
Constructor Details
#initialize(api_client = ApiClient.default) ⇒ ChecksApi
Returns a new instance of ChecksApi.
7 8 9 |
# File 'lib/phrase/api/checks_api.rb', line 7 def initialize(api_client = ApiClient.default) @api_client = api_client end |
Instance Attribute Details
#api_client ⇒ Object
Returns the value of attribute api_client.
5 6 7 |
# File 'lib/phrase/api/checks_api.rb', line 5 def api_client @api_client end |
Instance Method Details
#check_issue_dismiss(project_id, id, opts = {}) ⇒ CheckIssue
Dismiss a check issue Note: The Checks API is still in development and might change in subsequent releases. Mark a check issue as dismissed so it no longer appears on the list of active check issues.
17 18 19 20 |
# File 'lib/phrase/api/checks_api.rb', line 17 def check_issue_dismiss(project_id, id, opts = {}) data, _status_code, _headers = check_issue_dismiss_with_http_info(project_id, id, opts) data end |
#check_issue_dismiss_with_http_info(project_id, id, opts = {}) ⇒ Array<(Response<(CheckIssue)>, Integer, Hash)>
Dismiss a check issue Note: The Checks API is still in development and might change in subsequent releases. Mark a check issue as dismissed so it no longer appears on the list of active check issues.
29 30 31 32 33 34 35 36 37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 |
# File 'lib/phrase/api/checks_api.rb', line 29 def check_issue_dismiss_with_http_info(project_id, id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: ChecksApi.check_issue_dismiss ...' end # verify the required parameter 'project_id' is set if @api_client.config.client_side_validation && project_id.nil? fail ArgumentError, "Missing the required parameter 'project_id' when calling ChecksApi.check_issue_dismiss" end # verify the required parameter 'id' is set if @api_client.config.client_side_validation && id.nil? fail ArgumentError, "Missing the required parameter 'id' when calling ChecksApi.check_issue_dismiss" end # resource path local_var_path = '/projects/{project_id}/checks/issues/{id}/dismiss'.sub('{' + 'project_id' + '}', CGI.escape(project_id.to_s)).sub('{' + 'id' + '}', CGI.escape(id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) header_params[:'X-PhraseApp-OTP'] = opts[:'x_phrase_app_otp'] if !opts[:'x_phrase_app_otp'].nil? # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:body] # return_type return_type = opts[:return_type] || 'CheckIssue' # auth_names auth_names = opts[:auth_names] || ['Basic', 'Token'] = opts.merge( :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:PATCH, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: ChecksApi#check_issue_dismiss\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end response = ::Phrase::Response.new(data, headers) return response, status_code, headers end |
#check_issues_list(project_id, opts = {}) ⇒ Array<CheckIssue>
List check issues Note: The Checks API is still in development and might change in subsequent releases. List check issues for the given project. Results can be filtered by locale, check name, and state.
94 95 96 97 |
# File 'lib/phrase/api/checks_api.rb', line 94 def check_issues_list(project_id, opts = {}) data, _status_code, _headers = check_issues_list_with_http_info(project_id, opts) data end |
#check_issues_list_with_http_info(project_id, opts = {}) ⇒ Array<(Response<(Array<CheckIssue>)>, Integer, Hash)>
List check issues Note: The Checks API is still in development and might change in subsequent releases. List check issues for the given project. Results can be filtered by locale, check name, and state.
111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 |
# File 'lib/phrase/api/checks_api.rb', line 111 def check_issues_list_with_http_info(project_id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: ChecksApi.check_issues_list ...' end # verify the required parameter 'project_id' is set if @api_client.config.client_side_validation && project_id.nil? fail ArgumentError, "Missing the required parameter 'project_id' when calling ChecksApi.check_issues_list" end allowable_values = ["active", "solved", "dismissed", "all"] if @api_client.config.client_side_validation && opts[:'state'] && !allowable_values.include?(opts[:'state']) fail ArgumentError, "invalid value for \"state\", must be one of #{allowable_values}" end allowable_values = ["translation_content_length", "translation_placeholder_usage", "translation_glossary_usage"] if @api_client.config.client_side_validation && opts[:'check_names'] && !opts[:'check_names'].all? { |item| allowable_values.include?(item) } fail ArgumentError, "invalid value for \"check_names\", must include one of #{allowable_values}" end # resource path local_var_path = '/projects/{project_id}/checks/issues'.sub('{' + 'project_id' + '}', CGI.escape(project_id.to_s)) # query parameters query_params = opts[:query_params] || {} query_params[:'page'] = opts[:'page'] if !opts[:'page'].nil? query_params[:'per_page'] = opts[:'per_page'] if !opts[:'per_page'].nil? query_params[:'state'] = opts[:'state'] if !opts[:'state'].nil? query_params[:'locale_ids'] = @api_client.build_collection_param(opts[:'locale_ids'], :multi) if !opts[:'locale_ids'].nil? query_params[:'check_names'] = @api_client.build_collection_param(opts[:'check_names'], :multi) if !opts[:'check_names'].nil? query_params[:'created_since'] = opts[:'created_since'] if !opts[:'created_since'].nil? # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) header_params[:'X-PhraseApp-OTP'] = opts[:'x_phrase_app_otp'] if !opts[:'x_phrase_app_otp'].nil? # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:body] # return_type return_type = opts[:return_type] || 'Array<CheckIssue>' # auth_names auth_names = opts[:auth_names] || ['Basic', 'Token'] = opts.merge( :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: ChecksApi#check_issues_list\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end response = ::Phrase::Response.new(data, headers) return response, status_code, headers end |