Class: Phrase::JobDetails
- Inherits:
-
Object
- Object
- Phrase::JobDetails
- Defined in:
- lib/phrase/models/job_details.rb
Instance Attribute Summary collapse
-
#annotations ⇒ Object
Returned only when ‘include_annotations=true` is supplied on the request.
-
#automation_id ⇒ Object
The ID of the automation that created this job, or null if the job was created manually.
-
#branch ⇒ Object
Returns the value of attribute branch.
-
#briefing ⇒ Object
Returns the value of attribute briefing.
-
#created_at ⇒ Object
Returns the value of attribute created_at.
-
#due_date ⇒ Object
Returns the value of attribute due_date.
-
#id ⇒ Object
Returns the value of attribute id.
-
#job_tag_name ⇒ Object
Returns the value of attribute job_tag_name.
-
#job_template_id ⇒ Object
The ID of the job template this job was created from, or null if no template was used.
-
#keys ⇒ Object
Returns the value of attribute keys.
-
#locales ⇒ Object
Returns the value of attribute locales.
-
#locked ⇒ Object
‘true` if the job has been locked by the project’s job-locking workflow (translations attached to the job are read-only until the job advances).
-
#name ⇒ Object
Returns the value of attribute name.
-
#owner ⇒ Object
Returns the value of attribute owner.
-
#project ⇒ Object
Returns the value of attribute project.
-
#source_locale ⇒ Object
Returns the value of attribute source_locale.
-
#source_translations_updated_at ⇒ Object
Returns the value of attribute source_translations_updated_at.
-
#state ⇒ Object
Returns the value of attribute state.
-
#ticket_url ⇒ Object
Returns the value of attribute ticket_url.
-
#updated_at ⇒ Object
Returns the value of attribute updated_at.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_all_of ⇒ Object
List of class defined in allOf (OpenAPI v3).
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ JobDetails
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ JobDetails
Initializes the object
119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 |
# File 'lib/phrase/models/job_details.rb', line 119 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Phrase::JobDetails` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| if (!self.class.attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Phrase::JobDetails`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'id') self.id = attributes[:'id'] end if attributes.key?(:'name') self.name = attributes[:'name'] end if attributes.key?(:'briefing') self.briefing = attributes[:'briefing'] end if attributes.key?(:'due_date') self.due_date = attributes[:'due_date'] end if attributes.key?(:'state') self.state = attributes[:'state'] end if attributes.key?(:'ticket_url') self.ticket_url = attributes[:'ticket_url'] end if attributes.key?(:'project') self.project = attributes[:'project'] end if attributes.key?(:'branch') self.branch = attributes[:'branch'] end if attributes.key?(:'created_at') self.created_at = attributes[:'created_at'] end if attributes.key?(:'updated_at') self.updated_at = attributes[:'updated_at'] end if attributes.key?(:'automation_id') self.automation_id = attributes[:'automation_id'] end if attributes.key?(:'job_template_id') self.job_template_id = attributes[:'job_template_id'] end if attributes.key?(:'owner') self.owner = attributes[:'owner'] end if attributes.key?(:'job_tag_name') self.job_tag_name = attributes[:'job_tag_name'] end if attributes.key?(:'source_translations_updated_at') self.source_translations_updated_at = attributes[:'source_translations_updated_at'] end if attributes.key?(:'source_locale') self.source_locale = attributes[:'source_locale'] end if attributes.key?(:'locales') if (value = attributes[:'locales']).is_a?(Array) self.locales = value end end if attributes.key?(:'keys') if (value = attributes[:'keys']).is_a?(Array) self.keys = value end end if attributes.key?(:'annotations') if (value = attributes[:'annotations']).is_a?(Array) self.annotations = value end end if attributes.key?(:'locked') self.locked = attributes[:'locked'] end end |
Instance Attribute Details
#annotations ⇒ Object
Returned only when ‘include_annotations=true` is supplied on the request.
44 45 46 |
# File 'lib/phrase/models/job_details.rb', line 44 def annotations @annotations end |
#automation_id ⇒ Object
The ID of the automation that created this job, or null if the job was created manually.
26 27 28 |
# File 'lib/phrase/models/job_details.rb', line 26 def automation_id @automation_id end |
#branch ⇒ Object
Returns the value of attribute branch.
19 20 21 |
# File 'lib/phrase/models/job_details.rb', line 19 def branch @branch end |
#briefing ⇒ Object
Returns the value of attribute briefing.
9 10 11 |
# File 'lib/phrase/models/job_details.rb', line 9 def briefing @briefing end |
#created_at ⇒ Object
Returns the value of attribute created_at.
21 22 23 |
# File 'lib/phrase/models/job_details.rb', line 21 def created_at @created_at end |
#due_date ⇒ Object
Returns the value of attribute due_date.
11 12 13 |
# File 'lib/phrase/models/job_details.rb', line 11 def due_date @due_date end |
#id ⇒ Object
Returns the value of attribute id.
5 6 7 |
# File 'lib/phrase/models/job_details.rb', line 5 def id @id end |
#job_tag_name ⇒ Object
Returns the value of attribute job_tag_name.
33 34 35 |
# File 'lib/phrase/models/job_details.rb', line 33 def job_tag_name @job_tag_name end |
#job_template_id ⇒ Object
The ID of the job template this job was created from, or null if no template was used.
29 30 31 |
# File 'lib/phrase/models/job_details.rb', line 29 def job_template_id @job_template_id end |
#keys ⇒ Object
Returns the value of attribute keys.
41 42 43 |
# File 'lib/phrase/models/job_details.rb', line 41 def keys @keys end |
#locales ⇒ Object
Returns the value of attribute locales.
39 40 41 |
# File 'lib/phrase/models/job_details.rb', line 39 def locales @locales end |
#locked ⇒ Object
‘true` if the job has been locked by the project’s job-locking workflow (translations attached to the job are read-only until the job advances).
47 48 49 |
# File 'lib/phrase/models/job_details.rb', line 47 def locked @locked end |
#name ⇒ Object
Returns the value of attribute name.
7 8 9 |
# File 'lib/phrase/models/job_details.rb', line 7 def name @name end |
#owner ⇒ Object
Returns the value of attribute owner.
31 32 33 |
# File 'lib/phrase/models/job_details.rb', line 31 def owner @owner end |
#project ⇒ Object
Returns the value of attribute project.
17 18 19 |
# File 'lib/phrase/models/job_details.rb', line 17 def project @project end |
#source_locale ⇒ Object
Returns the value of attribute source_locale.
37 38 39 |
# File 'lib/phrase/models/job_details.rb', line 37 def source_locale @source_locale end |
#source_translations_updated_at ⇒ Object
Returns the value of attribute source_translations_updated_at.
35 36 37 |
# File 'lib/phrase/models/job_details.rb', line 35 def source_translations_updated_at @source_translations_updated_at end |
#state ⇒ Object
Returns the value of attribute state.
13 14 15 |
# File 'lib/phrase/models/job_details.rb', line 13 def state @state end |
#ticket_url ⇒ Object
Returns the value of attribute ticket_url.
15 16 17 |
# File 'lib/phrase/models/job_details.rb', line 15 def ticket_url @ticket_url end |
#updated_at ⇒ Object
Returns the value of attribute updated_at.
23 24 25 |
# File 'lib/phrase/models/job_details.rb', line 23 def updated_at @updated_at end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 |
# File 'lib/phrase/models/job_details.rb', line 50 def self.attribute_map { :'id' => :'id', :'name' => :'name', :'briefing' => :'briefing', :'due_date' => :'due_date', :'state' => :'state', :'ticket_url' => :'ticket_url', :'project' => :'project', :'branch' => :'branch', :'created_at' => :'created_at', :'updated_at' => :'updated_at', :'automation_id' => :'automation_id', :'job_template_id' => :'job_template_id', :'owner' => :'owner', :'job_tag_name' => :'job_tag_name', :'source_translations_updated_at' => :'source_translations_updated_at', :'source_locale' => :'source_locale', :'locales' => :'locales', :'keys' => :'keys', :'annotations' => :'annotations', :'locked' => :'locked' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
274 275 276 |
# File 'lib/phrase/models/job_details.rb', line 274 def self.build_from_hash(attributes) new.build_from_hash(attributes) end |
.openapi_all_of ⇒ Object
List of class defined in allOf (OpenAPI v3)
111 112 113 114 115 |
# File 'lib/phrase/models/job_details.rb', line 111 def self.openapi_all_of [ :'Job' ] end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
102 103 104 105 106 107 108 |
# File 'lib/phrase/models/job_details.rb', line 102 def self.openapi_nullable Set.new([ :'due_date', :'automation_id', :'job_template_id', ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 |
# File 'lib/phrase/models/job_details.rb', line 76 def self.openapi_types { :'id' => :'String', :'name' => :'String', :'briefing' => :'String', :'due_date' => :'DateTime', :'state' => :'String', :'ticket_url' => :'String', :'project' => :'ProjectShort', :'branch' => :'BranchName', :'created_at' => :'DateTime', :'updated_at' => :'DateTime', :'automation_id' => :'String', :'job_template_id' => :'String', :'owner' => :'UserPreview', :'job_tag_name' => :'String', :'source_translations_updated_at' => :'DateTime', :'source_locale' => :'LocalePreview', :'locales' => :'Array<LocalePreview>', :'keys' => :'Array<KeyPreview>', :'annotations' => :'Array<JobAnnotationShort>', :'locked' => :'Boolean' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 |
# File 'lib/phrase/models/job_details.rb', line 234 def ==(o) return true if self.equal?(o) self.class == o.class && id == o.id && name == o.name && briefing == o.briefing && due_date == o.due_date && state == o.state && ticket_url == o.ticket_url && project == o.project && branch == o.branch && created_at == o.created_at && updated_at == o.updated_at && automation_id == o.automation_id && job_template_id == o.job_template_id && owner == o.owner && job_tag_name == o.job_tag_name && source_translations_updated_at == o.source_translations_updated_at && source_locale == o.source_locale && locales == o.locales && keys == o.keys && annotations == o.annotations && locked == o.locked end |
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type
302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 |
# File 'lib/phrase/models/job_details.rb', line 302 def _deserialize(type, value) case type.to_sym when :DateTime DateTime.parse(value) when :Date Date.parse(value) when :Time Time.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model Phrase.const_get(type).build_from_hash(value) end end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
373 374 375 376 377 378 379 380 381 382 383 384 385 |
# File 'lib/phrase/models/job_details.rb', line 373 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 |
# File 'lib/phrase/models/job_details.rb', line 281 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.openapi_types.each_pair do |key, type| if type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) }) end elsif !attributes[self.class.attribute_map[key]].nil? self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]])) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(o) ⇒ Boolean
261 262 263 |
# File 'lib/phrase/models/job_details.rb', line 261 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
267 268 269 |
# File 'lib/phrase/models/job_details.rb', line 267 def hash [id, name, briefing, due_date, state, ticket_url, project, branch, created_at, updated_at, automation_id, job_template_id, owner, job_tag_name, source_translations_updated_at, source_locale, locales, keys, annotations, locked].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
221 222 223 224 |
# File 'lib/phrase/models/job_details.rb', line 221 def list_invalid_properties invalid_properties = Array.new invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
349 350 351 |
# File 'lib/phrase/models/job_details.rb', line 349 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
355 356 357 358 359 360 361 362 363 364 365 366 367 |
# File 'lib/phrase/models/job_details.rb', line 355 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
343 344 345 |
# File 'lib/phrase/models/job_details.rb', line 343 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
228 229 230 |
# File 'lib/phrase/models/job_details.rb', line 228 def valid? true end |