Class: Phrase::KeyFormatAnnotationsApi
- Inherits:
-
Object
- Object
- Phrase::KeyFormatAnnotationsApi
- Defined in:
- lib/phrase/api/key_format_annotations_api.rb
Instance Attribute Summary collapse
-
#api_client ⇒ Object
Returns the value of attribute api_client.
Instance Method Summary collapse
-
#initialize(api_client = ApiClient.default) ⇒ KeyFormatAnnotationsApi
constructor
A new instance of KeyFormatAnnotationsApi.
-
#key_format_annotations_list(project_id, id, opts = {}) ⇒ Array<KeyFormatAnnotationsList200ResponseInner>
List format annotations for a key Returns the format annotations stored on a translation key.
-
#key_format_annotations_list_with_http_info(project_id, id, opts = {}) ⇒ Array<(Response<(Array<KeyFormatAnnotationsList200ResponseInner>)>, Integer, Hash)>
List format annotations for a key Returns the format annotations stored on a translation key.
Constructor Details
#initialize(api_client = ApiClient.default) ⇒ KeyFormatAnnotationsApi
Returns a new instance of KeyFormatAnnotationsApi.
7 8 9 |
# File 'lib/phrase/api/key_format_annotations_api.rb', line 7 def initialize(api_client = ApiClient.default) @api_client = api_client end |
Instance Attribute Details
#api_client ⇒ Object
Returns the value of attribute api_client.
5 6 7 |
# File 'lib/phrase/api/key_format_annotations_api.rb', line 5 def api_client @api_client end |
Instance Method Details
#key_format_annotations_list(project_id, id, opts = {}) ⇒ Array<KeyFormatAnnotationsList200ResponseInner>
List format annotations for a key Returns the format annotations stored on a translation key. Format annotations capture file-format data recorded when the key was imported — for example, an ARB placeholder block or an XLIFF note. Results are limited to 1,000 entries.
18 19 20 21 |
# File 'lib/phrase/api/key_format_annotations_api.rb', line 18 def key_format_annotations_list(project_id, id, opts = {}) data, _status_code, _headers = key_format_annotations_list_with_http_info(project_id, id, opts) data end |
#key_format_annotations_list_with_http_info(project_id, id, opts = {}) ⇒ Array<(Response<(Array<KeyFormatAnnotationsList200ResponseInner>)>, Integer, Hash)>
List format annotations for a key Returns the format annotations stored on a translation key. Format annotations capture file-format data recorded when the key was imported — for example, an ARB placeholder block or an XLIFF note. Results are limited to 1,000 entries.
31 32 33 34 35 36 37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 |
# File 'lib/phrase/api/key_format_annotations_api.rb', line 31 def key_format_annotations_list_with_http_info(project_id, id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: KeyFormatAnnotationsApi.key_format_annotations_list ...' end # verify the required parameter 'project_id' is set if @api_client.config.client_side_validation && project_id.nil? fail ArgumentError, "Missing the required parameter 'project_id' when calling KeyFormatAnnotationsApi.key_format_annotations_list" end # verify the required parameter 'id' is set if @api_client.config.client_side_validation && id.nil? fail ArgumentError, "Missing the required parameter 'id' when calling KeyFormatAnnotationsApi.key_format_annotations_list" end # resource path local_var_path = '/projects/{project_id}/keys/{id}/format_annotations'.sub('{' + 'project_id' + '}', CGI.escape(project_id.to_s)).sub('{' + 'id' + '}', CGI.escape(id.to_s)) # query parameters query_params = opts[:query_params] || {} query_params[:'branch'] = opts[:'branch'] if !opts[:'branch'].nil? # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) header_params[:'X-PhraseApp-OTP'] = opts[:'x_phrase_app_otp'] if !opts[:'x_phrase_app_otp'].nil? # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:body] # return_type return_type = opts[:return_type] || 'Array<KeyFormatAnnotationsList200ResponseInner>' # auth_names auth_names = opts[:auth_names] || ['Basic', 'Token'] = opts.merge( :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: KeyFormatAnnotationsApi#key_format_annotations_list\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end response = ::Phrase::Response.new(data, headers) return response, status_code, headers end |