Class: Phrase::MachineTranslationApi
- Inherits:
-
Object
- Object
- Phrase::MachineTranslationApi
- Defined in:
- lib/phrase/api/machine_translation_api.rb
Instance Attribute Summary collapse
-
#api_client ⇒ Object
Returns the value of attribute api_client.
Instance Method Summary collapse
-
#initialize(api_client = ApiClient.default) ⇒ MachineTranslationApi
constructor
A new instance of MachineTranslationApi.
-
#machine_translation_locale_provider_mappings_create(account_id, machine_translation_locale_provider_mappings_create_parameters, opts = {}) ⇒ MachineTranslationLocaleProviderMapping
Create a locale provider mapping Creates a locale-pair-specific machine translation provider override for the account.
-
#machine_translation_locale_provider_mappings_create_with_http_info(account_id, machine_translation_locale_provider_mappings_create_parameters, opts = {}) ⇒ Array<(Response<(MachineTranslationLocaleProviderMapping)>, Integer, Hash)>
Create a locale provider mapping Creates a locale-pair-specific machine translation provider override for the account.
-
#machine_translation_locale_provider_mappings_destroy(account_id, source_locale_code, target_locale_code, opts = {}) ⇒ nil
Delete a locale provider mapping Removes the machine translation provider override for the specified source and target locale pair.
-
#machine_translation_locale_provider_mappings_destroy_with_http_info(account_id, source_locale_code, target_locale_code, opts = {}) ⇒ Array<(Response, Integer, Hash)>
Delete a locale provider mapping Removes the machine translation provider override for the specified source and target locale pair.
-
#machine_translation_settings_show(account_id, opts = {}) ⇒ MachineTranslationSettings
Get machine translation settings Returns the machine translation configuration for the account, including the default translation service, current machine translation unit usage, and any locale-pair-specific provider mappings.
-
#machine_translation_settings_show_with_http_info(account_id, opts = {}) ⇒ Array<(Response<(MachineTranslationSettings)>, Integer, Hash)>
Get machine translation settings Returns the machine translation configuration for the account, including the default translation service, current machine translation unit usage, and any locale-pair-specific provider mappings.
-
#machine_translation_settings_update(account_id, machine_translation_settings_update_parameters, opts = {}) ⇒ MachineTranslationSettings
Update machine translation settings Sets the default machine translation service for the account.
-
#machine_translation_settings_update_with_http_info(account_id, machine_translation_settings_update_parameters, opts = {}) ⇒ Array<(Response<(MachineTranslationSettings)>, Integer, Hash)>
Update machine translation settings Sets the default machine translation service for the account.
Constructor Details
#initialize(api_client = ApiClient.default) ⇒ MachineTranslationApi
Returns a new instance of MachineTranslationApi.
7 8 9 |
# File 'lib/phrase/api/machine_translation_api.rb', line 7 def initialize(api_client = ApiClient.default) @api_client = api_client end |
Instance Attribute Details
#api_client ⇒ Object
Returns the value of attribute api_client.
5 6 7 |
# File 'lib/phrase/api/machine_translation_api.rb', line 5 def api_client @api_client end |
Instance Method Details
#machine_translation_locale_provider_mappings_create(account_id, machine_translation_locale_provider_mappings_create_parameters, opts = {}) ⇒ MachineTranslationLocaleProviderMapping
Create a locale provider mapping Creates a locale-pair-specific machine translation provider override for the account. When a mapping exists for a given source/target locale pair, that provider is used instead of the account default. Only one mapping may exist per source/target locale pair; attempting to create a duplicate returns a validation error. The source and target locale codes must differ.
17 18 19 20 |
# File 'lib/phrase/api/machine_translation_api.rb', line 17 def machine_translation_locale_provider_mappings_create(account_id, machine_translation_locale_provider_mappings_create_parameters, opts = {}) data, _status_code, _headers = machine_translation_locale_provider_mappings_create_with_http_info(account_id, machine_translation_locale_provider_mappings_create_parameters, opts) data end |
#machine_translation_locale_provider_mappings_create_with_http_info(account_id, machine_translation_locale_provider_mappings_create_parameters, opts = {}) ⇒ Array<(Response<(MachineTranslationLocaleProviderMapping)>, Integer, Hash)>
Create a locale provider mapping Creates a locale-pair-specific machine translation provider override for the account. When a mapping exists for a given source/target locale pair, that provider is used instead of the account default. Only one mapping may exist per source/target locale pair; attempting to create a duplicate returns a validation error. The source and target locale codes must differ.
29 30 31 32 33 34 35 36 37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 |
# File 'lib/phrase/api/machine_translation_api.rb', line 29 def machine_translation_locale_provider_mappings_create_with_http_info(account_id, machine_translation_locale_provider_mappings_create_parameters, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: MachineTranslationApi.machine_translation_locale_provider_mappings_create ...' end # verify the required parameter 'account_id' is set if @api_client.config.client_side_validation && account_id.nil? fail ArgumentError, "Missing the required parameter 'account_id' when calling MachineTranslationApi.machine_translation_locale_provider_mappings_create" end # verify the required parameter 'machine_translation_locale_provider_mappings_create_parameters' is set if @api_client.config.client_side_validation && machine_translation_locale_provider_mappings_create_parameters.nil? fail ArgumentError, "Missing the required parameter 'machine_translation_locale_provider_mappings_create_parameters' when calling MachineTranslationApi.machine_translation_locale_provider_mappings_create" end # resource path local_var_path = '/accounts/{account_id}/machine_translation_locale_provider_mappings'.sub('{' + 'account_id' + '}', CGI.escape(account_id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # HTTP header 'Content-Type' header_params['Content-Type'] = @api_client.select_header_content_type(['application/json']) header_params[:'X-PhraseApp-OTP'] = opts[:'x_phrase_app_otp'] if !opts[:'x_phrase_app_otp'].nil? # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:body] || @api_client.object_to_http_body(machine_translation_locale_provider_mappings_create_parameters) # return_type return_type = opts[:return_type] || 'MachineTranslationLocaleProviderMapping' # auth_names auth_names = opts[:auth_names] || ['Basic', 'Token'] = opts.merge( :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:POST, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: MachineTranslationApi#machine_translation_locale_provider_mappings_create\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end response = ::Phrase::Response.new(data, headers) return response, status_code, headers end |
#machine_translation_locale_provider_mappings_destroy(account_id, source_locale_code, target_locale_code, opts = {}) ⇒ nil
Delete a locale provider mapping Removes the machine translation provider override for the specified source and target locale pair. The mapping is identified by locale codes supplied as query parameters rather than a path ID.
92 93 94 95 |
# File 'lib/phrase/api/machine_translation_api.rb', line 92 def machine_translation_locale_provider_mappings_destroy(account_id, source_locale_code, target_locale_code, opts = {}) data, _status_code, _headers = machine_translation_locale_provider_mappings_destroy_with_http_info(account_id, source_locale_code, target_locale_code, opts) data end |
#machine_translation_locale_provider_mappings_destroy_with_http_info(account_id, source_locale_code, target_locale_code, opts = {}) ⇒ Array<(Response, Integer, Hash)>
Delete a locale provider mapping Removes the machine translation provider override for the specified source and target locale pair. The mapping is identified by locale codes supplied as query parameters rather than a path ID.
105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 |
# File 'lib/phrase/api/machine_translation_api.rb', line 105 def machine_translation_locale_provider_mappings_destroy_with_http_info(account_id, source_locale_code, target_locale_code, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: MachineTranslationApi.machine_translation_locale_provider_mappings_destroy ...' end # verify the required parameter 'account_id' is set if @api_client.config.client_side_validation && account_id.nil? fail ArgumentError, "Missing the required parameter 'account_id' when calling MachineTranslationApi.machine_translation_locale_provider_mappings_destroy" end # verify the required parameter 'source_locale_code' is set if @api_client.config.client_side_validation && source_locale_code.nil? fail ArgumentError, "Missing the required parameter 'source_locale_code' when calling MachineTranslationApi.machine_translation_locale_provider_mappings_destroy" end # verify the required parameter 'target_locale_code' is set if @api_client.config.client_side_validation && target_locale_code.nil? fail ArgumentError, "Missing the required parameter 'target_locale_code' when calling MachineTranslationApi.machine_translation_locale_provider_mappings_destroy" end # resource path local_var_path = '/accounts/{account_id}/machine_translation_locale_provider_mappings'.sub('{' + 'account_id' + '}', CGI.escape(account_id.to_s)) # query parameters query_params = opts[:query_params] || {} query_params[:'source_locale_code'] = source_locale_code query_params[:'target_locale_code'] = target_locale_code # header parameters header_params = opts[:header_params] || {} header_params[:'X-PhraseApp-OTP'] = opts[:'x_phrase_app_otp'] if !opts[:'x_phrase_app_otp'].nil? # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:body] # return_type return_type = opts[:return_type] # auth_names auth_names = opts[:auth_names] || ['Basic', 'Token'] = opts.merge( :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:DELETE, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: MachineTranslationApi#machine_translation_locale_provider_mappings_destroy\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end response = ::Phrase::Response.new(data, headers) return response, status_code, headers end |
#machine_translation_settings_show(account_id, opts = {}) ⇒ MachineTranslationSettings
Get machine translation settings Returns the machine translation configuration for the account, including the default translation service, current machine translation unit usage, and any locale-pair-specific provider mappings.
168 169 170 171 |
# File 'lib/phrase/api/machine_translation_api.rb', line 168 def machine_translation_settings_show(account_id, opts = {}) data, _status_code, _headers = machine_translation_settings_show_with_http_info(account_id, opts) data end |
#machine_translation_settings_show_with_http_info(account_id, opts = {}) ⇒ Array<(Response<(MachineTranslationSettings)>, Integer, Hash)>
Get machine translation settings Returns the machine translation configuration for the account, including the default translation service, current machine translation unit usage, and any locale-pair-specific provider mappings.
179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 |
# File 'lib/phrase/api/machine_translation_api.rb', line 179 def machine_translation_settings_show_with_http_info(account_id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: MachineTranslationApi.machine_translation_settings_show ...' end # verify the required parameter 'account_id' is set if @api_client.config.client_side_validation && account_id.nil? fail ArgumentError, "Missing the required parameter 'account_id' when calling MachineTranslationApi.machine_translation_settings_show" end # resource path local_var_path = '/accounts/{account_id}/machine_translation_settings'.sub('{' + 'account_id' + '}', CGI.escape(account_id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) header_params[:'X-PhraseApp-OTP'] = opts[:'x_phrase_app_otp'] if !opts[:'x_phrase_app_otp'].nil? # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:body] # return_type return_type = opts[:return_type] || 'MachineTranslationSettings' # auth_names auth_names = opts[:auth_names] || ['Basic', 'Token'] = opts.merge( :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: MachineTranslationApi#machine_translation_settings_show\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end response = ::Phrase::Response.new(data, headers) return response, status_code, headers end |
#machine_translation_settings_update(account_id, machine_translation_settings_update_parameters, opts = {}) ⇒ MachineTranslationSettings
Update machine translation settings
Sets the default machine translation service for the account. Requires write access to the account's machine translation settings. Passing an empty or absent value for default_service resets the account to its plan default (Microsoft Translate).
235 236 237 238 |
# File 'lib/phrase/api/machine_translation_api.rb', line 235 def machine_translation_settings_update(account_id, machine_translation_settings_update_parameters, opts = {}) data, _status_code, _headers = machine_translation_settings_update_with_http_info(account_id, machine_translation_settings_update_parameters, opts) data end |
#machine_translation_settings_update_with_http_info(account_id, machine_translation_settings_update_parameters, opts = {}) ⇒ Array<(Response<(MachineTranslationSettings)>, Integer, Hash)>
Update machine translation settings Sets the default machine translation service for the account. Requires write access to the account's machine translation settings. Passing an empty or absent value for `default_service` resets the account to its plan default (Microsoft Translate).
247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 |
# File 'lib/phrase/api/machine_translation_api.rb', line 247 def machine_translation_settings_update_with_http_info(account_id, machine_translation_settings_update_parameters, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: MachineTranslationApi.machine_translation_settings_update ...' end # verify the required parameter 'account_id' is set if @api_client.config.client_side_validation && account_id.nil? fail ArgumentError, "Missing the required parameter 'account_id' when calling MachineTranslationApi.machine_translation_settings_update" end # verify the required parameter 'machine_translation_settings_update_parameters' is set if @api_client.config.client_side_validation && machine_translation_settings_update_parameters.nil? fail ArgumentError, "Missing the required parameter 'machine_translation_settings_update_parameters' when calling MachineTranslationApi.machine_translation_settings_update" end # resource path local_var_path = '/accounts/{account_id}/machine_translation_settings'.sub('{' + 'account_id' + '}', CGI.escape(account_id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # HTTP header 'Content-Type' header_params['Content-Type'] = @api_client.select_header_content_type(['application/json']) header_params[:'X-PhraseApp-OTP'] = opts[:'x_phrase_app_otp'] if !opts[:'x_phrase_app_otp'].nil? # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:body] || @api_client.object_to_http_body(machine_translation_settings_update_parameters) # return_type return_type = opts[:return_type] || 'MachineTranslationSettings' # auth_names auth_names = opts[:auth_names] || ['Basic', 'Token'] = opts.merge( :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:PATCH, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: MachineTranslationApi#machine_translation_settings_update\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end response = ::Phrase::Response.new(data, headers) return response, status_code, headers end |