Class: Phrase::ProjectUpdateParameters

Inherits:
Object
  • Object
show all
Defined in:
lib/phrase/models/project_update_parameters.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ ProjectUpdateParameters

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
342
343
344
345
346
347
348
349
# File 'lib/phrase/models/project_update_parameters.rb', line 207

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Phrase::ProjectUpdateParameters` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Phrase::ProjectUpdateParameters`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'account_id')
    self. = attributes[:'account_id']
  end

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  end

  if attributes.key?(:'point_of_contact')
    self.point_of_contact = attributes[:'point_of_contact']
  end

  if attributes.key?(:'main_format')
    self.main_format = attributes[:'main_format']
  end

  if attributes.key?(:'media')
    self.media = attributes[:'media']
  end

  if attributes.key?(:'shares_translation_memory')
    self.shares_translation_memory = attributes[:'shares_translation_memory']
  end

  if attributes.key?(:'project_image')
    self.project_image = attributes[:'project_image']
  end

  if attributes.key?(:'remove_project_image')
    self.remove_project_image = attributes[:'remove_project_image']
  end

  if attributes.key?(:'workflow')
    self.workflow = attributes[:'workflow']
  end

  if attributes.key?(:'machine_translation_enabled')
    self.machine_translation_enabled = attributes[:'machine_translation_enabled']
  end

  if attributes.key?(:'enable_branching')
    self.enable_branching = attributes[:'enable_branching']
  end

  if attributes.key?(:'protect_master_branch')
    self.protect_master_branch = attributes[:'protect_master_branch']
  end

  if attributes.key?(:'enable_all_data_type_translation_keys_for_translators')
    self.enable_all_data_type_translation_keys_for_translators = attributes[:'enable_all_data_type_translation_keys_for_translators']
  end

  if attributes.key?(:'enable_icu_message_format')
    self.enable_icu_message_format = attributes[:'enable_icu_message_format']
  end

  if attributes.key?(:'zero_plural_form_enabled')
    self.zero_plural_form_enabled = attributes[:'zero_plural_form_enabled']
  end

  if attributes.key?(:'autotranslate_enabled')
    self.autotranslate_enabled = attributes[:'autotranslate_enabled']
  end

  if attributes.key?(:'autotranslate_check_new_translation_keys')
    self.autotranslate_check_new_translation_keys = attributes[:'autotranslate_check_new_translation_keys']
  end

  if attributes.key?(:'autotranslate_check_new_uploads')
    self.autotranslate_check_new_uploads = attributes[:'autotranslate_check_new_uploads']
  end

  if attributes.key?(:'autotranslate_check_new_locales')
    self.autotranslate_check_new_locales = attributes[:'autotranslate_check_new_locales']
  end

  if attributes.key?(:'autotranslate_mark_as_unverified')
    self.autotranslate_mark_as_unverified = attributes[:'autotranslate_mark_as_unverified']
  end

  if attributes.key?(:'autotranslate_use_machine_translation')
    self.autotranslate_use_machine_translation = attributes[:'autotranslate_use_machine_translation']
  end

  if attributes.key?(:'autotranslate_use_translation_memory')
    self.autotranslate_use_translation_memory = attributes[:'autotranslate_use_translation_memory']
  end

  if attributes.key?(:'autotranslate_overwrite_unverified_translations')
    self.autotranslate_overwrite_unverified_translations = attributes[:'autotranslate_overwrite_unverified_translations']
  end

  if attributes.key?(:'default_encoding')
    self.default_encoding = attributes[:'default_encoding']
  end

  if attributes.key?(:'placeholder_styles')
    if (value = attributes[:'placeholder_styles']).is_a?(Array)
      self.placeholder_styles = value
    end
  end

  if attributes.key?(:'autocomplete_job_enabled')
    self.autocomplete_job_enabled = attributes[:'autocomplete_job_enabled']
  end

  if attributes.key?(:'job_locking_enabled')
    self.job_locking_enabled = attributes[:'job_locking_enabled']
  end

  if attributes.key?(:'smart_suggest_enabled')
    self.smart_suggest_enabled = attributes[:'smart_suggest_enabled']
  end

  if attributes.key?(:'smart_suggest_use_glossary')
    self.smart_suggest_use_glossary = attributes[:'smart_suggest_use_glossary']
  end

  if attributes.key?(:'smart_suggest_use_machine_translation')
    self.smart_suggest_use_machine_translation = attributes[:'smart_suggest_use_machine_translation']
  end

  if attributes.key?(:'translation_keys_sort_collation')
    self.translation_keys_sort_collation = attributes[:'translation_keys_sort_collation']
  end

  if attributes.key?(:'cldr_version')
    self.cldr_version = attributes[:'cldr_version']
  end
end

Instance Attribute Details

#account_idObject

(Optional) ID of an account the requesting user belongs to. Used only to disambiguate the request context; the project itself cannot be moved between accounts through this endpoint.



6
7
8
# File 'lib/phrase/models/project_update_parameters.rb', line 6

def 
  @account_id
end

#autocomplete_job_enabledObject

(Optional) Enable autocomplete-job behavior so that newly created keys and locales are automatically added to in-progress jobs.



81
82
83
# File 'lib/phrase/models/project_update_parameters.rb', line 81

def autocomplete_job_enabled
  @autocomplete_job_enabled
end

#autotranslate_check_new_localesObject

(Optional) Requires autotranslate_enabled to be true



60
61
62
# File 'lib/phrase/models/project_update_parameters.rb', line 60

def autotranslate_check_new_locales
  @autotranslate_check_new_locales
end

#autotranslate_check_new_translation_keysObject

(Optional) Requires autotranslate_enabled to be true



54
55
56
# File 'lib/phrase/models/project_update_parameters.rb', line 54

def autotranslate_check_new_translation_keys
  @autotranslate_check_new_translation_keys
end

#autotranslate_check_new_uploadsObject

(Optional) Requires autotranslate_enabled to be true



57
58
59
# File 'lib/phrase/models/project_update_parameters.rb', line 57

def autotranslate_check_new_uploads
  @autotranslate_check_new_uploads
end

#autotranslate_enabledObject

(Optional) Autopilot, requires machine_translation_enabled. [Read more](support.phrase.com/hc/en-us/articles/5822187934364)



51
52
53
# File 'lib/phrase/models/project_update_parameters.rb', line 51

def autotranslate_enabled
  @autotranslate_enabled
end

#autotranslate_mark_as_unverifiedObject

(Optional) Requires autotranslate_enabled to be true



63
64
65
# File 'lib/phrase/models/project_update_parameters.rb', line 63

def autotranslate_mark_as_unverified
  @autotranslate_mark_as_unverified
end

#autotranslate_overwrite_unverified_translationsObject

(Optional) Requires autotranslate_enabled to be true



72
73
74
# File 'lib/phrase/models/project_update_parameters.rb', line 72

def autotranslate_overwrite_unverified_translations
  @autotranslate_overwrite_unverified_translations
end

#autotranslate_use_machine_translationObject

(Optional) Requires autotranslate_enabled to be true



66
67
68
# File 'lib/phrase/models/project_update_parameters.rb', line 66

def autotranslate_use_machine_translation
  @autotranslate_use_machine_translation
end

#autotranslate_use_translation_memoryObject

(Optional) Requires autotranslate_enabled to be true



69
70
71
# File 'lib/phrase/models/project_update_parameters.rb', line 69

def autotranslate_use_translation_memory
  @autotranslate_use_translation_memory
end

#cldr_versionObject

(Optional) CLDR plural-rule version used by the project.



99
100
101
# File 'lib/phrase/models/project_update_parameters.rb', line 99

def cldr_version
  @cldr_version
end

#default_encodingObject

(Optional) Sets the default encoding for Uploads. If you leave it empty, we will try to guess it automatically for you when you Upload a file. You can still override this value by setting the [‘file_encoding`](/en/api/strings/uploads/upload-a-new-file) parameter for Uploads.



75
76
77
# File 'lib/phrase/models/project_update_parameters.rb', line 75

def default_encoding
  @default_encoding
end

#enable_all_data_type_translation_keys_for_translatorsObject

(Optional) Otherwise, translators are not allowed to edit translations other than strings



42
43
44
# File 'lib/phrase/models/project_update_parameters.rb', line 42

def enable_all_data_type_translation_keys_for_translators
  @enable_all_data_type_translation_keys_for_translators
end

#enable_branchingObject

(Optional) Enable branching in the project



36
37
38
# File 'lib/phrase/models/project_update_parameters.rb', line 36

def enable_branching
  @enable_branching
end

#enable_icu_message_formatObject

(Optional) We can validate and highlight your ICU messages. [Read more](support.phrase.com/hc/en-us/articles/5822319545116)



45
46
47
# File 'lib/phrase/models/project_update_parameters.rb', line 45

def enable_icu_message_format
  @enable_icu_message_format
end

#job_locking_enabledObject

(Optional) When enabled, translations are locked once a job moves into review.



84
85
86
# File 'lib/phrase/models/project_update_parameters.rb', line 84

def job_locking_enabled
  @job_locking_enabled
end

#machine_translation_enabledObject

(Optional) Enable machine translation support in the project. Required for Pre-Translation



33
34
35
# File 'lib/phrase/models/project_update_parameters.rb', line 33

def machine_translation_enabled
  @machine_translation_enabled
end

#main_formatObject

(Optional) Main file format specified by its API Extension name. Used for locale downloads if no format is specified. For API Extension names of available file formats see [Format Guide](support.phrase.com/hc/en-us/sections/6111343326364) or our [Formats API Endpoint](#formats).



15
16
17
# File 'lib/phrase/models/project_update_parameters.rb', line 15

def main_format
  @main_format
end

#mediaObject

(Optional) Main technology stack used in the project. It affects for example the suggested placeholder style. Predefined values include: ‘Ruby`, `JavaScript`, `AngularJS`, `React`, `iOS`, `Android`, `Python`, `PHP`, `Java`, `Go`, `Windows Phone`, `Rails`, `Node.js`, `.NET`, `Django`, `Symfony`, `Yii Framework`, `Zend Framework`, `Apple App Store Description`, `Google Play Description`, but it can also take any other value.



18
19
20
# File 'lib/phrase/models/project_update_parameters.rb', line 18

def media
  @media
end

#nameObject

(Optional) Name of the project



9
10
11
# File 'lib/phrase/models/project_update_parameters.rb', line 9

def name
  @name
end

#placeholder_stylesObject

(Optional) List of placeholder styles enabled for the project.



78
79
80
# File 'lib/phrase/models/project_update_parameters.rb', line 78

def placeholder_styles
  @placeholder_styles
end

#point_of_contactObject

(Optional) User ID of the point of contact for the project. Pass ‘null` to unset.



12
13
14
# File 'lib/phrase/models/project_update_parameters.rb', line 12

def point_of_contact
  @point_of_contact
end

#project_imageObject

(Optional) Image to identify the project



24
25
26
# File 'lib/phrase/models/project_update_parameters.rb', line 24

def project_image
  @project_image
end

#protect_master_branchObject

(Optional) Protect the master branch in project where branching is enabled



39
40
41
# File 'lib/phrase/models/project_update_parameters.rb', line 39

def protect_master_branch
  @protect_master_branch
end

#remove_project_imageObject

(Optional) Indicates whether the project image should be deleted.



27
28
29
# File 'lib/phrase/models/project_update_parameters.rb', line 27

def remove_project_image
  @remove_project_image
end

#shares_translation_memoryObject

(Optional) Indicates whether the project should share the account’s translation memory



21
22
23
# File 'lib/phrase/models/project_update_parameters.rb', line 21

def shares_translation_memory
  @shares_translation_memory
end

#smart_suggest_enabledObject

(Optional) Enable Smart Suggest for the project.



87
88
89
# File 'lib/phrase/models/project_update_parameters.rb', line 87

def smart_suggest_enabled
  @smart_suggest_enabled
end

#smart_suggest_use_glossaryObject

(Optional) Allow Smart Suggest to source suggestions from the project glossary.



90
91
92
# File 'lib/phrase/models/project_update_parameters.rb', line 90

def smart_suggest_use_glossary
  @smart_suggest_use_glossary
end

#smart_suggest_use_machine_translationObject

(Optional) Allow Smart Suggest to source suggestions from machine translation.



93
94
95
# File 'lib/phrase/models/project_update_parameters.rb', line 93

def smart_suggest_use_machine_translation
  @smart_suggest_use_machine_translation
end

#translation_keys_sort_collationObject

(Optional) Collation used when sorting translation keys alphabetically.



96
97
98
# File 'lib/phrase/models/project_update_parameters.rb', line 96

def translation_keys_sort_collation
  @translation_keys_sort_collation
end

#workflowObject

(Optional) Review Workflow. "simple" / "review". [Read more](support.phrase.com/hc/en-us/articles/5784094755484)



30
31
32
# File 'lib/phrase/models/project_update_parameters.rb', line 30

def workflow
  @workflow
end

#zero_plural_form_enabledObject

(Optional) Displays the input fields for the ‘ZERO’ plural form for every key as well although only some languages require the ‘ZERO’ explicitly.



48
49
50
# File 'lib/phrase/models/project_update_parameters.rb', line 48

def zero_plural_form_enabled
  @zero_plural_form_enabled
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
# File 'lib/phrase/models/project_update_parameters.rb', line 124

def self.attribute_map
  {
    :'account_id' => :'account_id',
    :'name' => :'name',
    :'point_of_contact' => :'point_of_contact',
    :'main_format' => :'main_format',
    :'media' => :'media',
    :'shares_translation_memory' => :'shares_translation_memory',
    :'project_image' => :'project_image',
    :'remove_project_image' => :'remove_project_image',
    :'workflow' => :'workflow',
    :'machine_translation_enabled' => :'machine_translation_enabled',
    :'enable_branching' => :'enable_branching',
    :'protect_master_branch' => :'protect_master_branch',
    :'enable_all_data_type_translation_keys_for_translators' => :'enable_all_data_type_translation_keys_for_translators',
    :'enable_icu_message_format' => :'enable_icu_message_format',
    :'zero_plural_form_enabled' => :'zero_plural_form_enabled',
    :'autotranslate_enabled' => :'autotranslate_enabled',
    :'autotranslate_check_new_translation_keys' => :'autotranslate_check_new_translation_keys',
    :'autotranslate_check_new_uploads' => :'autotranslate_check_new_uploads',
    :'autotranslate_check_new_locales' => :'autotranslate_check_new_locales',
    :'autotranslate_mark_as_unverified' => :'autotranslate_mark_as_unverified',
    :'autotranslate_use_machine_translation' => :'autotranslate_use_machine_translation',
    :'autotranslate_use_translation_memory' => :'autotranslate_use_translation_memory',
    :'autotranslate_overwrite_unverified_translations' => :'autotranslate_overwrite_unverified_translations',
    :'default_encoding' => :'default_encoding',
    :'placeholder_styles' => :'placeholder_styles',
    :'autocomplete_job_enabled' => :'autocomplete_job_enabled',
    :'job_locking_enabled' => :'job_locking_enabled',
    :'smart_suggest_enabled' => :'smart_suggest_enabled',
    :'smart_suggest_use_glossary' => :'smart_suggest_use_glossary',
    :'smart_suggest_use_machine_translation' => :'smart_suggest_use_machine_translation',
    :'translation_keys_sort_collation' => :'translation_keys_sort_collation',
    :'cldr_version' => :'cldr_version'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



430
431
432
# File 'lib/phrase/models/project_update_parameters.rb', line 430

def self.build_from_hash(attributes)
  new.build_from_hash(attributes)
end

.openapi_nullableObject

List of attributes with nullable: true



200
201
202
203
# File 'lib/phrase/models/project_update_parameters.rb', line 200

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
# File 'lib/phrase/models/project_update_parameters.rb', line 162

def self.openapi_types
  {
    :'account_id' => :'String',
    :'name' => :'String',
    :'point_of_contact' => :'String',
    :'main_format' => :'String',
    :'media' => :'String',
    :'shares_translation_memory' => :'Boolean',
    :'project_image' => :'File',
    :'remove_project_image' => :'Boolean',
    :'workflow' => :'String',
    :'machine_translation_enabled' => :'Boolean',
    :'enable_branching' => :'Boolean',
    :'protect_master_branch' => :'Boolean',
    :'enable_all_data_type_translation_keys_for_translators' => :'Boolean',
    :'enable_icu_message_format' => :'Boolean',
    :'zero_plural_form_enabled' => :'Boolean',
    :'autotranslate_enabled' => :'Boolean',
    :'autotranslate_check_new_translation_keys' => :'Boolean',
    :'autotranslate_check_new_uploads' => :'Boolean',
    :'autotranslate_check_new_locales' => :'Boolean',
    :'autotranslate_mark_as_unverified' => :'Boolean',
    :'autotranslate_use_machine_translation' => :'Boolean',
    :'autotranslate_use_translation_memory' => :'Boolean',
    :'autotranslate_overwrite_unverified_translations' => :'Boolean',
    :'default_encoding' => :'String',
    :'placeholder_styles' => :'Array<String>',
    :'autocomplete_job_enabled' => :'Boolean',
    :'job_locking_enabled' => :'Boolean',
    :'smart_suggest_enabled' => :'Boolean',
    :'smart_suggest_use_glossary' => :'Boolean',
    :'smart_suggest_use_machine_translation' => :'Boolean',
    :'translation_keys_sort_collation' => :'String',
    :'cldr_version' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



378
379
380
381
382
383
384
385
386
387
388
389
390
391
392
393
394
395
396
397
398
399
400
401
402
403
404
405
406
407
408
409
410
411
412
413
# File 'lib/phrase/models/project_update_parameters.rb', line 378

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
       == o. &&
      name == o.name &&
      point_of_contact == o.point_of_contact &&
      main_format == o.main_format &&
      media == o.media &&
      shares_translation_memory == o.shares_translation_memory &&
      project_image == o.project_image &&
      remove_project_image == o.remove_project_image &&
      workflow == o.workflow &&
      machine_translation_enabled == o.machine_translation_enabled &&
      enable_branching == o.enable_branching &&
      protect_master_branch == o.protect_master_branch &&
      enable_all_data_type_translation_keys_for_translators == o.enable_all_data_type_translation_keys_for_translators &&
      enable_icu_message_format == o.enable_icu_message_format &&
      zero_plural_form_enabled == o.zero_plural_form_enabled &&
      autotranslate_enabled == o.autotranslate_enabled &&
      autotranslate_check_new_translation_keys == o.autotranslate_check_new_translation_keys &&
      autotranslate_check_new_uploads == o.autotranslate_check_new_uploads &&
      autotranslate_check_new_locales == o.autotranslate_check_new_locales &&
      autotranslate_mark_as_unverified == o.autotranslate_mark_as_unverified &&
      autotranslate_use_machine_translation == o.autotranslate_use_machine_translation &&
      autotranslate_use_translation_memory == o.autotranslate_use_translation_memory &&
      autotranslate_overwrite_unverified_translations == o.autotranslate_overwrite_unverified_translations &&
      default_encoding == o.default_encoding &&
      placeholder_styles == o.placeholder_styles &&
      autocomplete_job_enabled == o.autocomplete_job_enabled &&
      job_locking_enabled == o.job_locking_enabled &&
      smart_suggest_enabled == o.smart_suggest_enabled &&
      smart_suggest_use_glossary == o.smart_suggest_use_glossary &&
      smart_suggest_use_machine_translation == o.smart_suggest_use_machine_translation &&
      translation_keys_sort_collation == o.translation_keys_sort_collation &&
      cldr_version == o.cldr_version
end

#_deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



458
459
460
461
462
463
464
465
466
467
468
469
470
471
472
473
474
475
476
477
478
479
480
481
482
483
484
485
486
487
488
489
490
491
492
493
494
495
# File 'lib/phrase/models/project_update_parameters.rb', line 458

def _deserialize(type, value)
  case type.to_sym
  when :DateTime
    DateTime.parse(value)
  when :Date
    Date.parse(value)
  when :Time
    Time.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    Phrase.const_get(type).build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



529
530
531
532
533
534
535
536
537
538
539
540
541
# File 'lib/phrase/models/project_update_parameters.rb', line 529

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



437
438
439
440
441
442
443
444
445
446
447
448
449
450
451
452
# File 'lib/phrase/models/project_update_parameters.rb', line 437

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  self.class.openapi_types.each_pair do |key, type|
    if type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) })
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]]))
    end # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


417
418
419
# File 'lib/phrase/models/project_update_parameters.rb', line 417

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



423
424
425
# File 'lib/phrase/models/project_update_parameters.rb', line 423

def hash
  [, name, point_of_contact, main_format, media, shares_translation_memory, project_image, remove_project_image, workflow, machine_translation_enabled, enable_branching, protect_master_branch, enable_all_data_type_translation_keys_for_translators, enable_icu_message_format, zero_plural_form_enabled, autotranslate_enabled, autotranslate_check_new_translation_keys, autotranslate_check_new_uploads, autotranslate_check_new_locales, autotranslate_mark_as_unverified, autotranslate_use_machine_translation, autotranslate_use_translation_memory, autotranslate_overwrite_unverified_translations, default_encoding, placeholder_styles, autocomplete_job_enabled, job_locking_enabled, smart_suggest_enabled, smart_suggest_use_glossary, smart_suggest_use_machine_translation, translation_keys_sort_collation, cldr_version].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



353
354
355
356
# File 'lib/phrase/models/project_update_parameters.rb', line 353

def list_invalid_properties
  invalid_properties = Array.new
  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



505
506
507
# File 'lib/phrase/models/project_update_parameters.rb', line 505

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



511
512
513
514
515
516
517
518
519
520
521
522
523
# File 'lib/phrase/models/project_update_parameters.rb', line 511

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



499
500
501
# File 'lib/phrase/models/project_update_parameters.rb', line 499

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



360
361
362
363
364
# File 'lib/phrase/models/project_update_parameters.rb', line 360

def valid?
  default_encoding_validator = EnumAttributeValidator.new('String', ["UTF-8", "UTF-16", "UTF-16BE", "UTF-16LE", "ISO-8859-1"])
  return false unless default_encoding_validator.valid?(@default_encoding)
  true
end