Class: Phrase::ProjectsApi
- Inherits:
-
Object
- Object
- Phrase::ProjectsApi
- Defined in:
- lib/phrase/api/projects_api.rb
Instance Attribute Summary collapse
-
#api_client ⇒ Object
Returns the value of attribute api_client.
Instance Method Summary collapse
-
#initialize(api_client = ApiClient.default) ⇒ ProjectsApi
constructor
A new instance of ProjectsApi.
-
#project_create(project_create_parameters, opts = {}) ⇒ ProjectDetails
Create a project Create a new project in the given account.
-
#project_create_with_http_info(project_create_parameters, opts = {}) ⇒ Array<(Response<(ProjectDetails)>, Integer, Hash)>
Create a project Create a new project in the given account.
-
#project_delete(id, opts = {}) ⇒ nil
Delete a project Delete an existing project.
-
#project_delete_with_http_info(id, opts = {}) ⇒ Array<(Response, Integer, Hash)>
Delete a project Delete an existing project.
-
#project_show(id, opts = {}) ⇒ ProjectDetails
Get a single project Get details on a single project.
-
#project_show_with_http_info(id, opts = {}) ⇒ Array<(Response<(ProjectDetails)>, Integer, Hash)>
Get a single project Get details on a single project.
-
#project_update(id, project_update_parameters, opts = {}) ⇒ ProjectDetails
Update a project Update an existing project.
-
#project_update_with_http_info(id, project_update_parameters, opts = {}) ⇒ Array<(Response<(ProjectDetails)>, Integer, Hash)>
Update a project Update an existing project.
-
#projects_list(opts = {}) ⇒ Array<Project>
List projects List all projects the current user has access to.
-
#projects_list_with_http_info(opts = {}) ⇒ Array<(Response<(Array<Project>)>, Integer, Hash)>
List projects List all projects the current user has access to.
Constructor Details
#initialize(api_client = ApiClient.default) ⇒ ProjectsApi
Returns a new instance of ProjectsApi.
7 8 9 |
# File 'lib/phrase/api/projects_api.rb', line 7 def initialize(api_client = ApiClient.default) @api_client = api_client end |
Instance Attribute Details
#api_client ⇒ Object
Returns the value of attribute api_client.
5 6 7 |
# File 'lib/phrase/api/projects_api.rb', line 5 def api_client @api_client end |
Instance Method Details
#project_create(project_create_parameters, opts = {}) ⇒ ProjectDetails
Create a project Create a new project in the given account. When ‘source_project_id` is supplied, the new project is created as a clone of that project. All locales, keys, and translations are copied asynchronously after the response is returned, so they may not be available immediately. Settings from the source project are inherited unless explicitly overridden in the request; in clone mode, the `shares_translation_memory` field is ignored and inherited from the source. `shares_translation_memory` defaults to `true` when omitted on a non-clone create.
16 17 18 19 |
# File 'lib/phrase/api/projects_api.rb', line 16 def project_create(project_create_parameters, opts = {}) data, _status_code, _headers = project_create_with_http_info(project_create_parameters, opts) data end |
#project_create_with_http_info(project_create_parameters, opts = {}) ⇒ Array<(Response<(ProjectDetails)>, Integer, Hash)>
Create a project Create a new project in the given account. When `source_project_id` is supplied, the new project is created as a clone of that project. All locales, keys, and translations are copied asynchronously after the response is returned, so they may not be available immediately. Settings from the source project are inherited unless explicitly overridden in the request; in clone mode, the `shares_translation_memory` field is ignored and inherited from the source. `shares_translation_memory` defaults to `true` when omitted on a non-clone create.
27 28 29 30 31 32 33 34 35 36 37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 |
# File 'lib/phrase/api/projects_api.rb', line 27 def project_create_with_http_info(project_create_parameters, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: ProjectsApi.project_create ...' end # verify the required parameter 'project_create_parameters' is set if @api_client.config.client_side_validation && project_create_parameters.nil? fail ArgumentError, "Missing the required parameter 'project_create_parameters' when calling ProjectsApi.project_create" end # resource path local_var_path = '/projects' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # HTTP header 'Content-Type' header_params['Content-Type'] = @api_client.select_header_content_type(['application/json']) header_params[:'X-PhraseApp-OTP'] = opts[:'x_phrase_app_otp'] if !opts[:'x_phrase_app_otp'].nil? # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:body] || @api_client.object_to_http_body(project_create_parameters) # return_type return_type = opts[:return_type] || 'ProjectDetails' # auth_names auth_names = opts[:auth_names] || ['Basic', 'Token'] = opts.merge( :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:POST, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: ProjectsApi#project_create\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end response = ::Phrase::Response.new(data, headers) return response, status_code, headers end |
#project_delete(id, opts = {}) ⇒ nil
Delete a project Delete an existing project. Associated repository syncs and OTA distributions are removed. A ‘project:delete` event is dispatched.
84 85 86 87 |
# File 'lib/phrase/api/projects_api.rb', line 84 def project_delete(id, opts = {}) data, _status_code, _headers = project_delete_with_http_info(id, opts) data end |
#project_delete_with_http_info(id, opts = {}) ⇒ Array<(Response, Integer, Hash)>
Delete a project Delete an existing project. Associated repository syncs and OTA distributions are removed. A `project:delete` event is dispatched.
95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 |
# File 'lib/phrase/api/projects_api.rb', line 95 def project_delete_with_http_info(id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: ProjectsApi.project_delete ...' end # verify the required parameter 'id' is set if @api_client.config.client_side_validation && id.nil? fail ArgumentError, "Missing the required parameter 'id' when calling ProjectsApi.project_delete" end # resource path local_var_path = '/projects/{id}'.sub('{' + 'id' + '}', CGI.escape(id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) header_params[:'X-PhraseApp-OTP'] = opts[:'x_phrase_app_otp'] if !opts[:'x_phrase_app_otp'].nil? # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:body] # return_type return_type = opts[:return_type] # auth_names auth_names = opts[:auth_names] || ['Basic', 'Token'] = opts.merge( :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:DELETE, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: ProjectsApi#project_delete\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end response = ::Phrase::Response.new(data, headers) return response, status_code, headers end |
#project_show(id, opts = {}) ⇒ ProjectDetails
Get a single project Get details on a single project.
150 151 152 153 |
# File 'lib/phrase/api/projects_api.rb', line 150 def project_show(id, opts = {}) data, _status_code, _headers = project_show_with_http_info(id, opts) data end |
#project_show_with_http_info(id, opts = {}) ⇒ Array<(Response<(ProjectDetails)>, Integer, Hash)>
Get a single project Get details on a single project.
161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 |
# File 'lib/phrase/api/projects_api.rb', line 161 def project_show_with_http_info(id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: ProjectsApi.project_show ...' end # verify the required parameter 'id' is set if @api_client.config.client_side_validation && id.nil? fail ArgumentError, "Missing the required parameter 'id' when calling ProjectsApi.project_show" end # resource path local_var_path = '/projects/{id}'.sub('{' + 'id' + '}', CGI.escape(id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) header_params[:'X-PhraseApp-OTP'] = opts[:'x_phrase_app_otp'] if !opts[:'x_phrase_app_otp'].nil? # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:body] # return_type return_type = opts[:return_type] || 'ProjectDetails' # auth_names auth_names = opts[:auth_names] || ['Basic', 'Token'] = opts.merge( :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: ProjectsApi#project_show\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end response = ::Phrase::Response.new(data, headers) return response, status_code, headers end |
#project_update(id, project_update_parameters, opts = {}) ⇒ ProjectDetails
Update a project Update an existing project.
217 218 219 220 |
# File 'lib/phrase/api/projects_api.rb', line 217 def project_update(id, project_update_parameters, opts = {}) data, _status_code, _headers = project_update_with_http_info(id, project_update_parameters, opts) data end |
#project_update_with_http_info(id, project_update_parameters, opts = {}) ⇒ Array<(Response<(ProjectDetails)>, Integer, Hash)>
Update a project Update an existing project.
229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 |
# File 'lib/phrase/api/projects_api.rb', line 229 def project_update_with_http_info(id, project_update_parameters, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: ProjectsApi.project_update ...' end # verify the required parameter 'id' is set if @api_client.config.client_side_validation && id.nil? fail ArgumentError, "Missing the required parameter 'id' when calling ProjectsApi.project_update" end # verify the required parameter 'project_update_parameters' is set if @api_client.config.client_side_validation && project_update_parameters.nil? fail ArgumentError, "Missing the required parameter 'project_update_parameters' when calling ProjectsApi.project_update" end # resource path local_var_path = '/projects/{id}'.sub('{' + 'id' + '}', CGI.escape(id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # HTTP header 'Content-Type' header_params['Content-Type'] = @api_client.select_header_content_type(['application/json']) header_params[:'X-PhraseApp-OTP'] = opts[:'x_phrase_app_otp'] if !opts[:'x_phrase_app_otp'].nil? # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:body] || @api_client.object_to_http_body(project_update_parameters) # return_type return_type = opts[:return_type] || 'ProjectDetails' # auth_names auth_names = opts[:auth_names] || ['Basic', 'Token'] = opts.merge( :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:PATCH, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: ProjectsApi#project_update\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end response = ::Phrase::Response.new(data, headers) return response, status_code, headers end |
#projects_list(opts = {}) ⇒ Array<Project>
List projects List all projects the current user has access to. When the ‘account_id` query parameter is omitted, the response includes projects across every account the user is a member of. Pass `account_id` to scope the results to a single account.
295 296 297 298 |
# File 'lib/phrase/api/projects_api.rb', line 295 def projects_list(opts = {}) data, _status_code, _headers = projects_list_with_http_info(opts) data end |
#projects_list_with_http_info(opts = {}) ⇒ Array<(Response<(Array<Project>)>, Integer, Hash)>
List projects List all projects the current user has access to. When the `account_id` query parameter is omitted, the response includes projects across every account the user is a member of. Pass `account_id` to scope the results to a single account.
311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 350 351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 366 367 368 |
# File 'lib/phrase/api/projects_api.rb', line 311 def projects_list_with_http_info(opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: ProjectsApi.projects_list ...' end allowable_values = ["name_asc", "name_desc", "updated_at_asc", "updated_at_desc", "space_asc", "space_desc"] if @api_client.config.client_side_validation && opts[:'sort_by'] && !allowable_values.include?(opts[:'sort_by']) fail ArgumentError, "invalid value for \"sort_by\", must be one of #{allowable_values}" end allowable_values = ["favorites"] if @api_client.config.client_side_validation && opts[:'filters'] && !opts[:'filters'].all? { |item| allowable_values.include?(item) } fail ArgumentError, "invalid value for \"filters\", must include one of #{allowable_values}" end # resource path local_var_path = '/projects' # query parameters query_params = opts[:query_params] || {} query_params[:'page'] = opts[:'page'] if !opts[:'page'].nil? query_params[:'per_page'] = opts[:'per_page'] if !opts[:'per_page'].nil? query_params[:'account_id'] = opts[:'account_id'] if !opts[:'account_id'].nil? query_params[:'sort_by'] = opts[:'sort_by'] if !opts[:'sort_by'].nil? query_params[:'filters'] = @api_client.build_collection_param(opts[:'filters'], :multi) if !opts[:'filters'].nil? query_params[:'q'] = opts[:'q'] if !opts[:'q'].nil? # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) header_params[:'X-PhraseApp-OTP'] = opts[:'x_phrase_app_otp'] if !opts[:'x_phrase_app_otp'].nil? # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:body] # return_type return_type = opts[:return_type] || 'Array<Project>' # auth_names auth_names = opts[:auth_names] || ['Basic', 'Token'] = opts.merge( :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: ProjectsApi#projects_list\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end response = ::Phrase::Response.new(data, headers) return response, status_code, headers end |